@@ -43,10 +43,10 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 	protected static final String RangerModuleName =  RangerConfiguration.getInstance().get(RangerHadoopConstants.AUDITLOG_RANGER_MODULE_ACL_NAME_PROP , RangerHadoopConstants.DEFAULT_RANGER_MODULE_ACL_NAME);
 
 	private static final Log LOG = LogFactory.getLog(RangerDefaultAuditHandler.class);
-	static long sequenceNumber = 0;
+	static long sequenceNumber;
 
 	private static String UUID 	= MiscUtil.generateUniqueId();
-	private static AtomicInteger  counter =  new AtomicInteger(0);;
+	private static AtomicInteger  counter =  new AtomicInteger(0);
 
 	public RangerDefaultAuditHandler() {
 	}
@@ -149,7 +149,7 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 				}
 
 				if(ret == null) {
-					ret = new ArrayList<AuthzAuditEvent>();
+					ret = new ArrayList<>();
 				}
 
 				ret.add(event);
@@ -225,7 +225,7 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 		Set<RangerTagForEval> tags = RangerAccessRequestUtil.getRequestTagsFromContext(request.getContext());
 
 		if (CollectionUtils.isNotEmpty(tags)) {
-			ret = new HashSet<String>();
+			ret = new HashSet<>();
 
 			for (RangerTagForEval tag : tags) {
 				ret.add(writeObjectAsString(tag));
@@ -251,13 +251,11 @@ public class RangerDefaultAuditHandler implements RangerAccessResultProcessor {
 
       if(nextId == Integer.MAX_VALUE) {
         // reset UUID and counter
-        RangerDefaultAuditHandler.UUID = MiscUtil.generateUniqueId();
+        UUID = MiscUtil.generateUniqueId();
         counter = new AtomicInteger(0);
       }
 
-      String ret = RangerDefaultAuditHandler.UUID + "-" + Integer.toString(nextId);
-
-      return ret;
+      return UUID + "-" + Integer.toString(nextId);
 	 }
 
 	private String writeObjectAsString(Serializable obj) {
