@@ -52,14 +52,15 @@ public class HadoopConfigHolder  {
 	public static final String HADOOP_NAME_RULES = "hadoop.security.auth_to_local";
 	public static final String HADOOP_SECURITY_AUTHENTICATION_METHOD = "kerberos";
 	public static final String HADOOP_RPC_PROTECTION = "hadoop.rpc.protection";
+	
 	public static final String ENABLE_HIVE_METASTORE_LOOKUP = "enable.hive.metastore.lookup";
 	public static final String HIVE_SITE_FILE_PATH = "hive.site.file.path";
 
-	private static boolean initialized = false;
-	private static Map<String,HashMap<String,Properties>> dataSource2ResourceListMap = new HashMap<String,HashMap<String,Properties>>();
-	private static Map<String,HadoopConfigHolder> dataSource2HadoopConfigHolder = new HashMap<String,HadoopConfigHolder>();
+	private static boolean initialized;
+	private static Map<String,HashMap<String,Properties>> dataSource2ResourceListMap = new HashMap<>();
+	private static Map<String,HadoopConfigHolder> dataSource2HadoopConfigHolder = new HashMap<>();
 	private static Properties globalLoginProp = new Properties();
-	private static Properties resourcemapProperties = null;
+	private static Properties resourcemapProperties;
 	
 	private String datasourceName;
 	private String defaultConfigFile;
@@ -74,9 +75,9 @@ public class HadoopConfigHolder  {
 	private boolean isKerberosAuth;
 	private boolean enableHiveMetastoreLookup;
 	
-	private Map<String,String> connectionProperties;
+	private Map<String,String>  connectionProperties;
 
-  private static Set<String> rangerInternalPropertyKeys = new HashSet<String>();
+  private static Set<String> rangerInternalPropertyKeys = new HashSet<>();
 	
 	public static HadoopConfigHolder getInstance(String aDatasourceName) {
 		HadoopConfigHolder ret = dataSource2HadoopConfigHolder.get(aDatasourceName);
@@ -92,10 +93,6 @@ public class HadoopConfigHolder  {
 		return ret;
 	}
 
-  public static HadoopConfigHolder getInstance(String aDatasourceName, Map<String,String> connectionProperties) {
-    return getInstance(aDatasourceName, connectionProperties, null);
-  }
-
 	public static HadoopConfigHolder getInstance(String aDatasourceName, Map<String,String> connectionProperties,
                                                String defaultConfigFile) {
 		HadoopConfigHolder ret = dataSource2HadoopConfigHolder.get(aDatasourceName);
@@ -145,19 +142,20 @@ public class HadoopConfigHolder  {
 	
 	private void initConnectionProp() {
 		if (!connectionProperties.containsKey(ENABLE_HIVE_METASTORE_LOOKUP)) {
-			connectionProperties.put(ENABLE_HIVE_METASTORE_LOOKUP, "false");
-		}
+			 connectionProperties.put(ENABLE_HIVE_METASTORE_LOOKUP, "false");
+		 }
 		if (!connectionProperties.containsKey(HIVE_SITE_FILE_PATH)) {
-			connectionProperties.put(HIVE_SITE_FILE_PATH, "");
-		}
-		for (String key : connectionProperties.keySet()) {
-			
+			 connectionProperties.put(HIVE_SITE_FILE_PATH, "");
+		 }
+
+		for (Map.Entry<String, String> entry : connectionProperties.entrySet()) {
+			String key = entry.getKey();
 			String resourceName = getResourceName(key);
 			
 			if (resourceName == null) {
 				resourceName = RANGER_SECTION_NAME;
 			}
-			String val = connectionProperties.get(key);
+			String val = entry.getValue();
 			addConfiguration(datasourceName, resourceName, key, val );
 		}
 	}
@@ -170,43 +168,41 @@ public class HadoopConfigHolder  {
 
 		if (resourcemapProperties != null) {
 			String rn = resourcemapProperties.getProperty(key);
-			return (rn != null) ? rn : defaultConfigFile;
+			return ( rn != null)  ? rn : defaultConfigFile;
 		} else {
 			return defaultConfigFile;
 		}
 	}
 
-	public static void initResourceMap() {
-		if (resourcemapProperties == null) {
-			resourcemapProperties = new Properties();
-			InputStream in = HadoopConfigHolder.class.getClassLoader().getResourceAsStream(RESOURCEMAP_PROP_FILE);
-			if (in != null) {
-				try {
-					resourcemapProperties.load(in);
-		          for (Map.Entry<Object, Object> entry : resourcemapProperties.entrySet() ) {
-		            String key = (String)entry.getKey();
-		            String value = (String)entry.getValue();
+	private static void initResourceMap() {
+		Properties props = new Properties();
+		InputStream in = HadoopConfigHolder.class.getClassLoader().getResourceAsStream(RESOURCEMAP_PROP_FILE);
+		if (in != null) {
+			try {
+				props.load(in);
+				for (Map.Entry<Object, Object> entry : props
+						.entrySet()) {
+					String value = (String) entry.getValue();
 					if (RANGER_SECTION_NAME.equals(value)) {
-		              rangerInternalPropertyKeys.add(key);
-		            }
-		          }
-				} catch (IOException e) {
-					throw new HadoopException("Unable to load resource map properties from [" + RESOURCEMAP_PROP_FILE + "]", e);
+						String key = (String) entry.getKey();
+						rangerInternalPropertyKeys.add(key);
+					}
 				}
-				finally {
-					if (in != null) {
-						try {
-							in.close();
-						}
-						catch (IOException ioe) {
-							// Ignore IOException during close of stream
-						}
+				resourcemapProperties = props;
+			} catch (IOException e) {
+				throw new HadoopException("Unable to load resource map properties from [" + RESOURCEMAP_PROP_FILE + "]", e);
+			}
+			finally {
+				if (in != null) {
+					try {
+						in.close();
+					} catch (IOException ioe) {
+						// Ignore IOException during close of stream
 					}
 				}
 			}
-			else {
-				throw new HadoopException("Unable to locate resource map properties from [" + RESOURCEMAP_PROP_FILE + "] in the class path.");
-			}
+		} else {
+			throw new HadoopException("Unable to locate resource map properties from [" + RESOURCEMAP_PROP_FILE + "] in the class path.");
 		}
 	}
 
@@ -235,8 +231,9 @@ public class HadoopConfigHolder  {
 					}
 				}
 	
-				if (prop.size() == 0)
+				if (prop.isEmpty()) {
 					return;
+				}
 				
 				for (Object keyobj : prop.keySet()) {
 					String key = (String)keyobj;
@@ -303,18 +300,18 @@ public class HadoopConfigHolder  {
 			} else {
 				hiveSiteFilePath = null;
 			}
+
                         password = prop.getProperty(RANGER_LOGIN_PASSWORD);
 			lookupPrincipal = prop.getProperty(RANGER_LOOKUP_PRINCIPAL);
 			lookupKeytab = prop.getProperty(RANGER_LOOKUP_KEYTAB);
 			nameRules = prop.getProperty(RANGER_NAME_RULES);
 			authType = prop.getProperty(RANGER_AUTH_TYPE, "simple");
 			
-			String hadoopSecurityAuthenticationn =  getHadoopSecurityAuthentication();
+			String hadoopSecurityAuthentication =  getHadoopSecurityAuthentication();
 
-			if (hadoopSecurityAuthenticationn != null) {
-				isKerberosAuth = (hadoopSecurityAuthenticationn.equalsIgnoreCase(HADOOP_SECURITY_AUTHENTICATION_METHOD));
-			}
-			else {
+			if (hadoopSecurityAuthentication != null) {
+				isKerberosAuth = HADOOP_SECURITY_AUTHENTICATION_METHOD.equalsIgnoreCase(hadoopSecurityAuthentication);
+			} else {
 				isKerberosAuth = (((userName != null) && (userName.indexOf("@") > -1)) || (SecureClientLogin.isKerberosCredentialExists(lookupPrincipal, lookupKeytab)));
 			}
 		}
@@ -349,7 +346,7 @@ public class HadoopConfigHolder  {
 		HashMap<String,Properties> resourceName2PropertiesMap  = dataSource2ResourceListMap.get(dataSource);
 		
 		if (resourceName2PropertiesMap == null) {
-			resourceName2PropertiesMap = new HashMap<String,Properties>();
+			resourceName2PropertiesMap = new HashMap<>();
 			dataSource2ResourceListMap.put(dataSource, resourceName2PropertiesMap);
 		}
 		
@@ -360,8 +357,7 @@ public class HadoopConfigHolder  {
 		}
 		if (value == null) {
 			prop.remove(propertyName);
-		}
-		else {
+		} else {
 			prop.put(propertyName, value);
 		}
 	}
@@ -422,19 +418,19 @@ public class HadoopConfigHolder  {
 		return isKerberosAuth;
 	}
 	
-	public String getLookupPrincipal(){
+	public String getLookupPrincipal() {
 		return lookupPrincipal;
 	}
 
-	public String getLookupKeytab(){
+	public String getLookupKeytab() {
 		return lookupKeytab;
 	}
 
-	public String getNameRules(){
+	public String getNameRules() {
 		return nameRules;
 	}
-	
-	public String getAuthType(){
+
+	public String getAuthType() {
 		return authType;
 	}
 
@@ -446,10 +442,9 @@ public class HadoopConfigHolder  {
 		return hiveSiteFilePath;
 	}
 
-  public Set<String> getRangerInternalPropertyKeys() {
-    return rangerInternalPropertyKeys;
-
-  }
+	public Set<String> getRangerInternalPropertyKeys() {
+		return rangerInternalPropertyKeys;
+	}
 
 	private String getProperties(String sectionName, String property) {
 
