@@ -159,11 +159,11 @@ public final class RangerScriptExecutionContext {
 		RangerTagForEval ret = null;
 		Object    val = getRequestContext().get(RangerAccessRequestUtil.KEY_CONTEXT_TAG_OBJECT);
 
-		if(val != null && val instanceof RangerTagForEval) {
+		if(val instanceof RangerTagForEval) {
 			ret = (RangerTagForEval)val;
 		} else {
 			if (LOG.isDebugEnabled()) {
-				LOG.debug("getCurrentTag() - No current TAG object. Script execution must be for resource-based policy.");
+				logDebug("RangerScriptExecutionContext.getCurrentTag() - No current TAG object. Script execution must be for resource-based policy.");
 			}
 		}
 		return ret;
@@ -182,7 +182,7 @@ public final class RangerScriptExecutionContext {
 			for (RangerTagForEval tag : tagObjectList) {
 				String tagType = tag.getType();
 				if (allTagTypes == null) {
-					allTagTypes = new HashSet<String>();
+					allTagTypes = new HashSet<>();
 				}
 				allTagTypes.add(tagType);
 			}
@@ -285,7 +285,7 @@ public final class RangerScriptExecutionContext {
 				ret = getAsDate(value, simpleDateFormat);
 				if (ret != null) {
 					if (LOG.isDebugEnabled()) {
-						LOG.debug("The best match found for Format-String:[" + simpleDateFormat.toPattern() + "], date:[" + ret +"]");
+						logDebug("RangerScriptExecutionContext.getAsDate() -The best match found for Format-String:[" + simpleDateFormat.toPattern() + "], date:[" + ret +"]");
 					}
 					break;
 				}
@@ -293,7 +293,7 @@ public final class RangerScriptExecutionContext {
 		}
 
 		if (ret == null) {
-			LOG.error("RangerScriptExecutionContext.getAsDate() - Could not convert [" + value + "] to Date using any of the Format-Strings: " + Arrays.toString(dateFormatStrings));
+			logError("RangerScriptExecutionContext.getAsDate() - Could not convert [" + value + "] to Date using any of the Format-Strings: " + Arrays.toString(dateFormatStrings));
 		} else {
 			ret = StringUtil.getUTCDateForLocalDate(ret);
 		}
@@ -361,30 +361,30 @@ public final class RangerScriptExecutionContext {
 			if (LOG.isDebugEnabled()) {
 				String resource = accessRequest.getResource().getAsString();
 
-				LOG.debug("getAllTags() - No TAGS. No TAGS for the RangerAccessResource=" + resource);
+				logDebug("RangerScriptExecutionContext.getAllTags() - No TAGS. No TAGS for the RangerAccessResource=" + resource);
 			}
 		}
 
 		return ret;
 	}
 
-	public void logDebug(String msg) {
+	public void logDebug(Object msg) {
 		LOG.debug(msg);
 	}
 
-	public void logInfo(String msg) {
+	public void logInfo(Object msg) {
 		LOG.info(msg);
 	}
 
-	public void logWarn(String msg) {
+	public void logWarn(Object msg) {
 		LOG.warn(msg);
 	}
 
-	public void logError(String msg) {
+	public void logError(Object msg) {
 		LOG.error(msg);
 	}
 
-	public void logFatal(String msg) {
+	public void logFatal(Object msg) {
 		LOG.fatal(msg);
 	}
 }
