@@ -57,26 +57,28 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	// For future use
 	private static final long serialVersionUID = 1L;
 
-	private String                            service        	= null;
-	private String                            name           	= null;
-	private Integer                           policyType     	= null;
-	private String                            description    	= null;
-	private String							  resourceSignature = null;
-	private Boolean                           isAuditEnabled 	= null;
-	private Map<String, RangerPolicyResource> resources      	= null;
-	private List<RangerPolicyItem>            policyItems    	= null;
-	private List<RangerPolicyItem>            denyPolicyItems	= null;
-	private List<RangerPolicyItem>            allowExceptions	= null;
-	private List<RangerPolicyItem>            denyExceptions	= null;
-	private List<RangerDataMaskPolicyItem>    dataMaskPolicyItems  = null;
-	private List<RangerRowFilterPolicyItem>   rowFilterPolicyItems = null;
+	private String                            service;
+	private String                            name;
+	private Integer                           policyType;
+	private String                            description;
+	private String							  resourceSignature;
+	private Boolean                           isAuditEnabled;
+	private Map<String, RangerPolicyResource> resources;
+	private List<RangerPolicyItem>            policyItems;
+	private List<RangerPolicyItem>            denyPolicyItems;
+	private List<RangerPolicyItem>            allowExceptions;
+	private List<RangerPolicyItem>            denyExceptions;
+	private List<RangerDataMaskPolicyItem>    dataMaskPolicyItems;
+	private List<RangerRowFilterPolicyItem>   rowFilterPolicyItems;
+  private String                            serviceType;
+  private List<String> policyLabels;
 
 
 	/**
 	 * @param
 	 */
 	public RangerPolicy() {
-		this(null, null, null, null, null, null, null);
+                this(null, null, null, null, null, null, null, null);
 	}
 
 	/**
@@ -88,7 +90,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 * @param policyItems
 	 * @param resourceSignature TODO
 	 */
-	public RangerPolicy(String service, String name, Integer policyType, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature) {
+        public RangerPolicy(String service, String name, Integer policyType, String description, Map<String, RangerPolicyResource> resources, List<RangerPolicyItem> policyItems, String resourceSignature, List<String> policyLables) {
 		super();
 
 		setService(service);
@@ -104,6 +106,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		setDenyExceptions(null);
 		setDataMaskPolicyItems(null);
 		setRowFilterPolicyItems(null);
+                setPolicyLabels(policyLables);
 	}
 
 	/**
@@ -125,6 +128,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		setDenyExceptions(other.getDenyExceptions());
 		setDataMaskPolicyItems(other.getDataMaskPolicyItems());
 		setRowFilterPolicyItems(other.getRowFilterPolicyItems());
+                setPolicyLabels(other.getPolicyLabels());
 	}
 
 	/**
@@ -211,6 +215,34 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.isAuditEnabled = isAuditEnabled == null ? Boolean.TRUE : isAuditEnabled;
 	}
 
+        public String getServiceType() {
+                return serviceType;
+        }
+
+        public void setServiceType(String serviceType) {
+                this.serviceType = serviceType;
+        }
+
+        public List<String> getPolicyLabels() {
+                return policyLabels;
+        }
+
+        public void setPolicyLabels(List<String> policyLabels) {
+                if (this.policyLabels == null) {
+                        this.policyLabels = new ArrayList<>();
+                }
+
+                if (this.policyLabels == policyLabels) {
+                        return;
+                }
+
+                this.policyLabels.clear();
+
+                if (policyLabels != null) {
+                        this.policyLabels.addAll(policyLabels);
+                }
+        }
+
 	/**
 	 * @return the resources
 	 */
@@ -223,7 +255,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 */
 	public void setResources(Map<String, RangerPolicyResource> resources) {
 		if(this.resources == null) {
-			this.resources = new HashMap<String, RangerPolicyResource>();
+			this.resources = new HashMap<>();
 		}
 
 		if(this.resources == resources) {
@@ -251,7 +283,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 */
 	public void setPolicyItems(List<RangerPolicyItem> policyItems) {
 		if(this.policyItems == null) {
-			this.policyItems = new ArrayList<RangerPolicyItem>();
+			this.policyItems = new ArrayList<>();
 		}
 
 		if(this.policyItems == policyItems) {
@@ -261,9 +293,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.policyItems.clear();
 
 		if(policyItems != null) {
-			for(RangerPolicyItem policyItem : policyItems) {
-				this.policyItems.add(policyItem);
-			}
+			this.policyItems.addAll(policyItems);
 		}
 	}
 
@@ -279,7 +309,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 */
 	public void setDenyPolicyItems(List<RangerPolicyItem> denyPolicyItems) {
 		if(this.denyPolicyItems == null) {
-			this.denyPolicyItems = new ArrayList<RangerPolicyItem>();
+			this.denyPolicyItems = new ArrayList<>();
 		}
 
 		if(this.denyPolicyItems == denyPolicyItems) {
@@ -289,9 +319,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.denyPolicyItems.clear();
 
 		if(denyPolicyItems != null) {
-			for(RangerPolicyItem policyItem : denyPolicyItems) {
-				this.denyPolicyItems.add(policyItem);
-			}
+			this.denyPolicyItems.addAll(denyPolicyItems);
 		}
 	}
 
@@ -307,7 +335,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 */
 	public void setAllowExceptions(List<RangerPolicyItem> allowExceptions) {
 		if(this.allowExceptions == null) {
-			this.allowExceptions = new ArrayList<RangerPolicyItem>();
+			this.allowExceptions = new ArrayList<>();
 		}
 
 		if(this.allowExceptions == allowExceptions) {
@@ -317,9 +345,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.allowExceptions.clear();
 
 		if(allowExceptions != null) {
-			for(RangerPolicyItem policyItem : allowExceptions) {
-				this.allowExceptions.add(policyItem);
-			}
+			this.allowExceptions.addAll(allowExceptions);
 		}
 	}
 
@@ -335,7 +361,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	 */
 	public void setDenyExceptions(List<RangerPolicyItem> denyExceptions) {
 		if(this.denyExceptions == null) {
-			this.denyExceptions = new ArrayList<RangerPolicyItem>();
+			this.denyExceptions = new ArrayList<>();
 		}
 
 		if(this.denyExceptions == denyExceptions) {
@@ -345,9 +371,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.denyExceptions.clear();
 
 		if(denyExceptions != null) {
-			for(RangerPolicyItem policyItem : denyExceptions) {
-				this.denyExceptions.add(policyItem);
-			}
+			this.denyExceptions.addAll(denyExceptions);
 		}
 	}
 
@@ -357,7 +381,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 
 	public void setDataMaskPolicyItems(List<RangerDataMaskPolicyItem> dataMaskPolicyItems) {
 		if(this.dataMaskPolicyItems == null) {
-			this.dataMaskPolicyItems = new ArrayList<RangerDataMaskPolicyItem>();
+			this.dataMaskPolicyItems = new ArrayList<>();
 		}
 
 		if(this.dataMaskPolicyItems == dataMaskPolicyItems) {
@@ -367,9 +391,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.dataMaskPolicyItems.clear();
 
 		if(dataMaskPolicyItems != null) {
-			for(RangerDataMaskPolicyItem dataMaskPolicyItem : dataMaskPolicyItems) {
-				this.dataMaskPolicyItems.add(dataMaskPolicyItem);
-			}
+			this.dataMaskPolicyItems.addAll(dataMaskPolicyItems);
 		}
 	}
 
@@ -379,7 +401,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 
 	public void setRowFilterPolicyItems(List<RangerRowFilterPolicyItem> rowFilterPolicyItems) {
 		if(this.rowFilterPolicyItems == null) {
-			this.rowFilterPolicyItems = new ArrayList<RangerRowFilterPolicyItem>();
+			this.rowFilterPolicyItems = new ArrayList<>();
 		}
 
 		if(this.rowFilterPolicyItems == rowFilterPolicyItems) {
@@ -389,9 +411,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		this.rowFilterPolicyItems.clear();
 
 		if(rowFilterPolicyItems != null) {
-			for(RangerRowFilterPolicyItem rowFilterPolicyItem : rowFilterPolicyItems) {
-				this.rowFilterPolicyItems.add(rowFilterPolicyItem);
-			}
+			this.rowFilterPolicyItems.addAll(rowFilterPolicyItems);
 		}
 	}
 
@@ -415,6 +435,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		sb.append("description={").append(description).append("} ");
 		sb.append("resourceSignature={").append(resourceSignature).append("} ");
 		sb.append("isAuditEnabled={").append(isAuditEnabled).append("} ");
+                sb.append("serviceType={").append(serviceType).append("} ");
 
 		sb.append("resources={");
 		if(resources != null) {
@@ -425,7 +446,15 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			}
 		}
 		sb.append("} ");
-
+                sb.append("policyLabels={");
+                if(policyLabels != null) {
+                        for(String policyLabel : policyLabels) {
+                                if(policyLabel != null) {
+                                        sb.append(policyLabel).append(" ");
+                                }
+                        }
+                }
+                sb.append("} ");
 		sb.append("policyItems={");
 		if(policyItems != null) {
 			for(RangerPolicyItem policyItem : policyItems) {
@@ -500,10 +529,9 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerPolicyResource implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private List<String> values      = null;
-		private Boolean      isExcludes = null;
-		private Boolean      isRecursive = null;
-
+		private List<String> values;
+		private Boolean      isExcludes;
+		private Boolean      isRecursive;
 
 		public RangerPolicyResource() {
 			this((List<String>)null, null, null);
@@ -539,7 +567,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setValues(List<String> values) {
 			if(this.values == null) {
-				this.values = new ArrayList<String>();
+				this.values = new ArrayList<>();
 			}
 
 			if(this.values == values) {
@@ -549,9 +577,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			this.values.clear();
 
 			if(values != null) {
-				for(String value : values) {
-					this.values.add(value);
-				}
+				this.values.addAll(values);
 			}
 		}
 
@@ -560,7 +586,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setValue(String value) {
 			if(this.values == null) {
-				this.values = new ArrayList<String>();
+				this.values = new ArrayList<>();
 			}
 
 			this.values.clear();
@@ -671,11 +697,11 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerPolicyItem implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private List<RangerPolicyItemAccess>    accesses      = null;
-		private List<String>                    users         = null;
-		private List<String>                    groups        = null;
-		private List<RangerPolicyItemCondition> conditions    = null;
-		private Boolean                         delegateAdmin = null;
+		private List<RangerPolicyItemAccess>    accesses;
+		private List<String>                    users;
+		private List<String>                    groups;
+		private List<RangerPolicyItemCondition> conditions;
+		private Boolean                         delegateAdmin;
 
 		public RangerPolicyItem() {
 			this(null, null, null, null, null);
@@ -700,7 +726,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setAccesses(List<RangerPolicyItemAccess> accesses) {
 			if(this.accesses == null) {
-				this.accesses = new ArrayList<RangerPolicyItemAccess>();
+				this.accesses = new ArrayList<>();
 			}
 
 			if(this.accesses == accesses) {
@@ -710,9 +736,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			this.accesses.clear();
 
 			if(accesses != null) {
-				for(RangerPolicyItemAccess access : accesses) {
-					this.accesses.add(access);
-				}
+				this.accesses.addAll(accesses);
 			}
 		}
 		/**
@@ -726,7 +750,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setUsers(List<String> users) {
 			if(this.users == null) {
-				this.users = new ArrayList<String>();
+				this.users = new ArrayList<>();
 			}
 
 			if(this.users == users) {
@@ -736,9 +760,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			this.users.clear();
 
 			if(users != null) {
-				for(String user : users) {
-					this.users.add(user);
-				}
+				this.users.addAll(users);
 			}
 		}
 		/**
@@ -752,7 +774,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setGroups(List<String> groups) {
 			if(this.groups == null) {
-				this.groups = new ArrayList<String>();
+				this.groups = new ArrayList<>();
 			}
 
 			if(this.groups == groups) {
@@ -762,9 +784,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			this.groups.clear();
 
 			if(groups != null) {
-				for(String group : groups) {
-					this.groups.add(group);
-				}
+				this.groups.addAll(groups);
 			}
 		}
 		/**
@@ -778,7 +798,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setConditions(List<RangerPolicyItemCondition> conditions) {
 			if(this.conditions == null) {
-				this.conditions = new ArrayList<RangerPolicyItemCondition>();
+				this.conditions = new ArrayList<>();
 			}
 
 			if(this.conditions == conditions) {
@@ -788,9 +808,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			this.conditions.clear();
 
 			if(conditions != null) {
-				for(RangerPolicyItemCondition condition : conditions) {
-					this.conditions.add(condition);
-				}
+				this.conditions.addAll(conditions);
 			}
 		}
 
@@ -929,7 +947,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerDataMaskPolicyItem extends RangerPolicyItem implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private RangerPolicyItemDataMaskInfo dataMaskInfo = null;
+		private RangerPolicyItemDataMaskInfo dataMaskInfo;
 
 		public RangerDataMaskPolicyItem() {
 			this(null, null, null, null, null, null);
@@ -1016,7 +1034,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerRowFilterPolicyItem extends RangerPolicyItem implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private RangerPolicyItemRowFilterInfo rowFilterInfo = null;
+		private RangerPolicyItemRowFilterInfo rowFilterInfo;
 
 		public RangerRowFilterPolicyItem() {
 			this(null, null, null, null, null, null);
@@ -1103,8 +1121,8 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerPolicyItemAccess implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private String  type      = null;
-		private Boolean isAllowed = null;
+		private String  type;
+		private Boolean isAllowed;
 
 		public RangerPolicyItemAccess() {
 			this(null, null);
@@ -1207,8 +1225,8 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerPolicyItemCondition implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private String type  = null;
-		private List<String> values = null;
+		private String type;
+		private List<String> values;
 
 		public RangerPolicyItemCondition() {
 			this(null, null);
@@ -1245,7 +1263,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 		 */
 		public void setValues(List<String> values) {
 			if (this.values == null) {
-				this.values = new ArrayList<String>();
+				this.values = new ArrayList<>();
 			}
 
 			if(this.values == values) {
@@ -1255,9 +1273,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 			this.values.clear();
 
 			if(values != null) {
-				for(String value : values) {
-					this.values.add(value);
-				}
+				this.values.addAll(values);
 			}
 		}
 
@@ -1327,9 +1343,9 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerPolicyItemDataMaskInfo implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private String dataMaskType  = null;
-		private String conditionExpr = null;
-		private String valueExpr     = null;
+		private String dataMaskType;
+		private String conditionExpr;
+		private String valueExpr;
 
 		public RangerPolicyItemDataMaskInfo() { }
 
@@ -1432,7 +1448,7 @@ public class RangerPolicy extends RangerBaseModelObject implements java.io.Seria
 	public static class RangerPolicyItemRowFilterInfo implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private String filterExpr = null;
+		private String filterExpr;
 
 		public RangerPolicyItemRowFilterInfo() { }
 
