@@ -22,8 +22,10 @@ package org.apache.ranger.plugin.model;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.HashMap;
+import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import javax.xml.bind.annotation.XmlAccessType;
 import javax.xml.bind.annotation.XmlAccessorType;
@@ -45,22 +47,21 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 	public static final String OPTION_ENABLE_DENY_AND_EXCEPTIONS_IN_POLICIES = "enableDenyAndExceptionsInPolicies";
 
-	private String                         name             = null;
-	private String                         implClass        = null;
-	private String                         label            = null;
-	private String                         description      = null;
-	private String                         rbKeyLabel       = null;
-	private String                         rbKeyDescription = null;
-	private Map<String, String>            options          = null;
-	private List<RangerServiceConfigDef>   configs          = null;
-	private List<RangerResourceDef>        resources        = null;
-	private List<RangerAccessTypeDef>      accessTypes      = null;
-	private List<RangerPolicyConditionDef> policyConditions = null;
-	private List<RangerContextEnricherDef> contextEnrichers = null;
-	private List<RangerEnumDef>            enums            = null;
-	private RangerDataMaskDef              dataMaskDef      = null;
-	private RangerRowFilterDef             rowFilterDef     = null;
-
+	private String                         name;
+	private String                         implClass;
+	private String                         label;
+	private String                         description;
+	private String                         rbKeyLabel;
+	private String                         rbKeyDescription;
+	private Map<String, String>            options;
+	private List<RangerServiceConfigDef>   configs;
+	private List<RangerResourceDef>        resources;
+	private List<RangerAccessTypeDef>      accessTypes;
+	private List<RangerPolicyConditionDef> policyConditions;
+	private List<RangerContextEnricherDef> contextEnrichers;
+	private List<RangerEnumDef>            enums;
+	private RangerDataMaskDef              dataMaskDef;
+	private RangerRowFilterDef             rowFilterDef;
 
 	public RangerServiceDef() {
 		this(null, null, null, null, null, null, null, null, null, null, null, null, null);
@@ -113,6 +114,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		setLabel(other.getLabel());
 		setDescription(other.getDescription());
 		setConfigs(other.getConfigs());
+		setOptions(other.getOptions());
 		setResources(other.getResources());
 		setAccessTypes(other.getAccessTypes());
 		setPolicyConditions(other.getPolicyConditions());
@@ -217,7 +219,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setConfigs(List<RangerServiceConfigDef> configs) {
 		if(this.configs == null) {
-			this.configs = new ArrayList<RangerServiceConfigDef>();
+			this.configs = new ArrayList<>();
 		} else
 
 		if(this.configs == configs) {
@@ -227,9 +229,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.configs.clear();
 
 		if(configs != null) {
-			for(RangerServiceConfigDef config : configs) {
-				this.configs.add(config);
-			}
+			this.configs.addAll(configs);
 		}
 	}
 
@@ -245,7 +245,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setOptions(Map<String, String> options) {
 		if(this.options == null) {
-			this.options = new HashMap<String, String>();
+			this.options = new HashMap<>();
 		} else if(this.options == options) {
 			return;
 		}
@@ -271,7 +271,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setResources(List<RangerResourceDef> resources) {
 		if(this.resources == null) {
-			this.resources = new ArrayList<RangerResourceDef>();
+			this.resources = new ArrayList<>();
 		}
 
 		if(this.resources == resources) {
@@ -281,9 +281,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.resources.clear();
 
 		if(resources != null) {
-			for(RangerResourceDef resource : resources) {
-				this.resources.add(resource);
-			}
+			this.resources.addAll(resources);
 		}
 	}
 
@@ -299,7 +297,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setAccessTypes(List<RangerAccessTypeDef> accessTypes) {
 		if(this.accessTypes == null) {
-			this.accessTypes = new ArrayList<RangerAccessTypeDef>();
+			this.accessTypes = new ArrayList<>();
 		}
 
 		if(this.accessTypes == accessTypes) {
@@ -309,9 +307,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.accessTypes.clear();
 
 		if(accessTypes != null) {
-			for(RangerAccessTypeDef accessType : accessTypes) {
-				this.accessTypes.add(accessType);
-			}
+			this.accessTypes.addAll(accessTypes);
 		}
 	}
 
@@ -327,7 +323,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setPolicyConditions(List<RangerPolicyConditionDef> policyConditions) {
 		if(this.policyConditions == null) {
-			this.policyConditions = new ArrayList<RangerPolicyConditionDef>();
+			this.policyConditions = new ArrayList<>();
 		}
 
 		if(this.policyConditions == policyConditions) {
@@ -337,9 +333,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.policyConditions.clear();
 
 		if(policyConditions != null) {
-			for(RangerPolicyConditionDef policyCondition : policyConditions) {
-				this.policyConditions.add(policyCondition);
-			}
+			this.policyConditions.addAll(policyConditions);
 		}
 	}
 
@@ -355,7 +349,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setContextEnrichers(List<RangerContextEnricherDef> contextEnrichers) {
 		if(this.contextEnrichers == null) {
-			this.contextEnrichers = new ArrayList<RangerContextEnricherDef>();
+			this.contextEnrichers = new ArrayList<>();
 		}
 
 		if(this.contextEnrichers == contextEnrichers) {
@@ -365,9 +359,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.contextEnrichers.clear();
 
 		if(contextEnrichers != null) {
-			for(RangerContextEnricherDef contextEnricher : contextEnrichers) {
-				this.contextEnrichers.add(contextEnricher);
-			}
+			this.contextEnrichers.addAll(contextEnrichers);
 		}
 	}
 
@@ -383,7 +375,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	 */
 	public void setEnums(List<RangerEnumDef> enums) {
 		if(this.enums == null) {
-			this.enums = new ArrayList<RangerEnumDef>();
+			this.enums = new ArrayList<>();
 		}
 
 		if(this.enums == enums) {
@@ -393,9 +385,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		this.enums.clear();
 
 		if(enums != null) {
-			for(RangerEnumDef enum1 : enums) {
-				this.enums.add(enum1);
-			}
+			this.enums.addAll(enums);
 		}
 	}
 
@@ -530,11 +520,10 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerEnumDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long                       itemId       = null;
-		private String                     name         = null;
-		private List<RangerEnumElementDef> elements     = null;
-		private Integer                    defaultIndex = null;
-
+		private Long                       itemId;
+		private String                     name;
+		private List<RangerEnumElementDef> elements;
+		private Integer                    defaultIndex;
 
 		public RangerEnumDef() {
 			this(null, null, null, null);
@@ -587,7 +576,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		 */
 		public void setElements(List<RangerEnumElementDef> elements) {
 			if(this.elements == null) {
-				this.elements = new ArrayList<RangerEnumElementDef>();
+				this.elements = new ArrayList<>();
 			}
 
 			if(this.elements == elements) {
@@ -597,9 +586,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.elements.clear();
 
 			if(elements != null) {
-				for(RangerEnumElementDef element : elements) {
-					this.elements.add(element);
-				}
+				this.elements.addAll(elements);
 			}
 		}
 
@@ -701,11 +688,10 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerEnumElementDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 		
-		private Long   itemId     = null;
-		private String name       = null;
-		private String label      = null;
-		private String rbKeyLabel = null;
-
+		private Long   itemId;
+		private String name;
+		private String label;
+		private String rbKeyLabel;
 
 		public RangerEnumElementDef() {
 			this(null, null, null, null);
@@ -851,21 +837,20 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerServiceConfigDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long    itemId            = null;
-		private String  name              = null;
-		private String  type              = null;
-		private String  subType           = null;
-		private Boolean mandatory         = null;
-		private String  defaultValue      = null;
-		private String  validationRegEx   = null;
-		private String  validationMessage = null;
-		private String  uiHint            = null;
-		private String  label             = null;
-		private String  description       = null;
-		private String  rbKeyLabel        = null;
-		private String  rbKeyDescription  = null;
-		private String  rbKeyValidationMessage = null;
-
+		private Long    itemId;
+		private String  name;
+		private String  type;
+		private String  subType;
+		private Boolean mandatory;
+		private String  defaultValue;
+		private String  validationRegEx;
+		private String  validationMessage;
+		private String  uiHint;
+		private String  label;
+		private String  description;
+		private String  rbKeyLabel;
+		private String  rbKeyDescription;
+		private String  rbKeyValidationMessage;
 
 		public RangerServiceConfigDef() {
 			this(null, null, null, null, null, null, null, null, null, null, null, null, null, null);
@@ -1240,28 +1225,30 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerResourceDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long                itemId                 = null;
-		private String              name                   = null;
-		private String              type                   = null;
-		private Integer             level                  = null;
-		private String              parent                 = null;
-		private Boolean             mandatory              = null;
-		private Boolean             lookupSupported        = null;
-		private Boolean             recursiveSupported     = null;
-		private Boolean             excludesSupported      = null;
-		private String              matcher                = null;
-		private Map<String, String> matcherOptions         = null;
-		private String              validationRegEx        = null;
-		private String              validationMessage      = null;
-		private String              uiHint                 = null;
-		private String              label                  = null;
-		private String              description            = null;
-		private String              rbKeyLabel             = null;
-		private String              rbKeyDescription       = null;
-		private String              rbKeyValidationMessage = null;
+		private Long                itemId;
+		private String              name;
+		private String              type;
+		private Integer             level;
+		private String              parent;
+		private Boolean             mandatory;
+		private Boolean             lookupSupported;
+		private Boolean             recursiveSupported;
+		private Boolean             excludesSupported;
+		private String              matcher;
+		private Map<String, String> matcherOptions;
+		private String              validationRegEx;
+		private String              validationMessage;
+		private String              uiHint;
+		private String              label;
+		private String              description;
+		private String              rbKeyLabel;
+		private String              rbKeyDescription;
+		private String              rbKeyValidationMessage;
+		private Set<String>         accessTypeRestrictions;
+		private Boolean             isValidLeaf;
 
 		public RangerResourceDef() {
-			this(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null);
+			this(null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null, null);
 		}
 
 		public RangerResourceDef(RangerResourceDef other) {
@@ -1284,9 +1271,11 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			setRbKeyLabel(other.getRbKeyLabel());
 			setRbKeyDescription(other.getRbKeyDescription());
 			setRbKeyValidationMessage(other.getRbKeyValidationMessage());
+			setAccessTypeRestrictions(other.getAccessTypeRestrictions());
+			setIsValidLeaf(other.getIsValidLeaf());
 		}
 
-		public RangerResourceDef(Long itemId, String name, String type, Integer level, String parent, Boolean mandatory, Boolean lookupSupported, Boolean recursiveSupported, Boolean excludesSupported, String matcher, Map<String, String> matcherOptions, String validationRegEx, String validationMessage, String uiHint, String label, String description, String rbKeyLabel, String rbKeyDescription, String rbKeyValidationMessage) {
+		public RangerResourceDef(Long itemId, String name, String type, Integer level, String parent, Boolean mandatory, Boolean lookupSupported, Boolean recursiveSupported, Boolean excludesSupported, String matcher, Map<String, String> matcherOptions, String validationRegEx, String validationMessage, String uiHint, String label, String description, String rbKeyLabel, String rbKeyDescription, String rbKeyValidationMessage, Set<String> accessTypeRestrictions, Boolean isValidLeaf) {
 			setItemId(itemId);
 			setName(name);
 			setType(type);
@@ -1306,6 +1295,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			setRbKeyLabel(rbKeyLabel);
 			setRbKeyDescription(rbKeyDescription);
 			setRbKeyValidationMessage(rbKeyValidationMessage);
+			setAccessTypeRestrictions(accessTypeRestrictions);
+			setIsValidLeaf(isValidLeaf);
 		}
 
 		/**
@@ -1574,6 +1565,20 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.rbKeyValidationMessage = rbKeyValidationMessage;
 		}
 
+		public Set<String> getAccessTypeRestrictions() {
+			return accessTypeRestrictions;
+		}
+
+		public void setAccessTypeRestrictions(Set<String> accessTypeRestrictions) {
+			this.accessTypeRestrictions = accessTypeRestrictions == null ? new HashSet<String>() : new HashSet<String>(accessTypeRestrictions);
+		}
+
+		public Boolean getIsValidLeaf() { return isValidLeaf; }
+
+		public void setIsValidLeaf(Boolean isValidLeaf) {
+		    this.isValidLeaf = isValidLeaf;
+        }
+
 		@Override
 		public String toString( ) {
 			StringBuilder sb = new StringBuilder();
@@ -1604,6 +1609,8 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			sb.append("rbKeyLabel={").append(rbKeyLabel).append("} ");
 			sb.append("rbKeyDescription={").append(rbKeyDescription).append("} ");
 			sb.append("rbKeyValidationMessage={").append(rbKeyValidationMessage).append("} ");
+			sb.append("accessTypeRestrictions={").append(accessTypeRestrictions == null ? "null" : accessTypeRestrictions.toString()).append("} ");
+			sb.append("isValidLeaf={").append(isValidLeaf == null ? "null" : isValidLeaf.toString()).append("} ");
 			sb.append("}");
 
 			return sb;
@@ -1660,6 +1667,12 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 					* result
 					+ ((validationRegEx == null) ? 0 : validationRegEx
 							.hashCode());
+			result = prime
+					* result
+					+ ((accessTypeRestrictions == null) ? 0 : accessTypeRestrictions.hashCode());
+			result = prime
+					* result
+					+ ((isValidLeaf == null) ? 0 : isValidLeaf.hashCode());
 			return result;
 		}
 
@@ -1763,7 +1776,17 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 					return false;
 			} else if (!validationRegEx.equals(other.validationRegEx))
 				return false;
-			return true;
+			if (accessTypeRestrictions == null) {
+				if (other.accessTypeRestrictions != null)
+					return false;
+			} else if (!accessTypeRestrictions.equals(other.accessTypeRestrictions))
+				return false;
+            if (isValidLeaf == null) {
+                if (other.isValidLeaf != null)
+                    return false;
+            } else if (!isValidLeaf.equals(other.isValidLeaf))
+                return false;
+            return true;
 		}
 		
 	}
@@ -1777,12 +1800,11 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerAccessTypeDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long               itemId        = null;
-		private String             name          = null;
-		private String             label         = null;
-		private String             rbKeyLabel    = null;
-		private Collection<String> impliedGrants = null;
-
+		private Long               itemId;
+		private String             name;
+		private String             label;
+		private String             rbKeyLabel;
+		private Collection<String> impliedGrants;
 
 		public RangerAccessTypeDef() {
 			this(null, null, null, null, null);
@@ -1797,11 +1819,11 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		}
 
 		public RangerAccessTypeDef(RangerAccessTypeDef other) {
-			this.setItemId(other.getItemId());
-			this.setName(other.getName());
-			this.setLabel(other.getLabel());
-			this.setRbKeyLabel(other.getRbKeyLabel());
-			this.setImpliedGrants(other.getImpliedGrants());
+			setItemId(other.getItemId());
+			setName(other.getName());
+			setLabel(other.getLabel());
+			setRbKeyLabel(other.getRbKeyLabel());
+			setImpliedGrants(other.getImpliedGrants());
 		}
 
 		/**
@@ -1872,7 +1894,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 		 */
 		public void setImpliedGrants(Collection<String> impliedGrants) {
 			if(this.impliedGrants == null) {
-				this.impliedGrants = new ArrayList<String>();
+				this.impliedGrants = new ArrayList<>();
 			}
 
 			if(this.impliedGrants == impliedGrants) {
@@ -1882,9 +1904,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.impliedGrants.clear();
 
 			if(impliedGrants != null) {
-				for(String impliedGrant : impliedGrants) {
-					this.impliedGrants.add(impliedGrant);
-				}
+				this.impliedGrants.addAll(impliedGrants);
 			}
 		}
 
@@ -1982,19 +2002,18 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerPolicyConditionDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long                itemId                 = null;
-		private String              name                   = null;
-		private String              evaluator              = null;
-		private Map<String, String> evaluatorOptions       = null;
-		private String              validationRegEx        = null;
-		private String              validationMessage      = null;
-		private String              uiHint                 = null;
-		private String              label                  = null;
-		private String              description            = null;
-		private String              rbKeyLabel             = null;
-		private String              rbKeyDescription       = null;
-		private String              rbKeyValidationMessage = null;
-
+		private Long                itemId;
+		private String              name;
+		private String              evaluator;
+		private Map<String, String> evaluatorOptions;
+		private String              validationRegEx;
+		private String              validationMessage;
+		private String              uiHint;
+		private String              label;
+		private String              description;
+		private String              rbKeyLabel;
+		private String              rbKeyDescription;
+		private String              rbKeyValidationMessage;
 
 		public RangerPolicyConditionDef() {
 			this(null, null, null, null, null, null, null, null, null, null, null, null);
@@ -2338,11 +2357,10 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerContextEnricherDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long                itemId              = null;
-		private String              name            = null;
-		private String              enricher        = null;
-		private Map<String, String> enricherOptions = null;
-
+		private Long                itemId;
+		private String              name;
+		private String              enricher;
+		private Map<String, String> enricherOptions;
 
 		public RangerContextEnricherDef() {
 			this(null, null, null, null);
@@ -2519,7 +2537,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 		public void setMaskTypes(List<RangerDataMaskTypeDef> maskTypes) {
 			if(this.maskTypes == null) {
-				this.maskTypes = new ArrayList<RangerDataMaskTypeDef>();
+				this.maskTypes = new ArrayList<>();
 			}
 
 			if(this.maskTypes == maskTypes) {
@@ -2529,9 +2547,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.maskTypes.clear();
 
 			if(maskTypes != null) {
-				for(RangerDataMaskTypeDef maskType : maskTypes) {
-					this.maskTypes.add(maskType);
-				}
+				this.maskTypes.addAll(maskTypes);
 			}
 		}
 
@@ -2541,7 +2557,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 		public void setAccessTypes(List<RangerAccessTypeDef> accessTypes) {
 			if(this.accessTypes == null) {
-				this.accessTypes = new ArrayList<RangerAccessTypeDef>();
+				this.accessTypes = new ArrayList<>();
 			}
 
 			if(this.accessTypes == accessTypes) {
@@ -2551,9 +2567,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.accessTypes.clear();
 
 			if(accessTypes != null) {
-				for(RangerAccessTypeDef accessType : accessTypes) {
-					this.accessTypes.add(accessType);
-				}
+				this.accessTypes.addAll(accessTypes);
 			}
 		}
 
@@ -2563,7 +2577,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 		public void setResources(List<RangerResourceDef> resources) {
 			if(this.resources == null) {
-				this.resources = new ArrayList<RangerResourceDef>();
+				this.resources = new ArrayList<>();
 			}
 
 			if(this.resources == resources) {
@@ -2573,9 +2587,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.resources.clear();
 
 			if(resources != null) {
-				for(RangerResourceDef resource : resources) {
-					this.resources.add(resource);
-				}
+				this.resources.addAll(resources);
 			}
 		}
 
@@ -2673,15 +2685,14 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 	public static class RangerDataMaskTypeDef implements java.io.Serializable {
 		private static final long serialVersionUID = 1L;
 
-		private Long                itemId           = null;
-		private String              name             = null;
-		private String              label            = null;
-		private String              description      = null;
-		private String              transformer      = null;
-		private Map<String, String> dataMaskOptions  = null;
-		private String              rbKeyLabel       = null;
-		private String              rbKeyDescription = null;
-
+		private Long                itemId;
+		private String              name;
+		private String              label;
+		private String              description;
+		private String              transformer;
+		private Map<String, String> dataMaskOptions;
+		private String              rbKeyLabel;
+		private String              rbKeyDescription;
 
 		public RangerDataMaskTypeDef() {
 			this(null, null, null, null, null, null, null, null);
@@ -2836,6 +2847,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			sb.append("name={").append(name).append("} ");
 			sb.append("label={").append(label).append("} ");
 			sb.append("description={").append(description).append("} ");
+			sb.append("transformer={").append(transformer).append("} ");
 			sb.append("dataMaskOptions={").append(dataMaskOptions).append("} ");
 			sb.append("rbKeyLabel={").append(rbKeyLabel).append("} ");
 			sb.append("rbKeyDescription={").append(rbKeyDescription).append("} ");
@@ -2856,6 +2868,9 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			result = prime * result + ((name == null) ? 0 : name.hashCode());
 			result = prime * result
 					+ ((rbKeyLabel == null) ? 0 : rbKeyLabel.hashCode());
+			result = prime * result + ((description == null) ? 0 : description.hashCode());
+			result = prime * result + ((transformer == null) ? 0 : transformer.hashCode());
+			result = prime * result + ((rbKeyDescription == null) ? 0 : rbKeyDescription.hashCode());
 			return result;
 		}
 
@@ -2894,6 +2909,21 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 					return false;
 			} else if (!rbKeyLabel.equals(other.rbKeyLabel))
 				return false;
+			if (description == null) {
+				if (other.description != null)
+					return false;
+			} else if (!description.equals(other.description))
+				return false;
+			if (transformer == null) {
+				if (other.transformer != null)
+					return false;
+			} else if (!transformer.equals(other.transformer))
+				return false;
+			if (rbKeyDescription == null) {
+				if (other.rbKeyDescription != null)
+					return false;
+			} else if (!rbKeyDescription.equals(other.rbKeyDescription))
+				return false;
 			return true;
 		}
 	}
@@ -2931,7 +2961,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 		public void setAccessTypes(List<RangerAccessTypeDef> accessTypes) {
 			if(this.accessTypes == null) {
-				this.accessTypes = new ArrayList<RangerAccessTypeDef>();
+				this.accessTypes = new ArrayList<>();
 			}
 
 			if(this.accessTypes == accessTypes) {
@@ -2941,9 +2971,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.accessTypes.clear();
 
 			if(accessTypes != null) {
-				for(RangerAccessTypeDef accessType : accessTypes) {
-					this.accessTypes.add(accessType);
-				}
+				this.accessTypes.addAll(accessTypes);
 			}
 		}
 
@@ -2953,7 +2981,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 
 		public void setResources(List<RangerResourceDef> resources) {
 			if(this.resources == null) {
-				this.resources = new ArrayList<RangerResourceDef>();
+				this.resources = new ArrayList<>();
 			}
 
 			if(this.resources == resources) {
@@ -2963,9 +2991,7 @@ public class RangerServiceDef extends RangerBaseModelObject implements java.io.S
 			this.resources.clear();
 
 			if(resources != null) {
-				for(RangerResourceDef resource : resources) {
-					this.resources.add(resource);
-				}
+				this.resources.addAll(resources);
 			}
 		}
 
