@@ -52,7 +52,7 @@ public class RangerPolicyValidator extends RangerValidator {
 			LOG.debug(String.format("==> RangerPolicyValidator.validate(%s, %s, %s)", policy, action, isAdmin));
 		}
 
-		List<ValidationFailureDetails> failures = new ArrayList<ValidationFailureDetails>();
+		List<ValidationFailureDetails> failures = new ArrayList<>();
 		boolean valid = isValid(policy, action, isAdmin, failures);
 		String message = "";
 		try {
@@ -257,12 +257,14 @@ public class RangerPolicyValidator extends RangerValidator {
 			int policyType=policy.getPolicyType() == null ? RangerPolicy.POLICY_TYPE_ACCESS : policy.getPolicyType();
 			switch (policyType) {
 			case RangerPolicy.POLICY_TYPE_DATAMASK:
-				if (CollectionUtils.isNotEmpty(policy.getDataMaskPolicyItems()))
+				if (CollectionUtils.isNotEmpty(policy.getDataMaskPolicyItems())) {
 					policyItemsCount += policy.getDataMaskPolicyItems().size();
+				}
 				break;
 			case RangerPolicy.POLICY_TYPE_ROWFILTER:
-				if (CollectionUtils.isNotEmpty(policy.getRowFilterPolicyItems()))
+				if (CollectionUtils.isNotEmpty(policy.getRowFilterPolicyItems())) {
 					policyItemsCount += policy.getRowFilterPolicyItems().size();
+				}
 				break;
 			default:
 				if (CollectionUtils.isNotEmpty(policy.getPolicyItems())){
@@ -459,7 +461,18 @@ public class RangerPolicyValidator extends RangerValidator {
 		RangerServiceDefHelper defHelper = new RangerServiceDefHelper(serviceDef);
 		Set<List<RangerResourceDef>> hierarchies = defHelper.getResourceHierarchies(policy.getPolicyType()); // this can be empty but not null!
 		if (hierarchies.isEmpty()) {
-			LOG.warn("RangerPolicyValidator.isValidResourceNames: serviceDef does not have any resource hierarchies, possibly due to a old/migrated service def!  Skipping this check!");
+			if (LOG.isDebugEnabled()) {
+				LOG.debug("RangerPolicyValidator.isValidResourceNames: serviceDef does not have any resource hierarchies, possibly due to invalid service def!!");
+			}
+			ValidationErrorCode error = ValidationErrorCode.POLICY_VALIDATION_ERR_INVALID_RESOURCE_NO_COMPATIBLE_HIERARCHY;
+			failures.add(new ValidationFailureDetailsBuilder()
+					.field("service def resource hierarchies")
+					.subField("incompatible")
+					.isSemanticallyIncorrect()
+					.becauseOf(error.getMessage(serviceDef.getName(), " does not have any resource hierarchies"))
+					.errorCode(error.getErrorCode())
+					.build());
+			valid = false;
 		} else {
 			/*
 			 * A policy is for a single hierarchy however, it doesn't specify which one.  So we have to guess which hierarchy(s) it possibly be for.  First, see if the policy could be for
@@ -570,8 +583,7 @@ public class RangerPolicyValidator extends RangerValidator {
 		// helper function skipping sanity checks of getting null arguments passed
 		Set<List<RangerResourceDef>> result = new HashSet<List<RangerResourceDef>>(hierarchies.size());
 		for (List<RangerResourceDef> aHierarchy : hierarchies) {
-			Set<String> hierarchyResources = defHelper.getAllResourceNames(aHierarchy);
-			if (hierarchyResources.containsAll(policyResources)) {
+			if (defHelper.hierarchyHasAllResources(aHierarchy, policyResources)) {
 				result.add(aHierarchy);
 			}
 		}
@@ -697,7 +709,7 @@ public class RangerPolicyValidator extends RangerValidator {
 			RangerPolicyResource policyResource = entry.getValue();
 			if(policyResource != null) {
 				if(CollectionUtils.isNotEmpty(policyResource.getValues())) {
-					Set<String> resources = new HashSet<String>(policyResource.getValues());
+					Set<String> resources = new HashSet<>(policyResource.getValues());
 					for (String aValue : resources) {
 						if (StringUtils.isBlank(aValue)) {
 							policyResource.getValues().remove(aValue);
