@@ -44,6 +44,7 @@ import org.apache.ranger.plugin.store.ServiceStore;
 
 import com.google.common.collect.ImmutableSet;
 import com.google.common.collect.Sets;
+import org.apache.ranger.plugin.util.ServiceDefUtil;
 
 public class RangerServiceDefValidator extends RangerValidator {
 
@@ -58,8 +59,14 @@ public class RangerServiceDefValidator extends RangerValidator {
 			LOG.debug(String.format("==> RangerServiceDefValidator.validate(%s, %s)", serviceDef, action));
 		}
 
-		List<ValidationFailureDetails> failures = new ArrayList<ValidationFailureDetails>();
-		boolean valid = isValid(serviceDef, action, failures);
+		RangerServiceDef normalizedServiceDef = ServiceDefUtil.normalize(serviceDef);
+
+		if(LOG.isDebugEnabled()) {
+			LOG.debug(String.format("Normalized Service Definition being validated: (%s, %s)", serviceDef, action));
+		}
+
+		List<ValidationFailureDetails> failures = new ArrayList<>();
+		boolean valid = isValid(normalizedServiceDef, action, failures);
 		String message = "";
 		try {
 			if (!valid) {
@@ -68,7 +75,7 @@ public class RangerServiceDefValidator extends RangerValidator {
 			}
 		} finally {
 			if(LOG.isDebugEnabled()) {
-				LOG.debug(String.format("<== RangerServiceDefValidator.validate(%s, %s): %s, reason[%s]", serviceDef, action, valid, message));
+				LOG.debug(String.format("<== RangerServiceDefValidator.validate(%s, %s): %s, reason[%s]", normalizedServiceDef, action, valid, message));
 			}
 		}
 	}
@@ -247,9 +254,9 @@ public class RangerServiceDefValidator extends RangerValidator {
 				.build());
 			valid = false;
 		} else {
-			List<RangerAccessTypeDef> defsWithImpliedGrants = new ArrayList<RangerAccessTypeDef>();
-			Set<String> accessNames = new HashSet<String>();
-			Set<Long> ids = new HashSet<Long>();
+			List<RangerAccessTypeDef> defsWithImpliedGrants = new ArrayList<>();
+			Set<String> accessNames = new HashSet<>();
+			Set<Long> ids = new HashSet<>();
 			for (RangerAccessTypeDef def : accessTypeDefs) {
 				String name = def.getName();
 				valid = isUnique(name, accessNames, "access type name", "access types", failures) && valid;
@@ -304,8 +311,8 @@ public class RangerServiceDefValidator extends RangerValidator {
 		if (CollectionUtils.isEmpty(policyConditions)) {
 			LOG.debug("Configs collection was null/empty! ok");
 		} else {
-			Set<Long> ids = new HashSet<Long>();
-			Set<String> names = new HashSet<String>();
+			Set<Long> ids = new HashSet<>();
+			Set<String> names = new HashSet<>();
 			for (RangerPolicyConditionDef conditionDef : policyConditions) {
 				valid = isUnique(conditionDef.getItemId(), ids, "policy condition def itemId", "policy condition defs", failures) && valid;
 				String name = conditionDef.getName();
@@ -478,7 +485,7 @@ public class RangerServiceDefValidator extends RangerValidator {
 		}
 		return valid;
 	}
-	
+
 	boolean isValidResourceGraph(RangerServiceDef serviceDef, List<ValidationFailureDetails> failures) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug(String.format("==> RangerServiceDefValidator.isValidResourceGraph(%s, %s)", serviceDef, failures));
@@ -504,6 +511,26 @@ public class RangerServiceDefValidator extends RangerValidator {
 				for (RangerResourceDef resourceDef : aHierarchy) {
 					valid = isUnique(resourceDef.getLevel(), levels, "resource level", "resources", failures) && valid;
 				}
+
+				// Ensure that aHierarchy contains resource-defs with increasing level values
+				int lastResourceLevel = Integer.MIN_VALUE;
+				for (RangerResourceDef resourceDef : aHierarchy) {
+					Integer resourceDefLevel = resourceDef.getLevel();
+					if (resourceDefLevel == null || resourceDefLevel < lastResourceLevel) {
+						ValidationErrorCode error = ValidationErrorCode.SERVICE_DEF_VALIDATION_ERR_INVALID_SERVICE_RESOURCE_LEVELS;
+						failures.add(new ValidationFailureDetailsBuilder()
+								.field("resource level")
+								.subField(String.valueOf(resourceDefLevel))
+								.isSemanticallyIncorrect()
+								.errorCode(error.getErrorCode())
+								.becauseOf(error.getMessage())
+								.build());
+						valid = false;
+						break;
+					} else {
+						lastResourceLevel = resourceDef.getLevel();
+					}
+				}
 			}
 		}
 
@@ -512,7 +539,7 @@ public class RangerServiceDefValidator extends RangerValidator {
 		}
 		return valid;
 	}
-	
+
 	boolean isValidEnums(List<RangerEnumDef> enumDefs, List<ValidationFailureDetails> failures) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug(String.format("==> RangerServiceDefValidator.isValidEnums(%s, %s)", enumDefs, failures));
@@ -522,8 +549,8 @@ public class RangerServiceDefValidator extends RangerValidator {
 		if (CollectionUtils.isEmpty(enumDefs)) {
 			LOG.debug("enum def collection passed in was null/empty. Ok.");
 		} else {
-			Set<String> names = new HashSet<String>();
-			Set<Long> ids = new HashSet<Long>();
+			Set<String> names = new HashSet<>();
+			Set<Long> ids = new HashSet<>();
 			for (RangerEnumDef enumDef : enumDefs) {
 				if (enumDef == null) {
 					ValidationErrorCode error = ValidationErrorCode.SERVICE_DEF_VALIDATION_ERR_ENUM_DEF_NULL_OBJECT;
@@ -586,8 +613,8 @@ public class RangerServiceDefValidator extends RangerValidator {
 			LOG.debug("Enum elements list passed in was null/empty!");
 		} else {
 			// enum element names should be valid and distinct
-			Set<String> elementNames = new HashSet<String>();
-			Set<Long> ids = new HashSet<Long>();
+			Set<String> elementNames = new HashSet<>();
+			Set<Long> ids = new HashSet<>();
 			for (RangerEnumElementDef elementDef : enumElementsDefs) {
 				if (elementDef == null) {
 					ValidationErrorCode error = ValidationErrorCode.SERVICE_DEF_VALIDATION_ERR_ENUM_DEF_NULL_ENUM_ELEMENT;
