@@ -16,30 +16,44 @@
  * specific language governing permissions and limitations
  * under the License.
  */
-
 package org.apache.ranger.plugin.policyengine;
 
+import org.apache.commons.collections.MapUtils;
+import org.apache.commons.lang.StringUtils;
+import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.util.ServiceDefUtil;
 
+import java.util.HashMap;
+import java.util.Map;
 
 public class RangerAccessResult {
+	public final static String KEY_MASK_TYPE =      "maskType";
+	public final static String KEY_MASK_CONDITION = "maskCondition";
+	public final static String KEY_MASKED_VALUE =   "maskedValue";
+
+	private static String KEY_FILTER_EXPR = "filterExpr";
+
 	private final String              serviceName;
 	private final RangerServiceDef    serviceDef;
 	private final RangerAccessRequest request;
 
-	private boolean isAccessDetermined = false;
-	private boolean  isAllowed = false;
-	private boolean isAuditedDetermined = false;
-	private boolean  isAudited = false;
+	private final int policyType;  // Really, policy-type for audit purpose
+	private boolean isAccessDetermined;
+	private boolean  isAllowed;
+	private boolean isAuditedDetermined;
+	private boolean  isAudited;
 	private long     auditPolicyId  = -1;
 	private long     policyId  = -1;
-	private long     evaluatedPoliciesCount = 0;
-	private String   reason    = null;
+	private long     evaluatedPoliciesCount;
+	private String   reason;
+	private Map<String, Object> additionalInfo;
 
-	public RangerAccessResult(final String serviceName, final RangerServiceDef serviceDef, final RangerAccessRequest request) {
+	public RangerAccessResult(final int policyType, final String serviceName, final RangerServiceDef serviceDef, final RangerAccessRequest request) {
 		this.serviceName = serviceName;
 		this.serviceDef  = serviceDef;
 		this.request     = request;
+		this.policyType = policyType;
 		this.isAccessDetermined = false;
 		this.isAllowed   = false;
 		this.isAuditedDetermined = false;
@@ -56,13 +70,13 @@ public class RangerAccessResult {
 		this.policyId    = other.getPolicyId();
 		this.evaluatedPoliciesCount = other.evaluatedPoliciesCount;
 		this.reason      = other.getReason();
+		this.additionalInfo = other.additionalInfo == null ? new HashMap<String, Object>() : new HashMap<>(other.additionalInfo);
 	}
 
 	public void setAuditResultFrom(final RangerAccessResult other) {
 		this.isAuditedDetermined = other.getIsAuditedDetermined();
 		this.isAudited = other.getIsAudited();
 		this.auditPolicyId = other.getAuditPolicyId();
-		this.evaluatedPoliciesCount += other.getEvaluatedPoliciesCount();
 	}
 
 	/**
@@ -86,6 +100,8 @@ public class RangerAccessResult {
 		return request;
 	}
 
+	public int getPolicyType() { return policyType; }
+
 	public boolean getIsAccessDetermined() { return isAccessDetermined; }
 
 	public void setIsAccessDetermined(boolean value) { isAccessDetermined = value; }
@@ -184,6 +200,101 @@ public class RangerAccessResult {
 		return ret;
 	}
 
+	public void setAdditionalInfo(Map<String, Object> additionalInfo) {
+		this.additionalInfo = additionalInfo;
+	}
+
+	public Map<String, Object> getAdditionalInfo() {
+		return additionalInfo;
+	}
+
+	public void addAdditionalInfo(String key, Object value) {
+		if (additionalInfo == null) {
+			additionalInfo = new HashMap<String, Object>();
+		}
+		additionalInfo.put(key, value);
+	}
+
+	public void removeAdditionalInfo(String key) {
+		if (MapUtils.isNotEmpty(additionalInfo)) {
+			additionalInfo.remove(key);
+		}
+	}
+
+	/**
+	 * @return the maskType
+	 */
+	public String getMaskType() {
+		return additionalInfo == null ? null :  (String) additionalInfo.get(KEY_MASK_TYPE);
+	}
+
+	/**
+	 * @param maskType the maskType to set
+	 */
+	public void setMaskType(String maskType) {
+		addAdditionalInfo(KEY_MASK_TYPE, maskType);
+	}
+
+	/**
+	 * @return the maskCondition
+	 */
+	public String getMaskCondition() {
+		return additionalInfo == null ? null : (String) additionalInfo.get(KEY_MASK_CONDITION);
+	}
+
+	/**
+	 * @param maskCondition the maskCondition to set
+	 */
+	public void setMaskCondition(String maskCondition) {
+		addAdditionalInfo(KEY_MASK_CONDITION, maskCondition);
+	}
+
+	/**
+	 * @return the maskedValue
+	 */
+	public String getMaskedValue() {
+		return additionalInfo == null ? null : (String) additionalInfo.get(KEY_MASKED_VALUE);
+	}
+	/**
+	 * @param maskedValue the maskedValue to set
+	 */
+	public void setMaskedValue(String maskedValue) {
+		addAdditionalInfo(KEY_MASKED_VALUE, maskedValue);
+	}
+
+	public boolean isMaskEnabled() {
+		return StringUtils.isNotEmpty(this.getMaskType()) && !StringUtils.equalsIgnoreCase(this.getMaskType(), RangerPolicy.MASK_TYPE_NONE);
+	}
+
+	public RangerServiceDef.RangerDataMaskTypeDef getMaskTypeDef() {
+		RangerServiceDef.RangerDataMaskTypeDef ret = null;
+
+		String maskType = getMaskType();
+		if(StringUtils.isNotEmpty(maskType)) {
+			ret = ServiceDefUtil.getDataMaskType(getServiceDef(), maskType);
+		}
+
+		return ret;
+	}
+
+	/**
+	 * @return the filterExpr
+	 */
+	public String getFilterExpr() {
+		return additionalInfo == null ? null : (String) additionalInfo.get(KEY_FILTER_EXPR);
+	}
+
+	/**
+	 * @param filterExpr the filterExpr to set
+	 */
+	public void setFilterExpr(String filterExpr) {
+		addAdditionalInfo(KEY_FILTER_EXPR, filterExpr);
+	}
+
+	public boolean isRowFilterEnabled() {
+		return StringUtils.isNotEmpty(getFilterExpr());
+	}
+
 	@Override
 	public String toString( ) {
 		StringBuilder sb = new StringBuilder();
@@ -198,12 +309,20 @@ public class RangerAccessResult {
 
         sb.append("isAccessDetermined={").append(isAccessDetermined).append("} ");
 		sb.append("isAllowed={").append(isAllowed).append("} ");
-        sb.append("isAuditedDetermined={").append(isAuditedDetermined).append("} ");
-        sb.append("isAudited={").append(isAudited).append("} ");
+		sb.append("isAuditedDetermined={").append(isAuditedDetermined).append("} ");
+		sb.append("isAudited={").append(isAudited).append("} ");
+		sb.append("policyType={").append(policyType).append("} ");
 		sb.append("policyId={").append(policyId).append("} ");
 		sb.append("auditPolicyId={").append(auditPolicyId).append("} ");
 		sb.append("evaluatedPoliciesCount={").append(evaluatedPoliciesCount).append("} ");
 		sb.append("reason={").append(reason).append("} ");
+		sb.append("additionalInfo={");
+		if (additionalInfo != null) {
+			for (Map.Entry<String, Object> entry : additionalInfo.entrySet()) {
+				sb.append(entry.getKey()).append("=").append(entry.getValue()).append(", ");
+			}
+		}
+		sb.append("}");
 
 		sb.append("}");
 
