@@ -25,8 +25,12 @@ import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.authorization.hadoop.config.RangerConfiguration;
 import org.apache.ranger.plugin.contextenricher.RangerContextEnricher;
+import org.apache.ranger.plugin.contextenricher.RangerTagEnricher;
+import org.apache.ranger.plugin.contextenricher.RangerTagForEval;
 import org.apache.ranger.plugin.model.RangerPolicy;
+import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemDataMaskInfo;
 import org.apache.ranger.plugin.model.RangerServiceDef;
+import org.apache.ranger.plugin.model.validation.RangerServiceDefHelper;
 import org.apache.ranger.plugin.policyevaluator.RangerCachedPolicyEvaluator;
 import org.apache.ranger.plugin.policyevaluator.RangerOptimizedPolicyEvaluator;
 import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
@@ -58,9 +62,6 @@ class RangerPolicyRepository {
         final boolean isAudited;
         final long    auditPolicyId;
 
-        AuditInfo() {
-            this(false, -1);
-        }
         AuditInfo(boolean isAudited, long auditPolicyId) {
             this.isAudited = isAudited;
             this.auditPolicyId = auditPolicyId;
@@ -194,59 +195,188 @@ class RangerPolicyRepository {
         }
     }
 
-    public String getServiceName() { return serviceName; }
+    @Override
+    public String toString( ) {
+        StringBuilder sb = new StringBuilder();
 
-    public RangerServiceDef getServiceDef() {
+        toString(sb);
+
+        return sb.toString();
+    }
+
+    void reorderPolicyEvaluators() {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("==> reorderEvaluators()");
+        }
+
+        if(policyResourceTrie == null) {
+            policyEvaluators = getReorderedPolicyEvaluators(policyEvaluators);
+        }
+
+        if(dataMaskResourceTrie == null) {
+            dataMaskPolicyEvaluators = getReorderedPolicyEvaluators(dataMaskPolicyEvaluators);
+        }
+
+        if(rowFilterResourceTrie == null) {
+            rowFilterPolicyEvaluators = getReorderedPolicyEvaluators(rowFilterPolicyEvaluators);
+        }
+
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("<== reorderEvaluators()");
+        }
+    }
+
+    String getServiceName() { return serviceName; }
+
+    RangerServiceDef getServiceDef() {
         return serviceDef;
     }
 
-    public List<RangerPolicy> getPolicies() {
+    List<RangerPolicy> getPolicies() {
         return policies;
     }
 
-    public long getPolicyVersion() {
+    long getPolicyVersion() {
         return policyVersion;
     }
 
-    public List<RangerContextEnricher> getContextEnrichers() { return contextEnrichers; }
+    AuditModeEnum getAuditModeEnum() { return auditModeEnum; }
+
+    boolean setAuditEnabledFromCache(RangerAccessRequest request, RangerAccessResult result) {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("==> RangerPolicyRepository.setAuditEnabledFromCache()");
+        }
+
+        final AuditInfo auditInfo = accessAuditCache != null ? accessAuditCache.get(request.getResource().getAsString()) : null;
+
+        if (auditInfo != null) {
+            result.setIsAudited(auditInfo.getIsAudited());
+            result.setAuditPolicyId(auditInfo.getAuditPolicyId());
+        }
+
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("<== RangerPolicyRepository.setAuditEnabledFromCache():" + (auditInfo != null));
+        }
+
+        return auditInfo != null;
+    }
+
+    void storeAuditEnabledInCache(RangerAccessRequest request, RangerAccessResult result) {
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("==> RangerPolicyRepository.storeAuditEnabledInCache()");
+        }
+
+        if (accessAuditCache != null && result.getIsAuditedDetermined()) {
+            accessAuditCache.put(request.getResource().getAsString(), new AuditInfo(result.getIsAudited(), result.getAuditPolicyId()));
+        }
+
+        if (LOG.isDebugEnabled()) {
+            LOG.debug("<== RangerPolicyRepository.storeAuditEnabledInCache()");
+        }
+    }
+
+    List<RangerContextEnricher> getContextEnrichers() { return contextEnrichers; }
 
     List<RangerPolicyEvaluator> getPolicyEvaluators() {
         return policyEvaluators;
     }
 
-    List<RangerPolicyEvaluator> getPolicyEvaluators(RangerAccessResource resource) {
-       String resourceStr = resource == null ? null : resource.getAsString();
-
-       return policyResourceTrie == null || StringUtils.isEmpty(resourceStr)  ? getPolicyEvaluators() : getPolicyEvaluators(policyResourceTrie, resource);
-    }
-
     List<RangerPolicyEvaluator> getDataMaskPolicyEvaluators() {
         return dataMaskPolicyEvaluators;
     }
 
-    List<RangerPolicyEvaluator> getDataMaskPolicyEvaluators(RangerAccessResource resource) {
-        String resourceStr = resource == null ? null : resource.getAsString();
-
-        return dataMaskResourceTrie == null || StringUtils.isEmpty(resourceStr)  ? getDataMaskPolicyEvaluators() : getPolicyEvaluators(dataMaskResourceTrie, resource);
-    }
-
     List<RangerPolicyEvaluator> getRowFilterPolicyEvaluators() {
         return rowFilterPolicyEvaluators;
     }
 
-    List<RangerPolicyEvaluator> getRowFilterPolicyEvaluators(RangerAccessResource resource) {
+    List<PolicyEvaluatorForTag> getLikelyMatchPolicyEvaluators(Set<RangerTagForEval> tags, int policyType) {
+        List<PolicyEvaluatorForTag> ret = Collections.EMPTY_LIST;
+
+        if (CollectionUtils.isNotEmpty(tags) && getServiceDef() != null) {
+
+            ret = new ArrayList<PolicyEvaluatorForTag>();
+
+            for (RangerTagForEval tag : tags) {
+                RangerAccessResource resource = new RangerTagResource(tag.getType(), getServiceDef());
+                List<RangerPolicyEvaluator> evaluators = getLikelyMatchPolicyEvaluators(resource, policyType);
+
+                if (CollectionUtils.isNotEmpty(evaluators)) {
+                    for (RangerPolicyEvaluator evaluator : evaluators) {
+                        ret.add(new PolicyEvaluatorForTag(evaluator, tag));
+                    }
+                }
+            }
+
+            if (CollectionUtils.isNotEmpty(ret)) {
+                switch(policyType) {
+                    case RangerPolicy.POLICY_TYPE_ACCESS:
+                        Collections.sort(ret, new PolicyEvaluatorForTag.PolicyEvalOrderComparator());
+                        break;
+                    case RangerPolicy.POLICY_TYPE_DATAMASK:
+                        Collections.sort(ret, new PolicyEvaluatorForTag.PolicyNameComparator());
+                        break;
+                    case RangerPolicy.POLICY_TYPE_ROWFILTER:
+                        Collections.sort(ret, new PolicyEvaluatorForTag.PolicyNameComparator());
+                        break;
+                    default:
+                        LOG.warn("Unknown policy-type:[" + policyType + "]. Ignoring..");
+                        break;
+                }
+            }
+        }
+        return ret;
+    }
+
+    List<RangerPolicyEvaluator> getLikelyMatchPolicyEvaluators(RangerAccessResource resource) {
+        List<RangerPolicyEvaluator> ret = new ArrayList<>();
+
+        for (int policyType : RangerPolicy.POLICY_TYPES) {
+            List<RangerPolicyEvaluator> evaluators = getLikelyMatchPolicyEvaluators(resource, policyType);
+            if (CollectionUtils.isNotEmpty(evaluators)) {
+                ret.addAll(evaluators);
+            }
+        }
+        return ret;
+    }
+
+    List<RangerPolicyEvaluator> getLikelyMatchPolicyEvaluators(RangerAccessResource resource, int policyType) {
+        switch(policyType) {
+            case RangerPolicy.POLICY_TYPE_ACCESS:
+                return getLikelyMatchAccessPolicyEvaluators(resource);
+            case RangerPolicy.POLICY_TYPE_DATAMASK:
+                return getLikelyMatchDataMaskPolicyEvaluators(resource);
+            case RangerPolicy.POLICY_TYPE_ROWFILTER:
+                return getLikelyMatchRowFilterPolicyEvaluators(resource);
+            default:
+                return Collections.EMPTY_LIST;
+        }
+    }
+
+    private List<RangerPolicyEvaluator> getLikelyMatchAccessPolicyEvaluators(RangerAccessResource resource) {
+       String resourceStr = resource == null ? null : resource.getAsString();
+
+       return policyResourceTrie == null || StringUtils.isEmpty(resourceStr)  ? getPolicyEvaluators() : getLikelyMatchPolicyEvaluators(policyResourceTrie, resource);
+    }
+
+    private List<RangerPolicyEvaluator> getLikelyMatchDataMaskPolicyEvaluators(RangerAccessResource resource) {
         String resourceStr = resource == null ? null : resource.getAsString();
 
-        return rowFilterResourceTrie == null || StringUtils.isEmpty(resourceStr)  ? getRowFilterPolicyEvaluators() : getPolicyEvaluators(rowFilterResourceTrie, resource);
+        return dataMaskResourceTrie == null || StringUtils.isEmpty(resourceStr)  ? getDataMaskPolicyEvaluators() : getLikelyMatchPolicyEvaluators(dataMaskResourceTrie, resource);
     }
-    AuditModeEnum getAuditModeEnum() { return auditModeEnum; }
 
-    private List<RangerPolicyEvaluator> getPolicyEvaluators(Map<String, RangerResourceTrie> resourceTrie, RangerAccessResource resource) {
+    private List<RangerPolicyEvaluator> getLikelyMatchRowFilterPolicyEvaluators(RangerAccessResource resource) {
+        String resourceStr = resource == null ? null : resource.getAsString();
+
+        return rowFilterResourceTrie == null || StringUtils.isEmpty(resourceStr)  ? getRowFilterPolicyEvaluators() : getLikelyMatchPolicyEvaluators(rowFilterResourceTrie, resource);
+    }
+
+    private List<RangerPolicyEvaluator> getLikelyMatchPolicyEvaluators(Map<String, RangerResourceTrie> resourceTrie, RangerAccessResource resource) {
         List<RangerPolicyEvaluator> ret          = null;
         Set<String>                 resourceKeys = resource == null ? null : resource.getKeys();
 
         if(CollectionUtils.isNotEmpty(resourceKeys)) {
-            boolean isRetModifiable = false;
+            List<List<RangerPolicyEvaluator>> resourceEvaluatorsList = null;
+            List<RangerPolicyEvaluator> smallestList = null;
 
             for(String resourceName : resourceKeys) {
                 RangerResourceTrie trie = resourceTrie.get(resourceName);
@@ -258,34 +388,41 @@ class RangerPolicyRepository {
                 List<RangerPolicyEvaluator> resourceEvaluators = trie.getEvaluatorsForResource(resource.getValue(resourceName));
 
                 if(CollectionUtils.isEmpty(resourceEvaluators)) { // no policies for this resource, bail out
-                    ret = null;
-                } else if(ret == null) { // initialize ret with policies found for this resource
-                    ret = resourceEvaluators;
-                } else { // remove policies from ret that are not in resourceEvaluators
-                    if(isRetModifiable) {
-                        ret.retainAll(resourceEvaluators);
-                    } else {
-                        final List<RangerPolicyEvaluator> shorterList;
-                        final List<RangerPolicyEvaluator> longerList;
-
-                        if (ret.size() < resourceEvaluators.size()) {
-                            shorterList = ret;
-                            longerList  = resourceEvaluators;
-                        } else {
-                            shorterList = resourceEvaluators;
-                            longerList  = ret;
-                        }
-
-                        ret = new ArrayList<>(shorterList);
-                        ret.retainAll(longerList);
-                        isRetModifiable = true;
-                    }
-                }
-
-                if(CollectionUtils.isEmpty(ret)) { // if no policy exists, bail out and return empty list
-                    ret = null;
+                    resourceEvaluatorsList = null;
+                    smallestList = null;
                     break;
                 }
+
+                if (smallestList == null) {
+                    smallestList = resourceEvaluators;
+                } else {
+                    if (resourceEvaluatorsList == null) {
+                        resourceEvaluatorsList = new ArrayList<>();
+                        resourceEvaluatorsList.add(smallestList);
+                    }
+                    resourceEvaluatorsList.add(resourceEvaluators);
+
+                    if (smallestList.size() > resourceEvaluators.size()) {
+                        smallestList = resourceEvaluators;
+                    }
+                }
+            }
+
+            if (resourceEvaluatorsList != null) {
+                ret = new ArrayList<>(smallestList);
+                for (List<RangerPolicyEvaluator> resourceEvaluators : resourceEvaluatorsList) {
+                    if (resourceEvaluators != smallestList) {
+                        // remove policies from ret that are not in resourceEvaluators
+                        ret.retainAll(resourceEvaluators);
+
+                        if (CollectionUtils.isEmpty(ret)) { // if no policy exists, bail out and return empty list
+                            ret = null;
+                            break;
+                        }
+                    }
+                }
+            } else {
+                ret = smallestList;
             }
         }
 
@@ -294,7 +431,7 @@ class RangerPolicyRepository {
         }
 
         if(LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerPolicyRepository.getPolicyEvaluators(" + resource.getAsString() + "): evaluatorCount=" + ret.size());
+            LOG.debug("<== RangerPolicyRepository.getLikelyMatchPolicyEvaluators(" + resource.getAsString() + "): evaluatorCount=" + ret.size());
         }
 
         return ret;
@@ -335,7 +472,7 @@ class RangerPolicyRepository {
                                     String newImpliedGrant = StringUtils.removeStart(impliedGrant, prefix);
 
                                     if (newImpliedGrants == null) {
-                                        newImpliedGrants = new ArrayList<String>();
+                                        newImpliedGrants = new ArrayList<>();
                                     }
 
                                     newImpliedGrants.add(newImpliedGrant);
@@ -346,7 +483,7 @@ class RangerPolicyRepository {
                         }
                     } else if (StringUtils.contains(accessType, AbstractServiceStore.COMPONENT_ACCESSTYPE_SEPARATOR)) {
                         if(unneededAccessTypeDefs == null) {
-                            unneededAccessTypeDefs = new ArrayList<RangerServiceDef.RangerAccessTypeDef>();
+                            unneededAccessTypeDefs = new ArrayList<>();
                         }
 
                         unneededAccessTypeDefs.add(accessTypeDef);
@@ -383,7 +520,7 @@ class RangerPolicyRepository {
                     CollectionUtils.isEmpty(policy.getRowFilterPolicyItems())) {
 
                     if(policiesToPrune == null) {
-                        policiesToPrune = new ArrayList<RangerPolicy>();
+                        policiesToPrune = new ArrayList<>();
                     }
 
                     policiesToPrune.add(policy);
@@ -391,7 +528,7 @@ class RangerPolicyRepository {
             }
 
             if(policiesToPrune != null) {
-	            rangerPolicies.removeAll(policiesToPrune);
+                rangerPolicies.removeAll(policiesToPrune);
             }
         }
 
@@ -418,7 +555,7 @@ class RangerPolicyRepository {
                             access.setType(newAccessType);
                         } else if (accessType.contains(AbstractServiceStore.COMPONENT_ACCESSTYPE_SEPARATOR)) {
                             if(accessesToPrune == null) {
-                                accessesToPrune = new ArrayList<RangerPolicy.RangerPolicyItemAccess>();
+                                accessesToPrune = new ArrayList<>();
                             }
 
                             accessesToPrune.add(access);
@@ -426,12 +563,29 @@ class RangerPolicyRepository {
                     }
 
                     if(accessesToPrune != null) {
-	                    policyItemAccesses.removeAll(accessesToPrune);
+                        policyItemAccesses.removeAll(accessesToPrune);
                     }
 
                     if (policyItemAccesses.isEmpty() && !policyItem.getDelegateAdmin()) {
                         if(itemsToPrune == null) {
-                            itemsToPrune = new ArrayList< RangerPolicy.RangerPolicyItem>();
+                            itemsToPrune = new ArrayList<>();
+                        }
+
+                        itemsToPrune.add(policyItem);
+
+                        continue;
+                    }
+                }
+
+                if (policyItem instanceof RangerPolicy.RangerDataMaskPolicyItem) {
+                    RangerPolicyItemDataMaskInfo dataMaskInfo = ((RangerPolicy.RangerDataMaskPolicyItem) policyItem).getDataMaskInfo();
+                    String                       maskType     = dataMaskInfo.getDataMaskType();
+
+                    if (StringUtils.startsWith(maskType, prefix)) {
+                        dataMaskInfo.setDataMaskType(StringUtils.removeStart(maskType, prefix));
+                    } else if (maskType.contains(AbstractServiceStore.COMPONENT_ACCESSTYPE_SEPARATOR)) {
+                        if (itemsToPrune == null) {
+                            itemsToPrune = new ArrayList<>();
                         }
 
                         itemsToPrune.add(policyItem);
@@ -440,7 +594,7 @@ class RangerPolicyRepository {
             }
 
             if(itemsToPrune != null) {
-	            policyItems.removeAll(itemsToPrune);
+                policyItems.removeAll(itemsToPrune);
             }
         }
 
@@ -482,10 +636,12 @@ class RangerPolicyRepository {
     }
 
     private void init(RangerPolicyEngineOptions options) {
+        RangerServiceDefHelper serviceDefHelper = new RangerServiceDefHelper(serviceDef, false);
+        options.setServiceDefHelper(serviceDefHelper);
 
-        List<RangerPolicyEvaluator> policyEvaluators = new ArrayList<RangerPolicyEvaluator>();
-        List<RangerPolicyEvaluator> dataMaskPolicyEvaluators  = new ArrayList<RangerPolicyEvaluator>();
-        List<RangerPolicyEvaluator> rowFilterPolicyEvaluators = new ArrayList<RangerPolicyEvaluator>();
+        List<RangerPolicyEvaluator> policyEvaluators = new ArrayList<>();
+        List<RangerPolicyEvaluator> dataMaskPolicyEvaluators  = new ArrayList<>();
+        List<RangerPolicyEvaluator> rowFilterPolicyEvaluators = new ArrayList<>();
 
         for (RangerPolicy policy : policies) {
             if (skipBuildingPolicyEvaluator(policy, options)) {
@@ -506,27 +662,37 @@ class RangerPolicyRepository {
                 }
             }
         }
-        Collections.sort(policyEvaluators);
+        RangerPolicyEvaluator.PolicyEvalOrderComparator comparator = new RangerPolicyEvaluator.PolicyEvalOrderComparator();
+        Collections.sort(policyEvaluators, comparator);
         this.policyEvaluators = Collections.unmodifiableList(policyEvaluators);
 
-        Collections.sort(dataMaskPolicyEvaluators);
+        Collections.sort(dataMaskPolicyEvaluators, comparator);
         this.dataMaskPolicyEvaluators = Collections.unmodifiableList(dataMaskPolicyEvaluators);
 
-        Collections.sort(rowFilterPolicyEvaluators);
+        Collections.sort(rowFilterPolicyEvaluators, comparator);
         this.rowFilterPolicyEvaluators = Collections.unmodifiableList(rowFilterPolicyEvaluators);
 
         List<RangerContextEnricher> contextEnrichers = new ArrayList<RangerContextEnricher>();
-        if (CollectionUtils.isNotEmpty(this.policyEvaluators)) {
-            if (!options.disableContextEnrichers && !CollectionUtils.isEmpty(serviceDef.getContextEnrichers())) {
+        if (CollectionUtils.isNotEmpty(this.policyEvaluators) || CollectionUtils.isNotEmpty(this.dataMaskPolicyEvaluators)
+                || CollectionUtils.isNotEmpty(this.rowFilterPolicyEvaluators)) {
+            if (CollectionUtils.isNotEmpty(serviceDef.getContextEnrichers())) {
                 for (RangerServiceDef.RangerContextEnricherDef enricherDef : serviceDef.getContextEnrichers()) {
                     if (enricherDef == null) {
                         continue;
                     }
+                    if (!options.disableContextEnrichers || options.enableTagEnricherWithLocalRefresher && StringUtils.equals(enricherDef.getEnricher(), RangerTagEnricher.class.getName())) {
+                        // This will be true only if the engine is initialized within ranger-admin
+                        RangerServiceDef.RangerContextEnricherDef contextEnricherDef = enricherDef;
 
-                    RangerContextEnricher contextEnricher = buildContextEnricher(enricherDef);
+                        if (options.enableTagEnricherWithLocalRefresher && StringUtils.equals(enricherDef.getEnricher(), RangerTagEnricher.class.getName())) {
+                            contextEnricherDef = new RangerServiceDef.RangerContextEnricherDef(enricherDef.getItemId(), enricherDef.getName(), "org.apache.ranger.common.RangerAdminTagEnricher", null);
+                        }
 
-                    if (contextEnricher != null) {
-                        contextEnrichers.add(contextEnricher);
+                        RangerContextEnricher contextEnricher = buildContextEnricher(contextEnricherDef);
+
+                        if (contextEnricher != null) {
+                            contextEnrichers.add(contextEnricher);
+                        }
                     }
                 }
             }
@@ -551,7 +717,7 @@ class RangerPolicyRepository {
                 LOG.debug("dataMask policy evaluation order: #" + (++order) + " - policy id=" + policy.getId() + "; name=" + policy.getName() + "; evalOrder=" + policyEvaluator.getEvalOrder());
             }
 
-            LOG.debug("rowFilter policy evaluation order: " + this.dataMaskPolicyEvaluators.size() + " policies");
+            LOG.debug("rowFilter policy evaluation order: " + this.rowFilterPolicyEvaluators.size() + " policies");
             order = 0;
             for(RangerPolicyEvaluator policyEvaluator : this.rowFilterPolicyEvaluators) {
                 RangerPolicy policy = policyEvaluator.getPolicy();
@@ -627,39 +793,6 @@ class RangerPolicyRepository {
         return ret;
     }
 
-    boolean setAuditEnabledFromCache(RangerAccessRequest request, RangerAccessResult result) {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerPolicyRepository.setAuditEnabledFromCache()");
-        }
-
-        final AuditInfo auditInfo = accessAuditCache != null ? accessAuditCache.get(request.getResource().getAsString()) : null;
-
-        if (auditInfo != null) {
-            result.setIsAudited(auditInfo.getIsAudited());
-            result.setAuditPolicyId(auditInfo.getAuditPolicyId());
-        }
-
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerPolicyRepository.setAuditEnabledFromCache():" + (auditInfo != null));
-        }
-
-        return auditInfo != null;
-    }
-
-     void storeAuditEnabledInCache(RangerAccessRequest request, RangerAccessResult result) {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("==> RangerPolicyRepository.storeAuditEnabledInCache()");
-        }
-
-        if (accessAuditCache != null && result.getIsAuditedDetermined()) {
-            accessAuditCache.put(request.getResource().getAsString(), new AuditInfo(result.getIsAudited(), result.getAuditPolicyId()));
-        }
-
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("<== RangerPolicyRepository.storeAuditEnabledInCache()");
-        }
-    }
-
     private boolean scrubPolicy(RangerPolicy policy) {
         if (LOG.isDebugEnabled()) {
             LOG.debug("==> RangerPolicyRepository.scrubPolicy(" + policy + ")");
@@ -721,53 +854,12 @@ class RangerPolicyRepository {
         }
     }
 
-    void reorderPolicyEvaluators() {
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("==> reorderEvaluators()");
-        }
-
-        if(policyResourceTrie != null) {
-            reorderPolicyEvaluators(policyResourceTrie);
-        } else {
-            policyEvaluators = getReorderedPolicyEvaluators(policyEvaluators);
-        }
-
-        if(dataMaskResourceTrie != null) {
-            reorderPolicyEvaluators(dataMaskResourceTrie);
-        } else {
-            dataMaskPolicyEvaluators = getReorderedPolicyEvaluators(dataMaskPolicyEvaluators);
-        }
-
-        if(rowFilterResourceTrie != null) {
-            reorderPolicyEvaluators(rowFilterResourceTrie);
-        } else {
-            rowFilterPolicyEvaluators = getReorderedPolicyEvaluators(rowFilterPolicyEvaluators);
-        }
-
-        if (LOG.isDebugEnabled()) {
-            LOG.debug("<== reorderEvaluators()");
-        }
-    }
-
-    private void reorderPolicyEvaluators(Map<String, RangerResourceTrie> trieMap) {
-        if(trieMap != null) {
-            for(Map.Entry<String, RangerResourceTrie> entry : trieMap.entrySet()) {
-                RangerResourceTrie trie = entry.getValue();
-
-                if(trie != null) {
-                    trie.reorderEvaluators();
-                }
-            }
-        }
-    }
-
     private List<RangerPolicyEvaluator> getReorderedPolicyEvaluators(List<RangerPolicyEvaluator> evaluators) {
         List<RangerPolicyEvaluator> ret = evaluators;
 
         if (CollectionUtils.isNotEmpty(evaluators)) {
-
-            ret = new ArrayList<RangerPolicyEvaluator>(evaluators);
-            Collections.sort(ret);
+            ret = new ArrayList<>(evaluators);
+            Collections.sort(ret, new RangerPolicyEvaluator.PolicyEvalOrderComparator());
 
             ret = Collections.unmodifiableList(ret);
         }
@@ -779,10 +871,10 @@ class RangerPolicyRepository {
         final Map<String, RangerResourceTrie> ret;
 
         if (CollectionUtils.isNotEmpty(evaluators) && serviceDef != null && CollectionUtils.isNotEmpty(serviceDef.getResources())) {
-            ret = new HashMap<String, RangerResourceTrie>();
+            ret = new HashMap<>();
 
             for (RangerServiceDef.RangerResourceDef resourceDef : serviceDef.getResources()) {
-                ret.put(resourceDef.getName(), new RangerResourceTrie(resourceDef, evaluators));
+                ret.put(resourceDef.getName(), new RangerResourceTrie(resourceDef, evaluators, RangerPolicyEvaluator.EVAL_ORDER_COMPARATOR));
             }
         } else {
             ret = null;
@@ -791,16 +883,7 @@ class RangerPolicyRepository {
         return ret;
     }
 
-    @Override
-    public String toString( ) {
-        StringBuilder sb = new StringBuilder();
-
-        toString(sb);
-
-        return sb.toString();
-    }
-
-    public StringBuilder toString(StringBuilder sb) {
+    private StringBuilder toString(StringBuilder sb) {
 
         sb.append("RangerPolicyRepository={");
 
@@ -816,6 +899,32 @@ class RangerPolicyRepository {
                 }
             }
         }
+        sb.append("} ");
+
+        sb.append("dataMaskPolicyEvaluators={");
+
+        if (this.dataMaskPolicyEvaluators != null) {
+            for (RangerPolicyEvaluator policyEvaluator : dataMaskPolicyEvaluators) {
+                if (policyEvaluator != null) {
+                    sb.append(policyEvaluator).append(" ");
+                }
+            }
+        }
+        sb.append("} ");
+
+        sb.append("rowFilterPolicyEvaluators={");
+
+        if (this.rowFilterPolicyEvaluators != null) {
+            for (RangerPolicyEvaluator policyEvaluator : rowFilterPolicyEvaluators) {
+                if (policyEvaluator != null) {
+                    sb.append(policyEvaluator).append(" ");
+                }
+            }
+        }
+        sb.append("} ");
+
+        sb.append("contextEnrichers={");
+
         if (contextEnrichers != null) {
             for (RangerContextEnricher contextEnricher : contextEnrichers) {
                 if (contextEnricher != null) {
@@ -823,6 +932,7 @@ class RangerPolicyRepository {
                 }
             }
         }
+        sb.append("} ");
 
         sb.append("} ");
 
