@@ -28,7 +28,6 @@ import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
-import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceEvaluator;
 import org.apache.ranger.plugin.util.ServiceDefUtil;
 
 import java.util.Map;
@@ -36,11 +35,11 @@ import java.util.Map;
 public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvaluator {
 	private static final Log LOG = LogFactory.getLog(RangerAbstractPolicyEvaluator.class);
 
-	private RangerPolicy     policy            = null;
-	private RangerServiceDef serviceDef        = null;
-	private Integer          leafResourceLevel = null;
-	private int              evalOrder         = 0;
-	protected long           usageCount        = 0;
+	private RangerPolicy     policy;
+	private RangerServiceDef serviceDef;
+	private Integer          leafResourceLevel;
+	private int              evalOrder;
+	protected long           usageCount;
 	protected boolean        usageCountMutable = true;
 
 
@@ -110,38 +109,6 @@ public abstract class RangerAbstractPolicyEvaluator implements RangerPolicyEvalu
 		return policy != null && policy.getIsAuditEnabled();
 	}
 
-	@Override
-	public int compareTo(RangerPolicyResourceEvaluator obj) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerAbstractPolicyEvaluator.compareTo()");
-		}
-
-		int result;
-
-		if(obj instanceof RangerPolicyEvaluator) {
-			RangerPolicyEvaluator other = (RangerPolicyEvaluator)obj;
-
-			if (hasDeny() && !other.hasDeny()) {
-				result = -1;
-			} else if (!hasDeny() && other.hasDeny()) {
-				result = 1;
-			} else {
-				result = Long.compare(other.getUsageCount(), this.usageCount);
-				if (result == 0) {
-					result = Integer.compare(this.evalOrder, other.getEvalOrder());
-				}
-			}
-		} else {
-			result = Long.compare(getId(), obj.getId());
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerAbstractPolicyEvaluator.compareTo(), result:" + result);
-		}
-
-		return result;
-	}
-
 	public void setEvalOrder(int evalOrder) {
 		this.evalOrder = evalOrder;
 	}
