@@ -36,8 +36,6 @@ import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerDataMaskPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItem;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemAccess;
-import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemDataMaskInfo;
-import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItemRowFilterInfo;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyResource;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerRowFilterPolicyItem;
 import org.apache.ranger.plugin.model.RangerServiceDef;
@@ -45,10 +43,8 @@ import org.apache.ranger.plugin.model.RangerServiceDef.RangerAccessTypeDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessResource;
 import org.apache.ranger.plugin.policyengine.RangerAccessResult;
-import org.apache.ranger.plugin.policyengine.RangerDataMaskResult;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
 import org.apache.ranger.plugin.policyengine.RangerResourceAccessInfo;
-import org.apache.ranger.plugin.policyengine.RangerRowFilterResult;
 import org.apache.ranger.plugin.policyengine.RangerTagAccessRequest;
 import org.apache.ranger.plugin.policyresourcematcher.RangerDefaultPolicyResourceMatcher;
 import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher;
@@ -64,18 +60,18 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 	private static final Log PERF_POLICY_INIT_LOG = RangerPerfTracer.getPerfLogger("policy.init");
 	private static final Log PERF_POLICY_REQUEST_LOG = RangerPerfTracer.getPerfLogger("policy.request");
 
-	private RangerPolicyResourceMatcher     resourceMatcher          = null;
-	private List<RangerPolicyItemEvaluator> allowEvaluators          = null;
-	private List<RangerPolicyItemEvaluator> denyEvaluators           = null;
-	private List<RangerPolicyItemEvaluator> allowExceptionEvaluators = null;
-	private List<RangerPolicyItemEvaluator> denyExceptionEvaluators  = null;
-	private int                             customConditionsCount    = 0;
-	private List<RangerDataMaskPolicyItemEvaluator>  dataMaskEvaluators  = null;
-	private List<RangerRowFilterPolicyItemEvaluator> rowFilterEvaluators = null;
+	private RangerPolicyResourceMatcher     resourceMatcher;
+	private List<RangerPolicyItemEvaluator> allowEvaluators;
+	private List<RangerPolicyItemEvaluator> denyEvaluators;
+	private List<RangerPolicyItemEvaluator> allowExceptionEvaluators;
+	private List<RangerPolicyItemEvaluator> denyExceptionEvaluators;
+	private int                             customConditionsCount;
+	private List<RangerDataMaskPolicyItemEvaluator>  dataMaskEvaluators;
+	private List<RangerRowFilterPolicyItemEvaluator> rowFilterEvaluators;
 
 	private String perfTag;
 
-	protected boolean needsDynamicEval() { return resourceMatcher != null ? resourceMatcher.getNeedsDynamicEval() : false; }
+	protected boolean needsDynamicEval() { return resourceMatcher != null && resourceMatcher.getNeedsDynamicEval(); }
 
 	@Override
 	public int getCustomConditionsCount() {
@@ -117,6 +113,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 
 		resourceMatcher.setServiceDef(serviceDef);
 		resourceMatcher.setPolicy(policy);
+		resourceMatcher.setServiceDefHelper(options.getServiceDefHelper());
 		resourceMatcher.init();
 
 		if(policy != null) {
@@ -135,10 +132,11 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			rowFilterEvaluators      = Collections.<RangerRowFilterPolicyItemEvaluator>emptyList();
 		}
 
-		Collections.sort(allowEvaluators);
-		Collections.sort(denyEvaluators);
-		Collections.sort(allowExceptionEvaluators);
-		Collections.sort(denyExceptionEvaluators);
+		RangerPolicyItemEvaluator.EvalOrderComparator comparator = new RangerPolicyItemEvaluator.EvalOrderComparator();
+		Collections.sort(allowEvaluators, comparator);
+		Collections.sort(denyEvaluators, comparator);
+		Collections.sort(allowExceptionEvaluators, comparator);
+		Collections.sort(denyExceptionEvaluators, comparator);
 
 		/* dataMask, rowFilter policyItems must be evaulated in the order given in the policy; hence no sort
 		Collections.sort(dataMaskEvaluators);
@@ -168,20 +166,26 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
         if (request != null && result != null) {
 
 			if (!result.getIsAccessDetermined() || !result.getIsAuditedDetermined()) {
-				RangerPolicyResourceMatcher.MatchType matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
+				RangerPolicyResourceMatcher.MatchType matchType;
 
-				final boolean isMatched;
-				if (request.isAccessTypeAny()) {
-					isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
-				} else if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
+				if (RangerTagAccessRequest.class.isInstance(request)) {
+					matchType = ((RangerTagAccessRequest) request).getMatchType();
 				} else {
-					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR;
+					matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
 				}
 
+				final boolean isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;;
+
 				if (isMatched) {
 					if (RangerTagAccessRequest.class.isInstance(request)) {
-						matchType = ((RangerTagAccessRequest) request).getMatchType();
+						if (matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT
+								&& !request.isAccessTypeAny()
+								&& request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
+							if (LOG.isDebugEnabled()) {
+								LOG.debug("Setting matchType from DESCENDANT to SELF, so that any DENY policy-items will take effect.");
+							}
+							matchType = RangerPolicyResourceMatcher.MatchType.SELF;
+						}
 					}
 					if (!result.getIsAuditedDetermined()) {
 						if (isAuditEnabled()) {
@@ -191,7 +195,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 					}
 					if (!result.getIsAccessDetermined()) {
 						if (hasMatchablePolicyItem(request)) {
-							evaluatePolicyItems(request, result, matchType != RangerPolicyResourceMatcher.MatchType.DESCENDANT);
+							evaluatePolicyItems(request, matchType, result);
 						}
 					}
 				}
@@ -205,104 +209,6 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
         }
     }
 
-	@Override
-	public void evaluate(RangerAccessRequest request, RangerDataMaskResult result) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyEvaluator.evaluate(" + request + ", " + result + ")");
-		}
-
-		RangerPerfTracer perf = null;
-
-		if(RangerPerfTracer.isPerfTraceEnabled(PERF_POLICY_REQUEST_LOG)) {
-			perf = RangerPerfTracer.getPerfTracer(PERF_POLICY_REQUEST_LOG, "RangerPolicyEvaluator.evaluate(requestHashCode=" + Integer.toHexString(System.identityHashCode(request)) + "," + perfTag + ")");
-		}
-
-		if (request != null && result != null && CollectionUtils.isNotEmpty(dataMaskEvaluators)) {
-
-			if (!result.getIsAccessDetermined() || !result.getIsAuditedDetermined()) {
-				RangerPolicyResourceMatcher.MatchType matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
-
-				final boolean isMatched;
-				if (request.isAccessTypeAny()) {
-					isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
-				} else if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
-				} else {
-					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR;
-				}
-
-				if (isMatched) {
-					if (!result.getIsAuditedDetermined()) {
-						if (isAuditEnabled()) {
-							result.setIsAudited(true);
-							result.setAuditPolicyId(getPolicy().getId());
-						}
-					}
-					if (!result.getIsAccessDetermined()) {
-						if (hasMatchablePolicyItem(request)) {
-							evaluatePolicyItems(request, result);
-						}
-					}
-				}
-			}
-
-		}
-
-		RangerPerfTracer.log(perf);
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyEvaluator.evaluate(" + request + ", " + result + ")");
-		}
-	}
-
-	@Override
-	public void evaluate(RangerAccessRequest request, RangerRowFilterResult result) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyEvaluator.evaluate(" + request + ", " + result + ")");
-		}
-
-		RangerPerfTracer perf = null;
-
-		if(RangerPerfTracer.isPerfTraceEnabled(PERF_POLICY_REQUEST_LOG)) {
-			perf = RangerPerfTracer.getPerfTracer(PERF_POLICY_REQUEST_LOG, "RangerPolicyEvaluator.evaluate(requestHashCode=" + Integer.toHexString(System.identityHashCode(request)) + "," + perfTag + ")");
-		}
-
-		if (request != null && result != null && CollectionUtils.isNotEmpty(rowFilterEvaluators)) {
-			if (!result.getIsAccessDetermined() || !result.getIsAuditedDetermined()) {
-				RangerPolicyResourceMatcher.MatchType matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
-
-				final boolean isMatched;
-				if (request.isAccessTypeAny()) {
-					isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
-				} else if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
-				} else {
-					isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR;
-				}
-
-				if (isMatched) {
-					if (!result.getIsAuditedDetermined()) {
-						if (isAuditEnabled()) {
-							result.setIsAudited(true);
-							result.setAuditPolicyId(getPolicy().getId());
-						}
-					}
-					if (!result.getIsAccessDetermined()) {
-						if (hasMatchablePolicyItem(request)) {
-							evaluatePolicyItems(request, result);
-						}
-					}
-				}
-			}
-		}
-
-		RangerPerfTracer.log(perf);
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyEvaluator.evaluate(" + request + ", " + result + ")");
-		}
-	}
-
 	@Override
 	public boolean isMatch(RangerAccessResource resource, Map<String, Object> evalContext) {
 		if(LOG.isDebugEnabled()) {
@@ -336,11 +242,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			LOG.debug("==> RangerDefaultPolicyEvaluator.isCompleteMatch(" + resource + ", " + evalContext + ")");
 		}
 
-		boolean ret = false;
-
-		if(resourceMatcher != null) {
-			ret = resourceMatcher.isCompleteMatch(resource, evalContext);
-		}
+		boolean ret = resourceMatcher != null && resourceMatcher.isCompleteMatch(resource, evalContext);
 
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("<== RangerDefaultPolicyEvaluator.isCompleteMatch(" + resource + "): " + ret);
@@ -355,11 +257,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			LOG.debug("==> RangerDefaultPolicyEvaluator.isCompleteMatch(" + resources + ", " + evalContext + ")");
 		}
 
-		boolean ret = false;
-
-		if(resourceMatcher != null) {
-			ret = resourceMatcher.isCompleteMatch(resources, evalContext);
-		}
+		boolean ret = resourceMatcher != null && resourceMatcher.isCompleteMatch(resources, evalContext);
 
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("<== RangerDefaultPolicyEvaluator.isCompleteMatch(" + resources + ", " + evalContext + "): " + ret);
@@ -374,7 +272,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			LOG.debug("==> RangerDefaultPolicyEvaluator.isAccessAllowed(" + resource + ", " + user + ", " + userGroups + ", " + accessType + ")");
 		}
 
-		Map<String, Object> evalContext = new HashMap<String, Object>();
+		Map<String, Object> evalContext = new HashMap<>();
 		RangerAccessRequestUtil.setCurrentUserInContext(evalContext, user);
 
 		boolean ret = isAccessAllowed(user, userGroups, accessType) && isMatch(resource, evalContext);
@@ -392,7 +290,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			LOG.debug("==> RangerDefaultPolicyEvaluator.isAccessAllowed(" + resources + ", " + user + ", " + userGroups + ", " + accessType + ")");
 		}
 
-		Map<String, Object> evalContext = new HashMap<String, Object>();
+		Map<String, Object> evalContext = new HashMap<>();
 		RangerAccessRequestUtil.setCurrentUserInContext(evalContext, user);
 
 		boolean ret = isAccessAllowed(user, userGroups, accessType) && isMatch(resources, evalContext);
@@ -409,28 +307,26 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> RangerDefaultPolicyEvaluator.getResourceAccessInfo(" + request + ", " + result + ")");
 		}
-		RangerPolicyResourceMatcher.MatchType matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
-
-		final boolean isMatched;
-		if (request.isAccessTypeAny()) {
-				isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;
-			} else if (request.getResourceMatchingScope() == RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS) {
-				isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.DESCENDANT;
-			} else {
-			isMatched = matchType == RangerPolicyResourceMatcher.MatchType.SELF || matchType == RangerPolicyResourceMatcher.MatchType.ANCESTOR;
+		RangerPolicyResourceMatcher.MatchType matchType;
+		if (RangerTagAccessRequest.class.isInstance(request)) {
+			matchType = ((RangerTagAccessRequest) request).getMatchType();
+		} else {
+			matchType = resourceMatcher != null ? resourceMatcher.getMatchType(request.getResource(), request.getContext()) : RangerPolicyResourceMatcher.MatchType.NONE;
 		}
 
+		final boolean isMatched = matchType != RangerPolicyResourceMatcher.MatchType.NONE;;
+
 		if (isMatched) {
 
 			if (CollectionUtils.isNotEmpty(allowEvaluators)) {
-				Set<String> users = new HashSet<String>();
-				Set<String> groups = new HashSet<String>();
+				Set<String> users = new HashSet<>();
+				Set<String> groups = new HashSet<>();
 
 				getResourceAccessInfo(request, allowEvaluators, users, groups);
 
 				if (CollectionUtils.isNotEmpty(allowExceptionEvaluators)) {
-					Set<String> exceptionUsers = new HashSet<String>();
-					Set<String> exceptionGroups = new HashSet<String>();
+					Set<String> exceptionUsers = new HashSet<>();
+					Set<String> exceptionGroups = new HashSet<>();
 
 					getResourceAccessInfo(request, allowExceptionEvaluators, exceptionUsers, exceptionGroups);
 
@@ -469,86 +365,19 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		}
 	}
 
-
-	protected void evaluatePolicyItems(RangerAccessRequest request, RangerAccessResult result, boolean isResourceMatch) {
+	protected void evaluatePolicyItems(RangerAccessRequest request, RangerPolicyResourceMatcher.MatchType matchType, RangerAccessResult result) {
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ", " + isResourceMatch + ")");
+			LOG.debug("==> RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ", " + matchType + ")");
 		}
 
-		RangerPolicyItemEvaluator matchedPolicyItem = getMatchingPolicyItem(request, denyEvaluators, denyExceptionEvaluators);
-
-		if(matchedPolicyItem == null && !result.getIsAllowed()) { // if not denied, evaluate allowItems only if not already allowed
-			matchedPolicyItem = getMatchingPolicyItem(request, allowEvaluators, allowExceptionEvaluators);
-		}
+		RangerPolicyItemEvaluator matchedPolicyItem = getMatchingPolicyItem(request, result);
 
 		if(matchedPolicyItem != null) {
-			RangerPolicy policy = getPolicy();
-
-			if(matchedPolicyItem.getPolicyItemType() == RangerPolicyItemEvaluator.POLICY_ITEM_TYPE_DENY) {
-				if(isResourceMatch) {
-					result.setIsAllowed(false);
-					result.setPolicyId(policy.getId());
-					result.setReason(matchedPolicyItem.getComments());
-				}
-			} else {
-				if(! result.getIsAllowed()) { // if access is not yet allowed by another policy
-					result.setIsAllowed(true);
-					result.setPolicyId(policy.getId());
-					result.setReason(matchedPolicyItem.getComments());
-				}
-			}
+			matchedPolicyItem.updateAccessResult(result, matchType, getPolicy().getId());
 		}
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ", " + isResourceMatch + ")");
-		}
-	}
-
-	protected void evaluatePolicyItems(RangerAccessRequest request, RangerDataMaskResult result) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ")");
-		}
-
-		RangerDataMaskPolicyItemEvaluator matchedPolicyItem = getMatchingPolicyItem(request, dataMaskEvaluators);
-		RangerPolicyItemDataMaskInfo      dataMaskInfo      = matchedPolicyItem != null ? matchedPolicyItem.getDataMaskInfo() : null;
-
-		if(dataMaskInfo != null) {
-			RangerPolicy policy = getPolicy();
-
-			result.setIsAllowed(true);
-			result.setIsAccessDetermined(true);
-
-			result.setMaskType(dataMaskInfo.getDataMaskType());
-			result.setMaskCondition(dataMaskInfo.getConditionExpr());
-			result.setMaskedValue(dataMaskInfo.getValueExpr());
-			result.setPolicyId(policy.getId());
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ", " + ")");
-		}
-	}
-
-	protected void evaluatePolicyItems(RangerAccessRequest request, RangerRowFilterResult result) {
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ")");
-		}
-
-		RangerRowFilterPolicyItemEvaluator matchedPolicyItem = getMatchingPolicyItem(request, rowFilterEvaluators);
-		RangerPolicyItemRowFilterInfo      rowFilterInfo     = matchedPolicyItem != null ? matchedPolicyItem.getRowFilterInfo() : null;
-
-		if(rowFilterInfo != null) {
-			RangerPolicy policy = getPolicy();
-
-			result.setIsAllowed(true);
-			result.setIsAccessDetermined(true);
-
-			result.setFilterExpr(rowFilterInfo.getFilterExpr());
-			result.setPolicyId(policy.getId());
-		}
-
-		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ", " + ")");
+			LOG.debug("<== RangerDefaultPolicyEvaluator.evaluatePolicyItems(" + request + ", " + result + ", " + matchType + ")");
 		}
 	}
 
@@ -605,11 +434,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			LOG.debug("==> RangerDefaultPolicyEvaluator.isMatch(" + resources + ", " + evalContext + ")");
 		}
 
-		boolean ret = false;
-
-		if(resourceMatcher != null) {
-			ret = resourceMatcher.isMatch(resources, evalContext);
-		}
+		boolean ret = resourceMatcher != null && resourceMatcher.isMatch(resources, evalContext);
 
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("<== RangerDefaultPolicyEvaluator.isMatch(" + resources + ", " + evalContext + "): " + ret);
@@ -723,20 +548,18 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 			for(RangerAccessTypeDef accessTypeDef : serviceDef.getAccessTypes()) {
 				if(!CollectionUtils.isEmpty(accessTypeDef.getImpliedGrants())) {
 					if(ret == null) {
-						ret = new HashMap<String, Collection<String>>();
+						ret = new HashMap<>();
 					}
 
 					Collection<String> impliedAccessGrants = ret.get(accessTypeDef.getName());
 
 					if(impliedAccessGrants == null) {
-						impliedAccessGrants = new HashSet<String>();
+						impliedAccessGrants = new HashSet<>();
 
 						ret.put(accessTypeDef.getName(), impliedAccessGrants);
 					}
 
-					for(String impliedAccessGrant : accessTypeDef.getImpliedGrants()) {
-						impliedAccessGrants.add(impliedAccessGrant);
-					}
+					impliedAccessGrants.addAll(accessTypeDef.getImpliedGrants());
 				}
 			}
 		}
@@ -777,7 +600,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		}
 
 		if(CollectionUtils.isNotEmpty(policyItems)) {
-			ret = new ArrayList<RangerPolicyItemEvaluator>();
+			ret = new ArrayList<>();
 
 			int policyItemCounter = 1;
 
@@ -803,7 +626,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		List<RangerDataMaskPolicyItemEvaluator> ret = null;
 
 		if(CollectionUtils.isNotEmpty(policyItems)) {
-			ret = new ArrayList<RangerDataMaskPolicyItemEvaluator>();
+			ret = new ArrayList<>();
 
 			int policyItemCounter = 1;
 
@@ -829,7 +652,7 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		List<RangerRowFilterPolicyItemEvaluator> ret = null;
 
 		if(CollectionUtils.isNotEmpty(policyItems)) {
-			ret = new ArrayList<RangerRowFilterPolicyItemEvaluator>();
+			ret = new ArrayList<>();
 
 			int policyItemCounter = 1;
 
@@ -863,6 +686,38 @@ public class RangerDefaultPolicyEvaluator extends RangerAbstractPolicyEvaluator
 		return ret;
 	}
 
+	protected RangerPolicyItemEvaluator getMatchingPolicyItem(RangerAccessRequest request, RangerAccessResult result) {
+		RangerPolicyItemEvaluator ret = null;
+
+		Integer policyType = getPolicy().getPolicyType();
+		if (policyType == null) {
+			policyType = RangerPolicy.POLICY_TYPE_ACCESS;
+		}
+
+		switch (policyType) {
+			case RangerPolicy.POLICY_TYPE_ACCESS: {
+				ret = getMatchingPolicyItem(request, denyEvaluators, denyExceptionEvaluators);
+
+				if(ret == null && !result.getIsAllowed()) { // if not denied, evaluate allowItems only if not already allowed
+					ret = getMatchingPolicyItem(request, allowEvaluators, allowExceptionEvaluators);
+				}
+				break;
+			}
+			case RangerPolicy.POLICY_TYPE_DATAMASK: {
+				ret = getMatchingPolicyItem(request, dataMaskEvaluators);
+				break;
+			}
+			case RangerPolicy.POLICY_TYPE_ROWFILTER: {
+				ret = getMatchingPolicyItem(request, rowFilterEvaluators);
+				break;
+			}
+			default:
+				break;
+		}
+
+		return ret;
+	}
+
 	protected <T extends RangerPolicyItemEvaluator> T getMatchingPolicyItem(RangerAccessRequest request, List<T> evaluators) {
 		T ret = getMatchingPolicyItem(request, evaluators, null);
 
