@@ -35,14 +35,14 @@ import java.util.*;
 public class RangerOptimizedPolicyEvaluator extends RangerDefaultPolicyEvaluator {
     private static final Log LOG = LogFactory.getLog(RangerOptimizedPolicyEvaluator.class);
 
-    private Set<String> groups         = new HashSet<String>();
-    private Set<String> users          = new HashSet<String>();
-    private Set<String> accessPerms    = new HashSet<String>();
-    private boolean     delegateAdmin  = false;
-    private boolean     hasAllPerms    = false;
-    private boolean     hasPublicGroup = false;
-    private boolean     hasCurrentUser = false;
-    private boolean     hasResourceOwner = false;
+    private Set<String> groups         = new HashSet<>();
+    private Set<String> users          = new HashSet<>();
+    private Set<String> accessPerms    = new HashSet<>();
+    private boolean     delegateAdmin;
+    private boolean     hasAllPerms;
+    private boolean     hasPublicGroup;
+    private boolean     hasCurrentUser;
+    private boolean     hasResourceOwner;
 
     // For computation of priority
     private static final String RANGER_POLICY_EVAL_MATCH_ANY_PATTERN_STRING   = "*";
@@ -81,10 +81,10 @@ public class RangerOptimizedPolicyEvaluator extends RangerDefaultPolicyEvaluator
         hasAllPerms = checkIfHasAllPerms();
 
         for (String user : users) {
-            if (!hasCurrentUser && user.equalsIgnoreCase(RangerPolicyEngine.USER_CURRENT)) {
+            if (!hasCurrentUser && RangerPolicyEngine.USER_CURRENT.equalsIgnoreCase(user)) {
                 hasCurrentUser = true;
             }
-            if (!hasResourceOwner && user.equalsIgnoreCase(RangerPolicyEngine.RESOURCE_OWNER)) {
+            if (!hasResourceOwner && RangerPolicyEngine.RESOURCE_OWNER.equalsIgnoreCase(user)) {
                 hasResourceOwner = true;
             }
             if (hasCurrentUser && hasResourceOwner) {
@@ -93,7 +93,7 @@ public class RangerOptimizedPolicyEvaluator extends RangerDefaultPolicyEvaluator
         }
 
         for (String group : groups) {
-            if (group.equalsIgnoreCase(RangerPolicyEngine.GROUP_PUBLIC)) {
+            if (RangerPolicyEngine.GROUP_PUBLIC.equalsIgnoreCase(group)) {
                 hasPublicGroup = true;
                 break;
             }
@@ -146,7 +146,7 @@ public class RangerOptimizedPolicyEvaluator extends RangerDefaultPolicyEvaluator
         RangerServiceDef                         serviceDef   = getServiceDef();
         List<RangerServiceDef.RangerResourceDef> resourceDefs = serviceDef.getResources();
         RangerPolicy                             policy       = getPolicy();
-        List<LevelResourceNames>                 tmpList      = new ArrayList<LevelResourceNames>();
+        List<LevelResourceNames>                 tmpList      = new ArrayList<>();
 
         for (Map.Entry<String, RangerPolicy.RangerPolicyResource> kv : policy.getResources().entrySet()) {
             String                            resourceName   = kv.getKey();
@@ -172,7 +172,7 @@ public class RangerOptimizedPolicyEvaluator extends RangerDefaultPolicyEvaluator
             boolean foundMatchAny         = false;
 
             for (String resourceName : item.policyResource.getValues()) {
-                if (resourceName.isEmpty() || resourceName.equals(RANGER_POLICY_EVAL_MATCH_ANY_PATTERN_STRING)) {
+                if (resourceName.isEmpty() || RANGER_POLICY_EVAL_MATCH_ANY_PATTERN_STRING.equals(resourceName)) {
                     foundMatchAny = true;
                     break;
                 } else if (resourceName.contains(RANGER_POLICY_EVAL_MATCH_ANY_PATTERN_STRING)) {
