@@ -20,6 +20,8 @@
 package org.apache.ranger.plugin.policyevaluator;
 
 
+import java.io.Serializable;
+import java.util.Comparator;
 import java.util.Map;
 import java.util.Set;
 
@@ -29,14 +31,14 @@ import org.apache.ranger.plugin.model.RangerServiceDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessResult;
 import org.apache.ranger.plugin.policyengine.RangerAccessResource;
-import org.apache.ranger.plugin.policyengine.RangerDataMaskResult;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
 import org.apache.ranger.plugin.policyengine.RangerResourceAccessInfo;
-import org.apache.ranger.plugin.policyengine.RangerRowFilterResult;
 import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceEvaluator;
 
 
 public interface RangerPolicyEvaluator extends RangerPolicyResourceEvaluator {
+	Comparator<RangerPolicyEvaluator> EVAL_ORDER_COMPARATOR = new RangerPolicyEvaluator.PolicyEvalOrderComparator();
+
 	String EVALUATOR_TYPE_AUTO   = "auto";
 	String EVALUATOR_TYPE_OPTIMIZED = "optimized";
 	String EVALUATOR_TYPE_CACHED    = "cached";
@@ -67,10 +69,6 @@ public interface RangerPolicyEvaluator extends RangerPolicyResourceEvaluator {
 
 	void evaluate(RangerAccessRequest request, RangerAccessResult result);
 
-	void evaluate(RangerAccessRequest request, RangerDataMaskResult result);
-
-	void evaluate(RangerAccessRequest request, RangerRowFilterResult result);
-
 	boolean isMatch(RangerAccessResource resource, Map<String, Object> evalContext);
 
 	boolean isCompleteMatch(RangerAccessResource resource, Map<String, Object> evalContext);
@@ -83,4 +81,25 @@ public interface RangerPolicyEvaluator extends RangerPolicyResourceEvaluator {
 
 	void getResourceAccessInfo(RangerAccessRequest request, RangerResourceAccessInfo result);
 
+	class PolicyEvalOrderComparator implements Comparator<RangerPolicyEvaluator>, Serializable {
+		@Override
+		public int compare(RangerPolicyEvaluator me, RangerPolicyEvaluator other) {
+			int result;
+
+			if (me.hasDeny() && !other.hasDeny()) {
+				result = -1;
+			} else if (!me.hasDeny() && other.hasDeny()) {
+				result = 1;
+			} else {
+				result = Long.compare(other.getUsageCount(), me.getUsageCount());
+
+				if (result == 0) {
+					result = Integer.compare(me.getEvalOrder(), other.getEvalOrder());
+				}
+			}
+
+			return result;
+		}
+	}
+
 }
