@@ -18,14 +18,18 @@
  */
 package org.apache.ranger.plugin.policyevaluator;
 
+import java.io.Serializable;
+import java.util.Comparator;
 import java.util.List;
 import java.util.Set;
 
 import org.apache.ranger.plugin.conditionevaluator.RangerConditionEvaluator;
 import org.apache.ranger.plugin.model.RangerPolicy.RangerPolicyItem;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
+import org.apache.ranger.plugin.policyengine.RangerAccessResult;
+import org.apache.ranger.plugin.policyresourcematcher.RangerPolicyResourceMatcher;
 
-public interface RangerPolicyItemEvaluator extends Comparable<RangerPolicyItemEvaluator> {
+public interface RangerPolicyItemEvaluator {
 	int POLICY_ITEM_TYPE_ALLOW            = 0;
 	int POLICY_ITEM_TYPE_DENY             = 1;
 	int POLICY_ITEM_TYPE_ALLOW_EXCEPTIONS = 2;
@@ -54,4 +58,13 @@ public interface RangerPolicyItemEvaluator extends Comparable<RangerPolicyItemEv
 	boolean matchAccessType(String accessType);
 
 	boolean matchCustomConditions(RangerAccessRequest request);
+
+	class EvalOrderComparator implements Comparator<RangerPolicyItemEvaluator>, Serializable {
+		@Override
+		public int compare(RangerPolicyItemEvaluator me, RangerPolicyItemEvaluator other) {
+			return Integer.compare(me.getEvalOrder(), other.getEvalOrder());
+		}
+	}
+	void updateAccessResult(RangerAccessResult result, RangerPolicyResourceMatcher.MatchType matchType, Long policyId);
+
 }
