@@ -48,18 +48,18 @@ public abstract class RangerAbstractResourceMatcher implements RangerResourceMat
 	public final static String OPTION_TOKEN_DELIMITER_ESCAPE = "tokenDelimiterEscape";
 	public final static String OPTION_TOKEN_DELIMITER_PREFIX = "tokenDelimiterPrefix";
 
-	protected RangerResourceDef    resourceDef    = null;
-	protected RangerPolicyResource policyResource = null;
+	protected RangerResourceDef    resourceDef;
+	protected RangerPolicyResource policyResource;
 
-	protected boolean      optIgnoreCase = false;
-	protected boolean      optWildCard   = false;
+	protected boolean      optIgnoreCase;
+	protected boolean      optWildCard;
 
-	protected List<String> policyValues = null;
-	protected boolean policyIsExcludes = false;
-	protected boolean isMatchAny = false;
-	protected ResourceMatcherWrapper resourceMatchers = null;
+	protected List<String> policyValues;
+	protected boolean policyIsExcludes;
+	protected boolean isMatchAny;
+	protected ResourceMatcherWrapper resourceMatchers;
 
-	protected boolean optReplaceTokens   = false;
+	protected boolean optReplaceTokens;
 	protected char    startDelimiterChar = '{';
 	protected char    endDelimiterChar   = '}';
 	protected char    escapeChar         = '\\';
@@ -86,8 +86,8 @@ public abstract class RangerAbstractResourceMatcher implements RangerResourceMat
 		optIgnoreCase = getOptionIgnoreCase(options);
 		optWildCard   = getOptionWildCard(options);
 
-		policyValues = new ArrayList<String>();
-		policyIsExcludes = policyResource == null ? false : policyResource.getIsExcludes();
+		policyValues = new ArrayList<>();
+		policyIsExcludes = policyResource != null && policyResource.getIsExcludes();
 
 		if (policyResource != null && policyResource.getValues() != null) {
 			for (String policyValue : policyResource.getValues()) {
@@ -167,7 +167,7 @@ public abstract class RangerAbstractResourceMatcher implements RangerResourceMat
 		return ServiceDefUtil.getOption(options, OPTION_TOKEN_DELIMITER_PREFIX, "");
 	}
 	protected ResourceMatcherWrapper buildResourceMatchers() {
-		List<ResourceMatcher> resourceMatchers = new ArrayList<ResourceMatcher>();
+		List<ResourceMatcher> resourceMatchers = new ArrayList<>();
 		boolean needsDynamicEval = false;
 
 		for (String policyValue : policyValues) {
@@ -185,7 +185,7 @@ public abstract class RangerAbstractResourceMatcher implements RangerResourceMat
 			}
 		}
 
-		Collections.sort(resourceMatchers);
+		Collections.sort(resourceMatchers, new ResourceMatcher.PriorityComparator());
 
 		return CollectionUtils.isNotEmpty(resourceMatchers) ?
 				new ResourceMatcherWrapper(needsDynamicEval, resourceMatchers) : null;
@@ -205,7 +205,7 @@ public abstract class RangerAbstractResourceMatcher implements RangerResourceMat
 			String policyValue = policyValues.get(0);
 
 			if(isMatchAny) {
-				ret = StringUtils.containsOnly(resource, WILDCARD_ASTERISK);
+				ret = StringUtils.isEmpty(resource) || StringUtils.containsOnly(resource, WILDCARD_ASTERISK);
 			} else {
 				ret = optIgnoreCase ? StringUtils.equalsIgnoreCase(resource, policyValue) : StringUtils.equals(resource, policyValue);
 			}
