@@ -39,13 +39,10 @@ import org.apache.ranger.plugin.policyengine.RangerAccessRequestImpl;
 import org.apache.ranger.plugin.policyengine.RangerAccessResourceImpl;
 import org.apache.ranger.plugin.policyengine.RangerAccessResult;
 import org.apache.ranger.plugin.policyengine.RangerAccessResultProcessor;
-import org.apache.ranger.plugin.policyengine.RangerDataMaskResult;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngine;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineImpl;
 import org.apache.ranger.plugin.policyengine.RangerPolicyEngineOptions;
 import org.apache.ranger.plugin.policyengine.RangerResourceAccessInfo;
-import org.apache.ranger.plugin.policyengine.RangerRowFilterResult;
-import org.apache.ranger.plugin.policyevaluator.RangerPolicyEvaluator;
 import org.apache.ranger.plugin.store.EmbeddedServiceDefsUtil;
 import org.apache.ranger.plugin.util.GrantRevokeRequest;
 import org.apache.ranger.plugin.util.PolicyRefresher;
@@ -57,16 +54,16 @@ public class RangerBasePlugin {
 
 	public static final char RANGER_TRUSTED_PROXY_IPADDRESSES_SEPARATOR_CHAR = ',';
 
-	private String                    serviceType  = null;
-	private String                    appId        = null;
-	private String                    serviceName  = null;
-	private PolicyRefresher           refresher    = null;
-	private RangerPolicyEngine        policyEngine = null;
+	private String                    serviceType;
+	private String                    appId;
+	private String                    serviceName;
+	private String                    clusterName;
+	private PolicyRefresher           refresher;
+	private RangerPolicyEngine        policyEngine;
 	private RangerPolicyEngineOptions policyEngineOptions = new RangerPolicyEngineOptions();
-	private RangerAccessResultProcessor resultProcessor = null;
-	private boolean                   useForwardedIPAddress = false;
-	private String[]                  trustedProxyAddresses = null;
-	private String                    clusterName = null;
+	private RangerAccessResultProcessor resultProcessor;
+	private boolean                   useForwardedIPAddress;
+	private String[]                  trustedProxyAddresses;
 	private Timer                     policyEngineRefreshTimer;
 
 	Map<String, LogHistory> logHistoryList = new Hashtable<String, RangerBasePlugin.LogHistory>();
@@ -81,7 +78,7 @@ public class RangerBasePlugin {
 	public String getServiceType() {
 		return serviceType;
 	}
-	
+
 	public String getClusterName() {
 		return clusterName;
 	}
@@ -113,17 +110,18 @@ public class RangerBasePlugin {
 	public void init() {
 		cleanup();
 
-		RangerConfiguration.getInstance().addResourcesForServiceType(serviceType);
-		RangerConfiguration.getInstance().initAudit(appId);
+		RangerConfiguration configuration = RangerConfiguration.getInstance();
+		configuration.addResourcesForServiceType(serviceType);
+		configuration.initAudit(appId);
 
 		String propertyPrefix    = "ranger.plugin." + serviceType;
-		long   pollingIntervalMs = RangerConfiguration.getInstance().getLong(propertyPrefix + ".policy.pollIntervalMs", 30 * 1000);
-		String cacheDir          = RangerConfiguration.getInstance().get(propertyPrefix + ".policy.cache.dir");
-		serviceName = RangerConfiguration.getInstance().get(propertyPrefix + ".service.name");
+		long   pollingIntervalMs = configuration.getLong(propertyPrefix + ".policy.pollIntervalMs", 30 * 1000);
+		String cacheDir          = configuration.get(propertyPrefix + ".policy.cache.dir");
+		serviceName = configuration.get(propertyPrefix + ".service.name");
 		clusterName = RangerConfiguration.getInstance().get(propertyPrefix + ".ambari.cluster.name", "");
 
-		useForwardedIPAddress = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".use.x-forwarded-for.ipaddress", false);
-		String trustedProxyAddressString = RangerConfiguration.getInstance().get(propertyPrefix + ".trusted.proxy.ipaddresses");
+		useForwardedIPAddress = configuration.getBoolean(propertyPrefix + ".use.x-forwarded-for.ipaddress", false);
+		String trustedProxyAddressString = configuration.get(propertyPrefix + ".trusted.proxy.ipaddresses");
 		trustedProxyAddresses = StringUtils.split(trustedProxyAddressString, RANGER_TRUSTED_PROXY_IPADDRESSES_SEPARATOR_CHAR);
 		if (trustedProxyAddresses != null) {
 			for (int i = 0; i < trustedProxyAddresses.length; i++) {
@@ -141,12 +139,9 @@ public class RangerBasePlugin {
 			LOG.warn("Ranger plugin will trust RemoteIPAddress and treat first X-Forwarded-Address in the access-request as the clientIPAddress");
 		}
 
-		policyEngineOptions.evaluatorType           = RangerConfiguration.getInstance().get(propertyPrefix + ".policyengine.option.evaluator.type", RangerPolicyEvaluator.EVALUATOR_TYPE_AUTO);
-		policyEngineOptions.cacheAuditResults       = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".policyengine.option.cache.audit.results", true);
-		policyEngineOptions.disableContextEnrichers = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".policyengine.option.disable.context.enrichers", false);
-		policyEngineOptions.disableCustomConditions = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".policyengine.option.disable.custom.conditions", false);
-		policyEngineOptions.disableTagPolicyEvaluation = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".policyengine.option.disable.tagpolicy.evaluation", false);
-		policyEngineOptions.disableTrieLookupPrefilter = RangerConfiguration.getInstance().getBoolean(propertyPrefix + ".policyengine.option.disable.trie.lookup.prefilter", false);
+		policyEngineOptions.configureForPlugin(configuration, propertyPrefix);
+
+		LOG.info(policyEngineOptions);
 
 		RangerAdminClient admin = createAdminClient(serviceName, appId, propertyPrefix);
 
@@ -154,7 +149,7 @@ public class RangerBasePlugin {
 		refresher.setDaemon(true);
 		refresher.startRefresher();
 
-		long policyReorderIntervalMs = RangerConfiguration.getInstance().getLong(propertyPrefix + ".policy.policyReorderInterval", 60 * 1000);
+		long policyReorderIntervalMs = configuration.getLong(propertyPrefix + ".policy.policyReorderInterval", 60 * 1000);
 		if (policyReorderIntervalMs >= 0 && policyReorderIntervalMs < 15 * 1000) {
 			policyReorderIntervalMs = 15 * 1000;
 		}
@@ -163,12 +158,12 @@ public class RangerBasePlugin {
 			LOG.debug(propertyPrefix + ".policy.policyReorderInterval:" + policyReorderIntervalMs);
 		}
 
-		if (policyReorderIntervalMs > 0) {
+		if (policyEngineOptions.disableTrieLookupPrefilter && policyReorderIntervalMs > 0) {
 			policyEngineRefreshTimer = new Timer("PolicyEngineRefreshTimer", true);
 			try {
 				policyEngineRefreshTimer.schedule(new PolicyEngineRefresher(this), policyReorderIntervalMs, policyReorderIntervalMs);
 				if (LOG.isDebugEnabled()) {
-					LOG.debug("Scheduled PolicyEngineRefresher to reorder policies nbased on number of evaluations in and every " + policyReorderIntervalMs + " milliseconds");
+					LOG.debug("Scheduled PolicyEngineRefresher to reorder policies based on number of evaluations in and every " + policyReorderIntervalMs + " milliseconds");
 				}
 			} catch (IllegalStateException exception) {
 				LOG.error("Error scheduling policyEngineRefresher:", exception);
@@ -176,8 +171,7 @@ public class RangerBasePlugin {
 				policyEngineRefreshTimer = null;
 			}
 		} else {
-			LOG.info("Policies will NOT be reordered based on number of evaluations because "
-					+ propertyPrefix + ".policy.policyReorderInterval is set to a negative number[" + policyReorderIntervalMs +"]");
+			LOG.info("Policies will NOT be reordered based on number of evaluations");
 		}
 	}
 
@@ -257,7 +251,7 @@ public class RangerBasePlugin {
 		if(policyEngine != null) {
 			policyEngine.preProcess(request);
 
-			return policyEngine.isAccessAllowed(request, resultProcessor);
+			return policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_ACCESS, resultProcessor);
 		}
 
 		return null;
@@ -269,31 +263,31 @@ public class RangerBasePlugin {
 		if(policyEngine != null) {
 			policyEngine.preProcess(requests);
 
-			return policyEngine.isAccessAllowed(requests, resultProcessor);
+			return policyEngine.evaluatePolicies(requests, RangerPolicy.POLICY_TYPE_ACCESS, resultProcessor);
 		}
 
 		return null;
 	}
 
-	public RangerDataMaskResult evalDataMaskPolicies(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
+	public RangerAccessResult evalDataMaskPolicies(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
 		RangerPolicyEngine policyEngine = this.policyEngine;
 
 		if(policyEngine != null) {
 			policyEngine.preProcess(request);
 
-			return policyEngine.evalDataMaskPolicies(request, resultProcessor);
+			return policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_DATAMASK, resultProcessor);
 		}
 
 		return null;
 	}
 
-	public RangerRowFilterResult evalRowFilterPolicies(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
+	public RangerAccessResult evalRowFilterPolicies(RangerAccessRequest request, RangerAccessResultProcessor resultProcessor) {
 		RangerPolicyEngine policyEngine = this.policyEngine;
 
 		if(policyEngine != null) {
 			policyEngine.preProcess(request);
 
-			return policyEngine.evalRowFilterPolicies(request, resultProcessor);
+			return policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_ROWFILTER, resultProcessor);
 		}
 
 		return null;
@@ -313,7 +307,7 @@ public class RangerBasePlugin {
 
 	public void grantAccess(GrantRevokeRequest request, RangerAccessResultProcessor resultProcessor) throws Exception {
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerAdminRESTClient.grantAccess(" + request + ")");
+			LOG.debug("==> RangerBasePlugin.grantAccess(" + request + ")");
 		}
 
 		PolicyRefresher   refresher = this.refresher;
@@ -333,13 +327,13 @@ public class RangerBasePlugin {
 		}
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerAdminRESTClient.grantAccess(" + request + ")");
+			LOG.debug("<== RangerBasePlugin.grantAccess(" + request + ")");
 		}
 	}
 
 	public void revokeAccess(GrantRevokeRequest request, RangerAccessResultProcessor resultProcessor) throws Exception {
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerAdminRESTClient.revokeAccess(" + request + ")");
+			LOG.debug("==> RangerBasePlugin.revokeAccess(" + request + ")");
 		}
 
 		PolicyRefresher   refresher = this.refresher;
@@ -359,13 +353,13 @@ public class RangerBasePlugin {
 		}
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerAdminRESTClient.revokeAccess(" + request + ")");
+			LOG.debug("<== RangerBasePlugin.revokeAccess(" + request + ")");
 		}
 	}
 
 	public static RangerAdminClient createAdminClient(String rangerServiceName, String applicationId, String propertyPrefix) {
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("==> RangerAdminRESTClient.createAdminClient(" + rangerServiceName + ", " + applicationId + ", " + propertyPrefix + ")");
+			LOG.debug("==> RangerBasePlugin.createAdminClient(" + rangerServiceName + ", " + applicationId + ", " + propertyPrefix + ")");
 		}
 
 		RangerAdminClient ret = null;
@@ -398,7 +392,7 @@ public class RangerBasePlugin {
 		ret.init(rangerServiceName, applicationId, propertyPrefix);
 
 		if(LOG.isDebugEnabled()) {
-			LOG.debug("<== RangerAdminRESTClient.createAdminClient(" + rangerServiceName + ", " + applicationId + ", " + propertyPrefix + "): policySourceImpl=" + policySourceImpl + ", client=" + ret);
+			LOG.debug("<== RangerBasePlugin.createAdminClient(" + rangerServiceName + ", " + applicationId + ", " + propertyPrefix + "): policySourceImpl=" + policySourceImpl + ", client=" + ret);
 		}
 		return ret;
 	}
@@ -484,8 +478,8 @@ public class RangerBasePlugin {
 	}
 
 	static class LogHistory {
-		long lastLogTime = 0;
-		int counter=0;
+		long lastLogTime;
+		int counter;
 	}
 
 	static private final class PolicyEngineRefresher extends TimerTask {
