@@ -44,7 +44,7 @@ import org.apache.ranger.plugin.model.RangerServiceDef.RangerResourceDef;
 import org.apache.ranger.plugin.util.SearchFilter;
 
 public class AbstractPredicateUtil {
-	private static Map<String, Comparator<RangerBaseModelObject>> sorterMap  = new HashMap<String, Comparator<RangerBaseModelObject>>();
+	private static Map<String, Comparator<RangerBaseModelObject>> sorterMap  = new HashMap<>();
 
 	public void applyFilter(List<? extends RangerBaseModelObject> objList, SearchFilter filter) {
 		if(CollectionUtils.isEmpty(objList)) {
@@ -69,7 +69,7 @@ public class AbstractPredicateUtil {
 			return null;
 		}
 
-		List<Predicate> predicates = new ArrayList<Predicate>();
+		List<Predicate> predicates = new ArrayList<>();
 		
 		addPredicates(filter, predicates);
 
@@ -96,6 +96,7 @@ public class AbstractPredicateUtil {
 		addPredicateForPartialPolicyName(filter.getParam(SearchFilter.POLICY_NAME_PARTIAL), predicates);
 		addPredicateForResourceSignature(filter.getParam(SearchFilter.RESOURCE_SIGNATURE), predicates);
 		addPredicateForPolicyType(filter.getParam(SearchFilter.POLICY_TYPE), predicates);
+                addPredicateForPartialPolicyLabels(filter.getParam(SearchFilter.POLICY_LABELS_PARTIAL), predicates);
 	}
 
 	public Comparator<RangerBaseModelObject> getSorter(SearchFilter filter) {
@@ -195,8 +196,8 @@ public class AbstractPredicateUtil {
 	protected final static Comparator<RangerBaseModelObject> policyNameComparator = new Comparator<RangerBaseModelObject>() {
 		@Override
 		public int compare(RangerBaseModelObject o1, RangerBaseModelObject o2) {
-			String val1 = (o1 != null && o1 instanceof RangerPolicy) ? ((RangerPolicy)o1).getName() : null;
-			String val2 = (o2 != null && o2 instanceof RangerPolicy) ? ((RangerPolicy)o2).getName() : null;
+			String val1 = (o1 instanceof RangerPolicy) ? ((RangerPolicy)o1).getName() : null;
+			String val2 = (o2 instanceof RangerPolicy) ? ((RangerPolicy)o2).getName() : null;
 
 			return ObjectUtils.compare(val1, val2);
 		}
@@ -461,10 +462,13 @@ public class AbstractPredicateUtil {
 						List<RangerPolicyItem> policyItems = (List<RangerPolicyItem>)policyItemsObj;
 
 						for(RangerPolicyItem policyItem : policyItems) {
-							if(policyItem.getUsers().contains(userName)) {
-								ret = true;
-
-								break;
+                                                        if(! policyItem.getUsers().isEmpty()) {
+                                                                for(String user : policyItem.getUsers()) {
+                                                                        if(StringUtils.containsIgnoreCase(user, userName)) {
+                                                                                ret = true;
+                                                                                break;
+                                                                        }
+                                                                }
 							}
 						}
 						if (ret) {
@@ -516,10 +520,13 @@ public class AbstractPredicateUtil {
 						List<RangerPolicyItem> policyItems = (List<RangerPolicyItem>)policyItemsObj;
 
 						for(RangerPolicyItem policyItem : policyItems) {
-							if(policyItem.getGroups().contains(groupName)) {
-								ret = true;
-
-								break;
+                                                        if(! policyItem.getGroups().isEmpty()) {
+                                                                for(String group : policyItem.getGroups()) {
+                                                                        if(StringUtils.containsIgnoreCase(group, groupName)) {
+                                                                                ret = true;
+                                                                                break;
+                                                                        }
+                                                                }
 							}
 						}
 						if (ret) {
@@ -818,6 +825,47 @@ public class AbstractPredicateUtil {
 		return ret;
 	}
 
+        private Predicate addPredicateForPartialPolicyLabels(final String policyLabels, List<Predicate> predicates) {
+                if (StringUtils.isEmpty(policyLabels)) {
+                        return null;
+                }
+
+                Predicate ret = new Predicate() {
+                        @Override
+                        public boolean evaluate(Object object) {
+                                if (object == null) {
+                                        return false;
+                                }
+                                boolean ret = false;
+
+                                if (object instanceof RangerPolicy) {
+                                        RangerPolicy policy = (RangerPolicy) object;
+                                        //	exact match
+                                        /*if (policy.getPolicyLabels().contains(policyLabels)) {
+                                                ret = true;
+                                        }*/
+                                        /*partial match*/
+                                        for (String label :policy.getPolicyLabels()){
+                                                ret = StringUtils.containsIgnoreCase(label, policyLabels);
+                                                if(ret){
+                                                        return ret;
+                                                }
+                                        }
+
+                                } else {
+                                        ret = true;
+                                }
+                                return ret;
+                        }
+                };
+                if (predicates != null) {
+                        predicates.add(ret);
+                }
+
+                return ret;
+        }
+
+
 	public Predicate createPredicateForResourceSignature(final String policySignature) {
 
 		if (StringUtils.isEmpty(policySignature)) {
