@@ -32,6 +32,7 @@ import org.apache.ranger.plugin.model.RangerServiceDef;
 
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
+import org.apache.ranger.plugin.util.ServiceDefUtil;
 
 /*
  * This utility class deals with service-defs embedded in ranger-plugins-common
@@ -47,7 +48,7 @@ public class EmbeddedServiceDefsUtil {
 
 
 	// following servicedef list should be reviewed/updated whenever a new embedded service-def is added
-	private static final String DEFAULT_BOOTSTRAP_SERVICEDEF_LIST = "tag,hdfs,hbase,hive,kms,knox,storm,yarn,kafka,solr,atlas,nifi";
+	private static final String DEFAULT_BOOTSTRAP_SERVICEDEF_LIST = "tag,hdfs,hbase,hive,kms,knox,storm,yarn,kafka,solr,atlas,nifi,sqoop";
 	private static final String PROPERTY_SUPPORTED_SERVICE_DEFS = "ranger.supportedcomponents";
 	private Set<String> supportedServiceDefs;
 	public static final String EMBEDDED_SERVICEDEF_TAG_NAME  = "tag";
@@ -63,6 +64,7 @@ public class EmbeddedServiceDefsUtil {
 	public static final String EMBEDDED_SERVICEDEF_NIFI_NAME  = "nifi";
 	public static final String EMBEDDED_SERVICEDEF_ATLAS_NAME  = "atlas";
 	public static final String EMBEDDED_SERVICEDEF_WASB_NAME  = "wasb";
+	public static final String EMBEDDED_SERVICEDEF_SQOOP_NAME = "sqoop";
 
 	public static final String PROPERTY_CREATE_EMBEDDED_SERVICE_DEFS = "ranger.service.store.create.embedded.service-defs";
 
@@ -81,25 +83,25 @@ public class EmbeddedServiceDefsUtil {
 	private static EmbeddedServiceDefsUtil instance = new EmbeddedServiceDefsUtil();
 
 	private boolean          createEmbeddedServiceDefs = true;
-	private RangerServiceDef hdfsServiceDef  = null;
-	private RangerServiceDef hBaseServiceDef = null;
-	private RangerServiceDef hiveServiceDef  = null;
-	private RangerServiceDef kmsServiceDef   = null;
-	private RangerServiceDef knoxServiceDef  = null;
-	private RangerServiceDef stormServiceDef = null;
-	private RangerServiceDef yarnServiceDef  = null;
-	private RangerServiceDef kafkaServiceDef = null;
-	private RangerServiceDef solrServiceDef  = null;
-	private RangerServiceDef nifiServiceDef  = null;
-	private RangerServiceDef atlasServiceDef  = null;
-	private RangerServiceDef wasbServiceDef	 = null;
+	private RangerServiceDef hdfsServiceDef;
+	private RangerServiceDef hBaseServiceDef;
+	private RangerServiceDef hiveServiceDef;
+	private RangerServiceDef kmsServiceDef;
+	private RangerServiceDef knoxServiceDef;
+	private RangerServiceDef stormServiceDef;
+	private RangerServiceDef yarnServiceDef;
+	private RangerServiceDef kafkaServiceDef;
+	private RangerServiceDef solrServiceDef;
+	private RangerServiceDef nifiServiceDef;
+	private RangerServiceDef atlasServiceDef;
+	private RangerServiceDef wasbServiceDef;
+	private RangerServiceDef sqoopServiceDef;
 
-	private RangerServiceDef tagServiceDef = null;
+	private RangerServiceDef tagServiceDef;
 
-	private Gson gsonBuilder = null;
+	private Gson gsonBuilder;
 
-
-	/* private constructor to restrict instantiation of this singleton utility class */
+	/** Private constructor to restrict instantiation of this singleton utility class. */
 	private EmbeddedServiceDefsUtil() {
 		gsonBuilder = new GsonBuilder().setDateFormat("yyyyMMdd-HH:mm:ss.SSS-Z").setPrettyPrinting().create();
 	}
@@ -133,7 +135,7 @@ public class EmbeddedServiceDefsUtil {
 
 			tagServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_TAG_NAME);
 			wasbServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_WASB_NAME);
-
+			sqoopServiceDef = getOrCreateServiceDef(store, EMBEDDED_SERVICEDEF_SQOOP_NAME);
 
 			// Ensure that tag service def is updated with access types of all service defs
 			store.updateTagServiceDefForAccessTypes();
@@ -188,6 +190,10 @@ public class EmbeddedServiceDefsUtil {
         return getId(atlasServiceDef);
     }
 
+	public long getSqoopServiceDefId() {
+		return getId(sqoopServiceDef);
+	}
+
 	public long getTagServiceDefId() { return getId(tagServiceDef); }
 
 	public long getWasbServiceDefId() { return getId(wasbServiceDef); }
@@ -214,7 +220,7 @@ public class EmbeddedServiceDefsUtil {
 		try {
 			ret = store.getServiceDefByName(serviceDefName);
 			if(ret == null && createEmbeddedServiceDefs && createServiceDef) {
-				ret = loadEmbeddedServiceDef(serviceDefName);
+				ret = ServiceDefUtil.normalize(loadEmbeddedServiceDef(serviceDefName));
 
 				LOG.info("creating embedded service-def " + serviceDefName);
 				if (ret.getId() != null) {
@@ -263,7 +269,7 @@ public class EmbeddedServiceDefsUtil {
 	}
 
 	private Set<String> getSupportedServiceDef(){
-		Set<String> supportedServiceDef =new HashSet<String>();
+		Set<String> supportedServiceDef =new HashSet<>();
 		try{
 			String ranger_supportedcomponents=RangerConfiguration.getInstance().get(PROPERTY_SUPPORTED_SERVICE_DEFS, DEFAULT_BOOTSTRAP_SERVICEDEF_LIST);
 			if(StringUtils.isBlank(ranger_supportedcomponents) || "all".equalsIgnoreCase(ranger_supportedcomponents)){
@@ -274,13 +280,12 @@ public class EmbeddedServiceDefsUtil {
 				for(String element:supportedComponents){
 					if(!StringUtils.isBlank(element)){
 						element=element.toLowerCase();
-						if(!supportedServiceDef.contains(element)){
-							supportedServiceDef.add(element);
-						}
+						supportedServiceDef.add(element);
 					}
 				}
 			}
 		}catch(Exception ex){
+			LOG.error("EmbeddedServiceDefsUtil.getSupportedServiceDef(): failed", ex);
 		}
 		return supportedServiceDef;
 	}
