@@ -52,6 +52,9 @@ public class SearchFilter {
 	public static final String RESOURCE_SIGNATURE = "resourceSignature:";     // search
 	public static final String POLICY_TYPE     = "policyType";    // search
     public static final String GUID		   = "guid"; //search
+    public static final String POLICY_LABEL     = "policyLabel";    // search
+    public static final String POLICY_LABELS_PARTIAL     = "policyLabelsPartial";    // search
+    public static final String POLICY_LABEL_ID       = "policyLabelId";      // search, sort
 
 	public static final String TAG_DEF_ID                = "tagDefId";            // search
 	public static final String TAG_DEF_GUID              = "tagDefGuid";          // search
@@ -72,12 +75,12 @@ public class SearchFilter {
 	public static final String PLUGIN_ENTITY_TYPE        = "pluginEntityType";
 	public static final String PLUGIN_IP_ADDRESS         = "pluginIpAddress";
 
-	private Map<String, String> params     = null;
-	private int                 startIndex = 0;
+	private Map<String, String> params;
+	private int                 startIndex;
 	private int                 maxRows    = Integer.MAX_VALUE;
 	private boolean             getCount   = true;
-	private String              sortBy     = null;
-	private String              sortType   = null;
+	private String              sortBy;
+	private String              sortType;
 
 	public SearchFilter() {
 		this(null);
@@ -132,7 +135,7 @@ public class SearchFilter {
 
 				if(name.startsWith(prefix)) {
 					if(ret == null) {
-						ret = new HashMap<String, String>();
+						ret = new HashMap<>();
 					}
 
 					if(stripPrefix) {
