@@ -57,9 +57,8 @@ import java.util.Set;
 
 import static org.junit.Assert.*;
 
-
 public class TestPolicyEngine {
-	static Gson gsonBuilder  = null;
+	static Gson gsonBuilder;
 
 	@BeforeClass
 	public static void setUpBeforeClass() throws Exception {
@@ -152,7 +151,7 @@ public class TestPolicyEngine {
 				"                <name>ranger.plugin.tag.attr.additional.date.formats</name>\n" +
 				"                <value>abcd||xyz||yyyy/MM/dd'T'HH:mm:ss.SSS'Z'</value>\n" +
 				"        </property>\n" +
-				"</configuration>\n");
+                "</configuration>\n");
 		writer.close();
 
 		RangerConfiguration config = RangerConfiguration.getInstance();
@@ -289,6 +288,13 @@ public class TestPolicyEngine {
 		runTestsFromResourceFiles(resourceFiles);
 	}
 
+	@Test
+	public void testPolicyEngine_hiveTagMasking() {
+		String[] resourceFiles = {"/policyengine/test_policyengine_tag_hive_mask.json"};
+
+		runTestsFromResourceFiles(resourceFiles);
+	}
+
 	@Test
 	public void testPolicyEngine_owner() {
 		String[] resourceFiles = {"/policyengine/test_policyengine_owner.json"};
@@ -428,7 +434,7 @@ public class TestPolicyEngine {
 
 			if(test.result != null) {
 				RangerAccessResult expected = test.result;
-				RangerAccessResult result   = policyEngine.isAccessAllowed(request, auditHandler);
+				RangerAccessResult result   = policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_ACCESS, auditHandler);
 
 				assertNotNull("result was null! - " + test.name, result);
 				assertEquals("isAllowed mismatched! - " + test.name, expected.getIsAllowed(), result.getIsAllowed());
@@ -437,8 +443,8 @@ public class TestPolicyEngine {
 			}
 
 			if(test.dataMaskResult != null) {
-				RangerDataMaskResult expected = test.dataMaskResult;
-				RangerDataMaskResult result   = policyEngine.evalDataMaskPolicies(request, auditHandler);
+				RangerAccessResult expected = test.dataMaskResult;
+				RangerAccessResult result   = policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_DATAMASK, auditHandler);
 
 				assertNotNull("result was null! - " + test.name, result);
 				assertEquals("maskType mismatched! - " + test.name, expected.getMaskType(), result.getMaskType());
@@ -448,8 +454,8 @@ public class TestPolicyEngine {
 			}
 
 			if(test.rowFilterResult != null) {
-				RangerRowFilterResult expected = test.rowFilterResult;
-				RangerRowFilterResult result   = policyEngine.evalRowFilterPolicies(request, auditHandler);
+				RangerAccessResult expected = test.rowFilterResult;
+				RangerAccessResult result   = policyEngine.evaluatePolicies(request, RangerPolicy.POLICY_TYPE_ROWFILTER, auditHandler);
 
 				assertNotNull("result was null! - " + test.name, result);
 				assertEquals("filterExpr mismatched! - " + test.name, expected.getFilterExpr(), result.getFilterExpr());
@@ -481,8 +487,8 @@ public class TestPolicyEngine {
 			public String              name;
 			public RangerAccessRequest request;
 			public RangerAccessResult  result;
-			public RangerDataMaskResult  dataMaskResult;
-			public RangerRowFilterResult rowFilterResult;
+			public RangerAccessResult  dataMaskResult;
+			public RangerAccessResult rowFilterResult;
 			public RangerResourceAccessInfo resourceAccessInfo;
 		}
 
