@@ -55,9 +55,16 @@ import org.junit.Test;
  * b) The IT group can read and write to the "temp" table, but only the "colfam1" column family.
  * c) The QA group can read and write to tables in "test_namespace" namespace.
  *
+ * In addition we have some TAG based policies created in Atlas and synced into Ranger:
+ *
+ * a) The tag "HbaseTableTag" is associated with "create" permission to the "dev" group to the "temp3" table
+ * b) The tag "HbaseColFamTag" is associated with "read" permission to the "dev" group to the "colfam1" column family of the "temp3" table.
+ * c) The tag "HbaseColTag" is associated with "write" permission to the "dev" group to the "col1" column of the "colfam1" column family of
+ * the "temp3" table.
+ *
  * Policies available from admin via:
  * 
- * http://localhost:6080/service/plugins/policies/download/HBASETest
+ * http://localhost:6080/service/plugins/policies/download/cl1_hbase
  */
 public class HBaseRangerAuthorizationTest {
 
@@ -180,7 +187,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
         
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -222,7 +229,7 @@ public class HBaseRangerAuthorizationTest {
         conn.close();
         
         // Try to disable + delete the table as the "IT" group
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -278,7 +285,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
 
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -306,7 +313,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
 
-        String user = getNotCurrentUser();
+        String user = "public";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"public"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -317,8 +324,9 @@ public class HBaseRangerAuthorizationTest {
                 // Read a row
                 try {
                     Get get = new Get(Bytes.toBytes("row1"));
-                    table.get(get);
-                    Assert.fail("Failure expected on an unauthorized user");
+                    Result result = table.get(get);
+                    byte[] valResult = result.getValue(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"));
+                    Assert.assertNull("Failure expected on an unauthorized user", valResult);
                 } catch (IOException ex) {
                     // expected
                 }
@@ -355,7 +363,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
 
-        String user = getNotCurrentUser();
+        String user = "public";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -400,7 +408,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
 
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -426,7 +434,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
 
-        String user = getNotCurrentUser();
+        String user = "public";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"public"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -457,7 +465,7 @@ public class HBaseRangerAuthorizationTest {
         conf.set("hbase.zookeeper.property.clientPort", "" + port);
         conf.set("zookeeper.znode.parent", "/hbase-unsecure");
 
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -515,7 +523,7 @@ public class HBaseRangerAuthorizationTest {
         conn.close();
         
         // Now try to read the row as group "IT" - it should fail as "IT" can only read from table "temp"
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -526,8 +534,9 @@ public class HBaseRangerAuthorizationTest {
                 // Read a row
                 try {
                     Get get = new Get(Bytes.toBytes("row1"));
-                    table.get(get);
-                    Assert.fail("Failure expected on an unauthorized user");
+                    Result result = table.get(get);
+                    byte[] valResult = result.getValue(Bytes.toBytes("colfam2"), Bytes.toBytes("col1"));
+                    Assert.assertNull("Failure expected on an unauthorized user", valResult);
                 } catch (IOException ex) {
                     // expected
                 }
@@ -583,7 +592,7 @@ public class HBaseRangerAuthorizationTest {
         put.addColumn(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"), Bytes.toBytes("val2"));
         table.put(put);
 
-        String user = getNotCurrentUser();
+        String user = "IT";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
         ugi.doAs(new PrivilegedExceptionAction<Void>() {
@@ -626,7 +635,7 @@ public class HBaseRangerAuthorizationTest {
         if (CollectionUtils.isNotEmpty(snapshots)) {
             admin.deleteSnapshot("test_snapshot");
         }
-        String user = getNotCurrentUser();
+        String user = "QA";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[]{"QA"});
 
@@ -661,6 +670,7 @@ public class HBaseRangerAuthorizationTest {
             admin.deleteSnapshot("test_snapshot");
         }
     }
+
     @Test
     public void testCloneSnapshotAsNonQAGroup() throws Exception {
         final Configuration conf = HBaseConfiguration.create();
@@ -682,7 +692,7 @@ public class HBaseRangerAuthorizationTest {
 
         admin.enableTable(tableName);
 
-        String user = getNotCurrentUser();
+        String user = "public";
 
         UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"public"});
 
@@ -715,6 +725,242 @@ public class HBaseRangerAuthorizationTest {
         admin.deleteSnapshot("test_snapshot");
     }
 
+    @Test
+    public void testTagBasedTablePolicy() throws Exception {
+        final Configuration conf = HBaseConfiguration.create();
+        conf.set("hbase.zookeeper.quorum", "localhost");
+        conf.set("hbase.zookeeper.property.clientPort", "" + port);
+        conf.set("zookeeper.znode.parent", "/hbase-unsecure");
+
+        final HTableDescriptor tableDescriptor = new HTableDescriptor(TableName.valueOf("temp3"));
+
+        // Adding column families to table descriptor
+        tableDescriptor.addFamily(new HColumnDescriptor("colfam1"));
+        tableDescriptor.addFamily(new HColumnDescriptor("colfam2"));
+
+        // Try to create a "temp3" table as the "IT" group - this should fail
+        String user = "IT";
+
+        // Try to create the table as the "IT" group - this should fail
+        UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"IT"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+            public Void run() throws Exception {
+                Connection conn = ConnectionFactory.createConnection(conf);
+                Admin admin = conn.getAdmin();
+
+                try {
+                    admin.createTable(tableDescriptor);
+                    Assert.fail("Failure expected on an unauthorized user");
+                } catch (IOException ex) {
+                    // expected
+                }
+
+                conn.close();
+                return null;
+            }
+        });
+
+        // Now try to create the table as the "dev" group - this should work
+        ugi = UserGroupInformation.createUserForTesting("dev", new String[] {"dev"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+            public Void run() throws Exception {
+                Connection conn = ConnectionFactory.createConnection(conf);
+                Admin admin = conn.getAdmin();
+
+                admin.createTable(tableDescriptor);
+
+                conn.close();
+                return null;
+            }
+        });
+
+        // Drop the table
+        Connection conn = ConnectionFactory.createConnection(conf);
+        Admin admin = conn.getAdmin();
+
+        admin.disableTable(TableName.valueOf("temp3"));
+        admin.deleteTable(TableName.valueOf("temp3"));
+
+        conn.close();
+    }
+
+    @Test
+    public void testTagBasedColumnFamilyPolicy() throws Exception {
+        final Configuration conf = HBaseConfiguration.create();
+        conf.set("hbase.zookeeper.quorum", "localhost");
+        conf.set("hbase.zookeeper.property.clientPort", "" + port);
+        conf.set("zookeeper.znode.parent", "/hbase-unsecure");
+
+        // Create a new table as process owner
+        final HTableDescriptor tableDescriptor = new HTableDescriptor(TableName.valueOf("temp3"));
+
+        // Adding column families to table descriptor
+        tableDescriptor.addFamily(new HColumnDescriptor("colfam1"));
+        tableDescriptor.addFamily(new HColumnDescriptor("colfam2"));
+
+        Connection conn = ConnectionFactory.createConnection(conf);
+        Admin admin = conn.getAdmin();
+
+        admin.createTable(tableDescriptor);
+
+        // Add a new row
+        Put put = new Put(Bytes.toBytes("row1"));
+        put.addColumn(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"), Bytes.toBytes("val1"));
+        Table table = conn.getTable(TableName.valueOf("temp3"));
+        table.put(put);
+
+        put = new Put(Bytes.toBytes("row1"));
+        put.addColumn(Bytes.toBytes("colfam2"), Bytes.toBytes("col1"), Bytes.toBytes("val2"));
+        table.put(put);
+
+        conn.close();
+
+        String user = "dev";
+        UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"dev"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+            public Void run() throws Exception {
+                Connection conn = ConnectionFactory.createConnection(conf);
+                Table table = conn.getTable(TableName.valueOf("temp3"));
+
+                // Try to read the "colfam1" of the "temp3" table as the "dev" group - this should work
+                Get get = new Get(Bytes.toBytes("row1"));
+                Result result = table.get(get);
+                byte[] valResult = result.getValue(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"));
+                Assert.assertTrue(Arrays.equals(valResult, Bytes.toBytes("val1")));
+
+                // Now try to read the "colfam2" column family of the temp3 table - this should fail
+                get = new Get(Bytes.toBytes("row1"));
+                result = table.get(get);
+                valResult = result.getValue(Bytes.toBytes("colfam2"), Bytes.toBytes("col1"));
+                Assert.assertNull(valResult);
+
+                conn.close();
+                return null;
+            }
+        });
+
+        // Now try to read colfam1 as the "IT" group - this should fail
+        ugi = UserGroupInformation.createUserForTesting("IT", new String[] {"IT"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+            public Void run() throws Exception {
+                Connection conn = ConnectionFactory.createConnection(conf);
+                Table table = conn.getTable(TableName.valueOf("temp3"));
+
+                Get get = new Get(Bytes.toBytes("row1"));
+                try {
+                    Result result = table.get(get);
+                    byte[] valResult = result.getValue(Bytes.toBytes("colfam2"), Bytes.toBytes("col1"));
+                    Assert.assertNull("Failure expected on an unauthorized user", valResult);
+                } catch (IOException ex) {
+                    // expected
+                }
+
+                return null;
+            }
+        });
+
+        // Drop the table
+        conn = ConnectionFactory.createConnection(conf);
+        admin = conn.getAdmin();
+
+        admin.disableTable(TableName.valueOf("temp3"));
+        admin.deleteTable(TableName.valueOf("temp3"));
+
+        conn.close();
+    }
+
+    @Test
+    public void testTagBasedColumnPolicy() throws Exception {
+        final Configuration conf = HBaseConfiguration.create();
+        conf.set("hbase.zookeeper.quorum", "localhost");
+        conf.set("hbase.zookeeper.property.clientPort", "" + port);
+        conf.set("zookeeper.znode.parent", "/hbase-unsecure");
+
+        // Create a new table as process owner
+        final HTableDescriptor tableDescriptor = new HTableDescriptor(TableName.valueOf("temp3"));
+
+        // Adding column families to table descriptor
+        tableDescriptor.addFamily(new HColumnDescriptor("colfam1"));
+        tableDescriptor.addFamily(new HColumnDescriptor("colfam2"));
+
+        Connection conn = ConnectionFactory.createConnection(conf);
+        Admin admin = conn.getAdmin();
+
+        admin.createTable(tableDescriptor);
+
+        // Add a new row
+        Put put = new Put(Bytes.toBytes("row1"));
+        put.addColumn(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"), Bytes.toBytes("val1"));
+        Table table = conn.getTable(TableName.valueOf("temp3"));
+        table.put(put);
+
+        put = new Put(Bytes.toBytes("row1"));
+        put.addColumn(Bytes.toBytes("colfam2"), Bytes.toBytes("col1"), Bytes.toBytes("val2"));
+        table.put(put);
+
+        conn.close();
+
+        String user = "dev";
+        UserGroupInformation ugi = UserGroupInformation.createUserForTesting(user, new String[] {"dev"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+            public Void run() throws Exception {
+                Connection conn = ConnectionFactory.createConnection(conf);
+                Table table = conn.getTable(TableName.valueOf("temp3"));
+
+                // Try to write something to the "col1" column of the "colfam1" of the "temp3" table as the "dev" group
+                // - this should work
+                Put put = new Put(Bytes.toBytes("row3"));
+                put.addColumn(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"), Bytes.toBytes("val2"));
+                table.put(put);
+
+                // Try to write something to the "col2" column of the "colfam1" of the "temp3" table as the "dev" group
+                // - this should fail
+                put = new Put(Bytes.toBytes("row3"));
+                put.addColumn(Bytes.toBytes("colfam1"), Bytes.toBytes("col2"), Bytes.toBytes("val2"));
+                try {
+                    table.put(put);
+                    Assert.fail("Failure expected on an unauthorized user");
+                } catch (IOException ex) {
+                    // expected
+                }
+
+                conn.close();
+                return null;
+            }
+        });
+
+        ugi = UserGroupInformation.createUserForTesting("IT", new String[] {"IT"});
+        ugi.doAs(new PrivilegedExceptionAction<Void>() {
+            public Void run() throws Exception {
+                Connection conn = ConnectionFactory.createConnection(conf);
+                Table table = conn.getTable(TableName.valueOf("temp3"));
+
+                // Try to write something to the "col1" column of the "colfam1" of the "temp3" table as the "IT" group
+                // - this should fail
+                Put put = new Put(Bytes.toBytes("row3"));
+                put.addColumn(Bytes.toBytes("colfam1"), Bytes.toBytes("col1"), Bytes.toBytes("val2"));
+                try {
+                    table.put(put);
+                    Assert.fail("Failure expected on an unauthorized user");
+                } catch (IOException ex) {
+                    // expected
+                }
+
+                conn.close();
+                return null;
+            }
+        });
+
+        // Drop the table
+        conn = ConnectionFactory.createConnection(conf);
+        admin = conn.getAdmin();
+
+        admin.disableTable(TableName.valueOf("temp3"));
+        admin.deleteTable(TableName.valueOf("temp3"));
+
+        conn.close();
+    }
+
     private static int getFreePort() throws IOException {
         ServerSocket serverSocket = new ServerSocket(0);
         int port = serverSocket.getLocalPort();
@@ -722,7 +968,4 @@ public class HBaseRangerAuthorizationTest {
         return port;
     }
 
-    private static String getNotCurrentUser() {
-        return "not-" + System.getProperty("user.name");
-    }
 }
