@@ -36,8 +36,15 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.fs.permission.FsAction;
 import org.apache.hadoop.hive.common.FileUtils;
 import org.apache.hadoop.hive.conf.HiveConf;
+import org.apache.hadoop.hive.metastore.IMetaStoreClient;
+import org.apache.hadoop.hive.metastore.api.HiveObjectPrivilege;
+import org.apache.hadoop.hive.metastore.api.HiveObjectRef;
+import org.apache.hadoop.hive.metastore.api.PrincipalType;
+import org.apache.hadoop.hive.metastore.api.PrivilegeGrantInfo;
+import org.apache.hadoop.hive.ql.metadata.HiveException;
 import org.apache.hadoop.hive.ql.parse.SemanticException;
 import org.apache.hadoop.hive.ql.security.HiveAuthenticationProvider;
+import org.apache.hadoop.hive.ql.security.authorization.AuthorizationUtils;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveAccessControlException;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveAuthzContext;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveAuthzPluginException;
@@ -46,6 +53,7 @@ import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveMetastoreClie
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HiveOperationType;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrincipal;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilege;
+import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilegeInfo;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilegeObject;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilegeObject.HivePrivObjectActionType;
 import org.apache.hadoop.hive.ql.security.authorization.plugin.HivePrivilegeObject.HivePrivilegeObjectType;
@@ -58,19 +66,20 @@ import org.apache.ranger.plugin.model.RangerPolicy;
 import org.apache.ranger.plugin.model.RangerServiceDef.RangerDataMaskTypeDef;
 import org.apache.ranger.plugin.policyengine.RangerAccessRequest;
 import org.apache.ranger.plugin.policyengine.RangerAccessResult;
-import org.apache.ranger.plugin.policyengine.RangerDataMaskResult;
-import org.apache.ranger.plugin.policyengine.RangerRowFilterResult;
 import org.apache.ranger.plugin.service.RangerBasePlugin;
 import org.apache.ranger.plugin.util.GrantRevokeRequest;
 import org.apache.ranger.plugin.util.RangerAccessRequestUtil;
 
 import com.google.common.collect.Sets;
 
+import org.apache.ranger.plugin.util.RangerPerfTracer;
 import org.apache.ranger.plugin.util.RangerRequestedResources;
 
 public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 	private static final Log LOG = LogFactory.getLog(RangerHiveAuthorizer.class);
 
+	private static final Log PERF_HIVEAUTH_REQUEST_LOG = RangerPerfTracer.getPerfLogger("hiveauth.request");
+
 	private static final char COLUMN_SEP = ',';
 
 	private static final String HIVE_CONF_VAR_QUERY_STRING = "hive.query.string";
@@ -221,6 +230,8 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 
 		RangerHiveAuditHandler auditHandler = new RangerHiveAuditHandler();
 
+		RangerPerfTracer perf = null;
+
 		try {
 			HiveAuthzSessionContext sessionContext = getHiveAuthzSessionContext();
 			String                  user           = ugi.getShortUserName();
@@ -237,6 +248,10 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 				return;
 			}
 
+			if(RangerPerfTracer.isPerfTraceEnabled(PERF_HIVEAUTH_REQUEST_LOG)) {
+				perf = RangerPerfTracer.getPerfTracer(PERF_HIVEAUTH_REQUEST_LOG, "RangerHiveAuthorizer.checkPrivileges(hiveOpType=" + hiveOpType + ")");
+			}
+
 			List<RangerHiveAccessRequest> requests = new ArrayList<RangerHiveAccessRequest>();
 
 			if(!CollectionUtils.isEmpty(inputHObjs)) {
@@ -376,11 +391,11 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 					request.setHiveAccessType(HiveAccessType.SELECT); // filtering/masking policies are defined only for SELECT
 					request.setResource(tblResource);
 
-					RangerRowFilterResult rowFilterResult = getRowFilterResult(request);
+					RangerAccessResult rowFilterResult = getRowFilterResult(request);
 
 					if (isRowFilterEnabled(rowFilterResult)) {
 						if(result == null) {
-							result = new RangerAccessResult(rowFilterResult.getServiceName(), rowFilterResult.getServiceDef(), request);
+							result = new RangerAccessResult(RangerPolicy.POLICY_TYPE_ACCESS, rowFilterResult.getServiceName(), rowFilterResult.getServiceDef(), request);
 						}
 
 						result.setIsAllowed(false);
@@ -390,16 +405,16 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 						// check if masking is enabled for any column in the table/view
 						request.setResourceMatchingScope(RangerAccessRequest.ResourceMatchingScope.SELF_OR_DESCENDANTS);
 
-						RangerDataMaskResult dataMaskResult = getDataMaskResult(request);
+						RangerAccessResult dataMaskResult = getDataMaskResult(request);
 
 						if (isDataMaskEnabled(dataMaskResult)) {
 							if(result == null) {
-								result = new RangerAccessResult(dataMaskResult.getServiceName(), dataMaskResult.getServiceDef(), request);
+								result = new RangerAccessResult(RangerPolicy.POLICY_TYPE_ACCESS, dataMaskResult.getServiceName(), dataMaskResult.getServiceDef(), request);
 							}
 
 							result.setIsAllowed(false);
 							result.setPolicyId(dataMaskResult.getPolicyId());
-							result.setReason("User does not have acces to unmasked column values");
+							result.setReason("User does not have access to unmasked column values");
 						}
 					}
 
@@ -420,6 +435,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			}
 		} finally {
 			auditHandler.flushAudit();
+			RangerPerfTracer.log(perf);
 		}
 	}
 
@@ -439,7 +455,13 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug(String.format("==> filterListCmdObjects(%s, %s)", objs, context));
 		}
-		
+
+		RangerPerfTracer perf = null;
+
+		if(RangerPerfTracer.isPerfTraceEnabled(PERF_HIVEAUTH_REQUEST_LOG)) {
+			perf = RangerPerfTracer.getPerfTracer(PERF_HIVEAUTH_REQUEST_LOG, "RangerHiveAuthorizer.filterListCmdObjects()");
+		}
+
 		List<HivePrivilegeObject> ret = null;
 
 		// bail out early if nothing is there to validate!
@@ -509,6 +531,8 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			}
 		}
 
+		RangerPerfTracer.log(perf);
+
 		if (LOG.isDebugEnabled()) {
 			int count = ret == null ? 0 : ret.size();
 			LOG.debug(String.format("<== filterListCmdObjects: count[%d], ret[%s]", count, ret));
@@ -524,6 +548,12 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			LOG.debug("==> applyRowFilterAndColumnMasking(" + queryContext + ", objCount=" + hiveObjs.size() + ")");
 		}
 
+		RangerPerfTracer perf = null;
+
+		if(RangerPerfTracer.isPerfTraceEnabled(PERF_HIVEAUTH_REQUEST_LOG)) {
+			perf = RangerPerfTracer.getPerfTracer(PERF_HIVEAUTH_REQUEST_LOG, "RangerHiveAuthorizer.applyRowFilterAndColumnMasking()");
+		}
+
 		if(CollectionUtils.isNotEmpty(hiveObjs)) {
 			for (HivePrivilegeObject hiveObj : hiveObjs) {
 				HivePrivilegeObjectType hiveObjType = hiveObj.getType();
@@ -576,6 +606,8 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			}
 		}
 
+		RangerPerfTracer.log(perf);
+
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("<== applyRowFilterAndColumnMasking(" + queryContext + ", objCount=" + hiveObjs.size() + "): retCount=" + ret.size());
 		}
@@ -588,12 +620,12 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return true; // TODO: derive from the policies
 	}
 
-	private RangerDataMaskResult getDataMaskResult(RangerHiveAccessRequest request) {
+	private RangerAccessResult getDataMaskResult(RangerHiveAccessRequest request) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> getDataMaskResult(request=" + request + ")");
 		}
 
-		RangerDataMaskResult ret = hivePlugin.evalDataMaskPolicies(request, null);
+		RangerAccessResult ret = hivePlugin.evalDataMaskPolicies(request, null);
 
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("<== getDataMaskResult(request=" + request + "): ret=" + ret);
@@ -602,12 +634,12 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return ret;
 	}
 
-	private RangerRowFilterResult getRowFilterResult(RangerHiveAccessRequest request) {
+	private RangerAccessResult getRowFilterResult(RangerHiveAccessRequest request) {
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("==> getRowFilterResult(request=" + request + ")");
 		}
 
-		RangerRowFilterResult ret = hivePlugin.evalRowFilterPolicies(request, null);
+		RangerAccessResult ret = hivePlugin.evalRowFilterPolicies(request, null);
 
 		if(LOG.isDebugEnabled()) {
 			LOG.debug("<== getRowFilterResult(request=" + request + "): ret=" + ret);
@@ -616,11 +648,11 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return ret;
 	}
 
-	private boolean isDataMaskEnabled(RangerDataMaskResult result) {
-		return result != null && result.isMaskEnabled() && !StringUtils.equalsIgnoreCase(result.getMaskType(), RangerPolicy.MASK_TYPE_NONE);
+	private boolean isDataMaskEnabled(RangerAccessResult result) {
+		return result != null && result.isMaskEnabled();
 	}
 
-	private boolean isRowFilterEnabled(RangerRowFilterResult result) {
+	private boolean isRowFilterEnabled(RangerAccessResult result) {
 		return result != null && result.isRowFilterEnabled() && StringUtils.isNotEmpty(result.getFilterExpr());
 	}
 
@@ -648,7 +680,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			RangerHiveResource      resource       = new RangerHiveResource(objectType, databaseName, tableOrViewName);
 			RangerHiveAccessRequest request        = new RangerHiveAccessRequest(resource, user, groups, objectType.name(), HiveAccessType.SELECT, context, sessionContext, clusterName);
 
-			RangerRowFilterResult result = hivePlugin.evalRowFilterPolicies(request, auditHandler);
+			RangerAccessResult result = hivePlugin.evalRowFilterPolicies(request, auditHandler);
 
 			if(isRowFilterEnabled(result)) {
 				ret = result.getFilterExpr();
@@ -689,7 +721,7 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 			RangerHiveResource      resource       = new RangerHiveResource(objectType, databaseName, tableOrViewName, columnName);
 			RangerHiveAccessRequest request        = new RangerHiveAccessRequest(resource, user, groups, objectType.name(), HiveAccessType.SELECT, context, sessionContext, clusterName);
 
-			RangerDataMaskResult result = hivePlugin.evalDataMaskPolicies(request, auditHandler);
+			RangerAccessResult result = hivePlugin.evalDataMaskPolicies(request, auditHandler);
 
 			ret = isDataMaskEnabled(result);
 
@@ -803,6 +835,9 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 
 	private HiveObjectType getObjectType(HivePrivilegeObject hiveObj, HiveOperationType hiveOpType) {
 		HiveObjectType objType = HiveObjectType.NONE;
+		if (hiveObj.getType() == null) {
+			return HiveObjectType.DATABASE;
+		}
 
 		switch(hiveObj.getType()) {
 			case DATABASE:
@@ -1255,8 +1290,8 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		boolean ret = false;
 		String[] fsScheme = hivePlugin.getFSScheme();
 		if (fsScheme != null) {
-			for (int i = 0; i < fsScheme.length; i++) {
-				if (!uri.isEmpty() && uri.startsWith(fsScheme[i])) {
+			for (String scheme : fsScheme) {
+				if (!uri.isEmpty() && uri.startsWith(scheme)) {
 					ret = true;
 					break;
 				}
@@ -1419,6 +1454,107 @@ public class RangerHiveAuthorizer extends RangerHiveAuthorizerBase {
 		return ret;
 	}
 
+	@Override
+	public List<HivePrivilegeInfo> showPrivileges(HivePrincipal principal,
+			HivePrivilegeObject privObj) throws HiveAuthzPluginException {
+		try {
+
+			LOG.debug("RangerHiveAuthorizer.showPrivileges()");
+			IMetaStoreClient mClient = getMetastoreClientFactory()
+					.getHiveMetastoreClient();
+			List<HivePrivilegeInfo> resPrivInfos = new ArrayList<HivePrivilegeInfo>();
+			String principalName = null;
+			PrincipalType principalType = null;
+			if (principal != null) {
+				principalName = principal.getName();
+				principalType = AuthorizationUtils
+						.getThriftPrincipalType(principal.getType());
+			}
+
+			List<HiveObjectPrivilege> msObjPrivs = mClient.list_privileges(
+					principalName, principalType,
+					this.getThriftHiveObjectRef(privObj));
+			if (msObjPrivs != null) {
+				for (HiveObjectPrivilege msObjPriv : msObjPrivs) {
+					HiveObjectRef msObjRef = msObjPriv.getHiveObject();
+					org.apache.hadoop.hive.metastore.api.HiveObjectType objectType = msObjRef
+							.getObjectType();
+					if (!isSupportedObjectType(objectType)) {
+						continue;
+					}
+					HivePrincipal resPrincipal = new HivePrincipal(
+							msObjPriv.getPrincipalName(),
+							AuthorizationUtils.getHivePrincipalType(msObjPriv
+									.getPrincipalType()));
+
+					PrivilegeGrantInfo msGrantInfo = msObjPriv.getGrantInfo();
+					HivePrivilege resPrivilege = new HivePrivilege(
+							msGrantInfo.getPrivilege(), null);
+
+					HivePrivilegeObject resPrivObj = new HivePrivilegeObject(
+							getPluginPrivilegeObjType(objectType),
+							msObjRef.getDbName(), msObjRef.getObjectName(),
+							msObjRef.getPartValues(), msObjRef.getColumnName());
+
+					HivePrincipal grantorPrincipal = new HivePrincipal(
+							msGrantInfo.getGrantor(),
+							AuthorizationUtils.getHivePrincipalType(msGrantInfo
+									.getGrantorType()));
+
+					HivePrivilegeInfo resPrivInfo = new HivePrivilegeInfo(
+							resPrincipal, resPrivilege, resPrivObj,
+							grantorPrincipal, msGrantInfo.isGrantOption(),
+							msGrantInfo.getCreateTime());
+					resPrivInfos.add(resPrivInfo);
+				}
+
+			} else {
+				throw new HiveAccessControlException(
+						"RangerHiveAuthorizer.showPrivileges():User has to specify"
+								+ " a user name or role in the show grant. ");
+			}
+			return resPrivInfos;
+
+		} catch (Exception e) {
+			LOG.error("RangerHiveAuthorizer.showPrivileges: showPrivileges returned by showPrivileges is null");
+			throw new HiveAuthzPluginException("hive showPrivileges" + ": "
+					+ e.getMessage(), e);
+		}
+	}
+
+	private boolean isSupportedObjectType(
+			org.apache.hadoop.hive.metastore.api.HiveObjectType objectType) {
+		switch (objectType) {
+		case DATABASE:
+		case TABLE:
+			return true;
+		default:
+			return false;
+		}
+
+	}
+
+	private HivePrivilegeObjectType getPluginPrivilegeObjType(
+			org.apache.hadoop.hive.metastore.api.HiveObjectType objectType) {
+		switch (objectType) {
+		case DATABASE:
+			return HivePrivilegeObjectType.DATABASE;
+		case TABLE:
+			return HivePrivilegeObjectType.TABLE_OR_VIEW;
+		default:
+			throw new AssertionError("Unexpected object type " + objectType);
+		}
+	}
+
+	static HiveObjectRef getThriftHiveObjectRef(HivePrivilegeObject privObj)
+			throws HiveAuthzPluginException {
+		try {
+			return AuthorizationUtils.getThriftHiveObjectRef(privObj);
+		} catch (HiveException e) {
+			throw new HiveAuthzPluginException(e);
+		}
+	}
+
 	private RangerRequestedResources buildRequestContextWithAllAccessedResources(List<RangerHiveAccessRequest> requests) {
 
 		RangerRequestedResources requestedResources = new RangerRequestedResources();
