@@ -46,10 +46,16 @@ public class RangerHiveResource extends RangerAccessResourceImpl {
 
 		switch(objectType) {
 			case DATABASE:
+				if (databaseorUrl == null) {
+					databaseorUrl = "*";
+				}
 				setValue(KEY_DATABASE, databaseorUrl);
 			break;
-	
+
 			case FUNCTION:
+				if (databaseorUrl == null) {
+					databaseorUrl = "";
+				}
 				setValue(KEY_DATABASE, databaseorUrl);
 				setValue(KEY_UDF, tableOrUdf);
 			break;
