@@ -50,6 +50,7 @@ import org.apache.hadoop.hive.metastore.api.FieldSchema;
 import org.apache.hadoop.hive.metastore.api.MetaException;
 import org.apache.ranger.plugin.client.BaseClient;
 import org.apache.ranger.plugin.client.HadoopException;
+import org.apache.ranger.plugin.util.PasswordUtils;
 import org.apache.thrift.TException;
 
 public class HiveClient extends BaseClient implements Closeable {
@@ -112,7 +113,7 @@ public class HiveClient extends BaseClient implements Closeable {
 					} else {
 						ret = getDBList(dbMatching,dbList);
 					}
-				} catch ( HadoopException he) {
+				} catch (HadoopException he) {
 					LOG.error("<== HiveClient getDatabaseList() :Unable to get the Database List", he);
 					throw he;
 				}
@@ -146,8 +147,7 @@ public class HiveClient extends BaseClient implements Closeable {
 			}
 		} catch (MetaException e) {
 			String msgDesc = "Unable to get Database";
-			HadoopException hdpException = new HadoopException(msgDesc,
-					e);
+			HadoopException hdpException = new HadoopException(msgDesc, e);
 			hdpException.generateResponseDataMap(false, getMessage(e),
 					msgDesc + ERR_MSG, null, null);
 			if (LOG.isDebugEnabled()) {
@@ -156,13 +156,13 @@ public class HiveClient extends BaseClient implements Closeable {
 			throw hdpException;
 		}
 		if (LOG.isDebugEnabled()) {
-			  LOG.debug("<== HiveClient.getDBListFromHM(): " + ret);
+			LOG.debug("<== HiveClient.getDBListFromHM(): " + ret);
 		}
 		return ret;
 	}
 		
 	private List<String> getDBList(String databaseMatching, List<String>dbList) throws  HadoopException {
-		if(LOG.isDebugEnabled()) {
+		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> HiveClient getDBList databaseMatching : " + databaseMatching + " ExcludedbList :" + dbList);
 		}
 
@@ -171,7 +171,7 @@ public class HiveClient extends BaseClient implements Closeable {
 			Statement stat =  null;
 			ResultSet rs = null;
 			String sql = "show databases";
-			if (databaseMatching != null && ! databaseMatching.isEmpty()) {
+			if (databaseMatching != null && !databaseMatching.isEmpty()) {
 				sql = sql + " like \"" + databaseMatching  + "\"";
 			}
 			try {
@@ -233,8 +233,8 @@ public class HiveClient extends BaseClient implements Closeable {
 					} else {
 						ret = getTblList(tblNameMatching,dbList,tblList);
 					}
-				} catch(HadoopException he) {
-					LOG.error("<== HiveClient getTblList() :Unable to get the Table List", he);
+				} catch (HadoopException he) {
+					LOG.error("<== HiveClient getTableList() :Unable to get the Table List", he);
 					throw he;
 				}
 				return ret;
@@ -257,7 +257,7 @@ public class HiveClient extends BaseClient implements Closeable {
 						if (tblList != null && tblList.contains(tblName)) {
 							continue;
 						}
-                        ret.add(tblName);
+						ret.add(tblName);
 					}
 				} catch (MetaException e) {
 					String msgDesc = "Unable to get Table.";
@@ -276,9 +276,9 @@ public class HiveClient extends BaseClient implements Closeable {
 		return ret;
 	}
 
-	public List<String> getTblList(String tableNameMatching, List<String> dbList, List<String> tblList) throws HadoopException {
+	private List<String> getTblList(String tableNameMatching, List<String> dbList, List<String> tblList) throws HadoopException {
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("==> HiveClient getTableList() tableNameMatching : " + tableNameMatching + " ExcludedbList :" + dbList + "ExcludeTableList :" + tblList);
+			LOG.debug("==> HiveClient getTblList() tableNameMatching : " + tableNameMatching + " ExcludedbList :" + dbList + "ExcludeTableList :" + tblList);
 		}
 
 		List<String> ret = new ArrayList<String>();
@@ -311,7 +311,7 @@ public class HiveClient extends BaseClient implements Closeable {
                             rs = stat.executeQuery(sql);
 							while (rs.next()) {
                                 String tblName = rs.getString(1);
-                                if (tblList != null && tblList.contains(tblName)) {
+								if (tblList != null	&& tblList.contains(tblName)) {
                                     continue;
                                 }
                                 ret.add(tblName);
@@ -350,7 +350,7 @@ public class HiveClient extends BaseClient implements Closeable {
 		}
 
 		if (LOG.isDebugEnabled()) {
-			LOG.debug("<== HiveClient getTableList() " +  ret);
+			LOG.debug("<== HiveClient getTblList() " +  ret);
 		}
 
 		return ret;
@@ -389,7 +389,7 @@ public class HiveClient extends BaseClient implements Closeable {
 			});
 		return columnList;
 	}
-	
+
 	private List<String> getClmListFromHM(String columnNameMatching,List<String> dbList, List<String> tblList, List<String> colList) throws HadoopException {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> HiveClient.getClmListFromHM() columnNameMatching: " + columnNameMatching + " dbList :" + dbList +  " tblList: " + tblList + " colList: " + colList);
@@ -436,7 +436,7 @@ public class HiveClient extends BaseClient implements Closeable {
 		return ret;
 	}
 
-	public List<String> getClmList(String columnNameMatching,List<String> dbList, List<String> tblList, List<String> colList) throws HadoopException {
+	private List<String> getClmList(String columnNameMatching,List<String> dbList, List<String> tblList, List<String> colList) throws HadoopException {
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("==> HiveClient.getClmList() columnNameMatching: " + columnNameMatching + " dbList :" + dbList +  " tblList: " + tblList + " colList: " + colList);
 		}
@@ -582,7 +582,7 @@ public class HiveClient extends BaseClient implements Closeable {
 					if (f.exists()) {
 						conf.addResource(f.toURI().toURL());
 					} else {
-						if (LOG.isDebugEnabled()) {
+						if(LOG.isDebugEnabled()) {
 							LOG.debug("Hive site conf file path " + hiveSiteFilePath + " does not exists for Hive Metastore lookup");
 						}
 					}
@@ -620,7 +620,7 @@ public class HiveClient extends BaseClient implements Closeable {
 					LOG.debug(msgDesc, hdpException);
 				}
 				throw hdpException;
-			} catch (Throwable t) {
+			} catch ( Throwable t) {
 				String msgDesc = "Unable to connect to Hive Thrift Server instance";
 				HadoopException hdpException = new HadoopException(msgDesc, t);
 				hdpException.generateResponseDataMap(false, getMessage(t), msgDesc + ERR_MSG, null, null);
@@ -705,13 +705,24 @@ public class HiveClient extends BaseClient implements Closeable {
 				}
 			}
 
+			String decryptedPwd = null;
 			try {
-				
+				decryptedPwd = PasswordUtils.decryptPassword(password);
+			} catch (Exception ex) {
+				LOG.info("Password decryption failed; trying Hive connection with received password string");
+				decryptedPwd = null;
+			} finally {
+				if (decryptedPwd == null) {
+					decryptedPwd = password;
+				}
+			}
+
+			try {
+
 				if (userName == null && password == null) {
 					con = DriverManager.getConnection(url);
-				}
-				else {
-					con = DriverManager.getConnection(url, userName, password);
+				} else {
+					con = DriverManager.getConnection(url, userName, decryptedPwd);
 				}
 			} catch (SQLException e) {
 				String msgDesc = "Unable to connect to Hive Thrift Server instance.";
@@ -779,8 +790,7 @@ public class HiveClient extends BaseClient implements Closeable {
 				List<String> tableList = hc.getTableList(args[2],null,null);
 				if (tableList.size() == 0) {
 					System.out.println("No tables found under database[" + args[1] + "] with table filter [" + args[2] + "]");
-				}
-				else {
+				} else {
 					for (String str : tableList) {
 						System.out.println("Table: " + str);
 					}
@@ -790,8 +800,7 @@ public class HiveClient extends BaseClient implements Closeable {
 				List<String> columnList = hc.getColumnList(args[3],null,null,null);
 				if (columnList.size() == 0) {
 					System.out.println("No columns found for db:" + args[1] + ", table: [" + args[2] + "], with column filter [" + args[3] + "]");
-				}
-				else {
+				} else {
 					for (String str : columnList) {
 						System.out.println("Column: " + str);
 					}
@@ -833,7 +842,7 @@ public class HiveClient extends BaseClient implements Closeable {
 			}
 		} catch (Exception e) {
 			throw e;
-		} finally  {
+		} finally {
 			if (connectionObj != null) {
 				connectionObj.close();
 			}
