@@ -33,12 +33,10 @@ is_unix = os_name == "LINUX" or os_name == "DARWIN"
 
 jisql_debug=True
 masked_pwd_string='********'
-if is_unix:
-	RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
-	if RANGER_KMS_HOME is None:
-		RANGER_KMS_HOME = os.getcwd()
-elif os_name == "WINDOWS":
-	RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
+
+RANGER_KMS_HOME = os.getenv("RANGER_KMS_HOME")
+if RANGER_KMS_HOME is None:
+	RANGER_KMS_HOME = os.getcwd()
 
 def check_output(query):
 	if is_unix:
@@ -69,9 +67,13 @@ def populate_global_dict():
 	library_path = os.path.join(RANGER_KMS_HOME,"cred","lib","*")
 	read_config_file = open(os.path.join(RANGER_KMS_HOME,'install.properties'))
 	for each_line in read_config_file.read().split('\n') :
-		if len(each_line) == 0 : continue
+		each_line = each_line.strip();
+		if len(each_line) == 0:
+			continue
+		elif each_line[0] == "#":
+			continue
 		if re.search('=', each_line):
-			key , value = each_line.strip().split("=",1)
+			key , value = each_line.split("=",1)
 			key = key.strip()
 			if 'PASSWORD' in key:
 				value = ''
@@ -133,13 +135,14 @@ class BaseDB(object):
 
 class MysqlConf(BaseDB):
 	# Constructor
-	def __init__(self, host,SQL_CONNECTOR_JAR,JAVA_BIN,db_ssl_enabled,db_ssl_required,db_ssl_verifyServerCertificate,javax_net_ssl_keyStore,javax_net_ssl_keyStorePassword,javax_net_ssl_trustStore,javax_net_ssl_trustStorePassword):
-		self.host = host
+	def __init__(self, host,SQL_CONNECTOR_JAR,JAVA_BIN,db_ssl_enabled,db_ssl_required,db_ssl_verifyServerCertificate,javax_net_ssl_keyStore,javax_net_ssl_keyStorePassword,javax_net_ssl_trustStore,javax_net_ssl_trustStorePassword,db_ssl_auth_type):
+		self.host = host.lower()
 		self.SQL_CONNECTOR_JAR = SQL_CONNECTOR_JAR
 		self.JAVA_BIN = JAVA_BIN
 		self.db_ssl_enabled=db_ssl_enabled.lower()
 		self.db_ssl_required=db_ssl_required.lower()
 		self.db_ssl_verifyServerCertificate=db_ssl_verifyServerCertificate.lower()
+		self.db_ssl_auth_type=db_ssl_auth_type.lower()
 		self.javax_net_ssl_keyStore=javax_net_ssl_keyStore
 		self.javax_net_ssl_keyStorePassword=javax_net_ssl_keyStorePassword
 		self.javax_net_ssl_trustStore=javax_net_ssl_trustStore
@@ -153,7 +156,10 @@ class MysqlConf(BaseDB):
 		if self.db_ssl_enabled == 'true':
 			db_ssl_param="?useSSL=%s&requireSSL=%s&verifyServerCertificate=%s" %(self.db_ssl_enabled,self.db_ssl_required,self.db_ssl_verifyServerCertificate)
 			if self.db_ssl_verifyServerCertificate == 'true':
-				db_ssl_cert_param=" -Djavax.net.ssl.keyStore=%s -Djavax.net.ssl.keyStorePassword=%s -Djavax.net.ssl.trustStore=%s -Djavax.net.ssl.trustStorePassword=%s " %(self.javax_net_ssl_keyStore,self.javax_net_ssl_keyStorePassword,self.javax_net_ssl_trustStore,self.javax_net_ssl_trustStorePassword)
+				if self.db_ssl_auth_type == '1-way':
+					db_ssl_cert_param=" -Djavax.net.ssl.trustStore=%s -Djavax.net.ssl.trustStorePassword=%s " %(self.javax_net_ssl_trustStore,self.javax_net_ssl_trustStorePassword)
+				else:
+					db_ssl_cert_param=" -Djavax.net.ssl.keyStore=%s -Djavax.net.ssl.keyStorePassword=%s -Djavax.net.ssl.trustStore=%s -Djavax.net.ssl.trustStorePassword=%s " %(self.javax_net_ssl_keyStore,self.javax_net_ssl_keyStorePassword,self.javax_net_ssl_trustStore,self.javax_net_ssl_trustStorePassword)
 		if is_unix:
 			jisql_cmd = "%s %s -cp %s:%s/jisql/lib/* org.apache.util.sql.Jisql -driver mysqlconj -cstring jdbc:mysql://%s/%s%s -u %s -p '%s' -noheader -trim -c \;" %(self.JAVA_BIN,db_ssl_cert_param,self.SQL_CONNECTOR_JAR,path,self.host,db_name,db_ssl_param,user,password)
 		elif os_name == "WINDOWS":
@@ -1363,6 +1369,7 @@ def main(argv):
 	db_ssl_enabled='false'
 	db_ssl_required='false'
 	db_ssl_verifyServerCertificate='false'
+	db_ssl_auth_type='2-way'
 	javax_net_ssl_keyStore=''
 	javax_net_ssl_keyStorePassword=''
 	javax_net_ssl_trustStore=''
@@ -1375,30 +1382,34 @@ def main(argv):
 					db_ssl_required=globalDict['db_ssl_required'].lower()
 				if 'db_ssl_verifyServerCertificate' in globalDict:
 					db_ssl_verifyServerCertificate=globalDict['db_ssl_verifyServerCertificate'].lower()
+				if 'db_ssl_auth_type' in globalDict:
+					db_ssl_auth_type=globalDict['db_ssl_auth_type'].lower()
 				if db_ssl_verifyServerCertificate == 'true':
-					if 'javax_net_ssl_keyStore' in globalDict:
-						javax_net_ssl_keyStore=globalDict['javax_net_ssl_keyStore']
-					if 'javax_net_ssl_keyStorePassword' in globalDict:
-						javax_net_ssl_keyStorePassword=globalDict['javax_net_ssl_keyStorePassword']
 					if 'javax_net_ssl_trustStore' in globalDict:
 						javax_net_ssl_trustStore=globalDict['javax_net_ssl_trustStore']
 					if 'javax_net_ssl_trustStorePassword' in globalDict:
 						javax_net_ssl_trustStorePassword=globalDict['javax_net_ssl_trustStorePassword']
-					if not os.path.exists(javax_net_ssl_keyStore):
-						log("[E] Invalid file Name! Unable to find keystore file:"+javax_net_ssl_keyStore,"error")
-						sys.exit(1)
 					if not os.path.exists(javax_net_ssl_trustStore):
 						log("[E] Invalid file Name! Unable to find truststore file:"+javax_net_ssl_trustStore,"error")
 						sys.exit(1)
-					if javax_net_ssl_keyStorePassword is None or javax_net_ssl_keyStorePassword =="":
-						log("[E] Invalid ssl keystore password!","error")
-						sys.exit(1)
 					if javax_net_ssl_trustStorePassword is None or javax_net_ssl_trustStorePassword =="":
 						log("[E] Invalid ssl truststore password!","error")
 						sys.exit(1)
+				if db_ssl_auth_type == '2-way':
+					if 'javax_net_ssl_keyStore' in globalDict:
+						javax_net_ssl_keyStore=globalDict['javax_net_ssl_keyStore']
+					if 'javax_net_ssl_keyStorePassword' in globalDict:
+						javax_net_ssl_keyStorePassword=globalDict['javax_net_ssl_keyStorePassword']
+					if not os.path.exists(javax_net_ssl_keyStore):
+						log("[E] Invalid file Name! Unable to find keystore file:"+javax_net_ssl_keyStore,"error")
+						sys.exit(1)
+					if javax_net_ssl_keyStorePassword is None or javax_net_ssl_keyStorePassword =="":
+						log("[E] Invalid ssl keystore password!","error")
+						sys.exit(1)
+
 
 		MYSQL_CONNECTOR_JAR=CONNECTOR_JAR
-		xa_sqlObj = MysqlConf(xa_db_host, MYSQL_CONNECTOR_JAR, JAVA_BIN,db_ssl_enabled,db_ssl_required,db_ssl_verifyServerCertificate,javax_net_ssl_keyStore,javax_net_ssl_keyStorePassword,javax_net_ssl_trustStore,javax_net_ssl_trustStorePassword)
+		xa_sqlObj = MysqlConf(xa_db_host, MYSQL_CONNECTOR_JAR, JAVA_BIN,db_ssl_enabled,db_ssl_required,db_ssl_verifyServerCertificate,javax_net_ssl_keyStore,javax_net_ssl_keyStorePassword,javax_net_ssl_trustStore,javax_net_ssl_trustStorePassword,db_ssl_auth_type)
 		xa_db_core_file = os.path.join(RANGER_KMS_HOME,mysql_core_file)
 
 	elif XA_DB_FLAVOR == "ORACLE":
