@@ -53,11 +53,12 @@ public class AtlasClient extends BaseClient {
 
 	private static final Logger LOG = Logger.getLogger(AtlasClient.class);
 	private static final String EXPECTED_MIME_TYPE = "application/json";
+	private static final String WEB_RESOURCE_CONTENT_TYPE = "application/x-www-form-urlencoded";
 	private static final String ATLAS_STATUS_API_ENDPOINT = "/j_spring_security_check";
 	/*** TYPE **/
 	private static final String ATLAS_LIST_TYPE_API_ENDPOINT = "/api/atlas/types/";
 	/**** ENTITY **/
-	private static final String ATLAS_ENTITY_lIST_API_ENDPOINT = "/api/atlas/v1/entities";
+	private static final String ATLAS_ENTITY_LIST_API_ENDPOINT = "/api/atlas/v1/entities";
 	/*** TERM **/
 	private static final String ATLAS_LIST_TERM_API_ENDPOINT = "/api/atlas/v1/taxonomies/Catalog/terms/";
 	/*** TAXONOMY **/
@@ -189,13 +190,13 @@ public class AtlasClient extends BaseClient {
 					decryptedPwd = password;
 				}
 			}
-			formData.add("j_password", PasswordUtils.decryptPassword(password));
+			formData.add("j_password", decryptedPwd);
 			try {
-				statusResponse = webResource.type("application/x-www-form-urlencoded").post(ClientResponse.class,
+				statusResponse = webResource.type(WEB_RESOURCE_CONTENT_TYPE).post(ClientResponse.class,
 						formData);
 			} catch (Exception e) {
-				String msgDesc = "Unable to get a valid statusResponse for " + "expected mime type : ["
-						+ EXPECTED_MIME_TYPE + "] URL : " + statusUrl + " - got null response.";
+				String msgDesc = "Unable to get a valid statusResponse for expected mime type : ["
+						+ WEB_RESOURCE_CONTENT_TYPE + "] URL : " + statusUrl + " - got null response.";
 				LOG.error(msgDesc);
 			}
 			if (LOG.isDebugEnabled()) {
@@ -258,9 +259,6 @@ public class AtlasClient extends BaseClient {
 			if (resultResponse != null) {
 				resultResponse.close();
 			}
-			if (client != null) {
-				client.destroy();
-			}
 		}
 		return lret;
 	}
@@ -302,7 +300,7 @@ public class AtlasClient extends BaseClient {
 									if (atlasResourceParameter == null || atlasResourceParameter.isEmpty()
 											|| responseResource.startsWith(atlasResourceParameter)) {
 										if (LOG.isDebugEnabled()) {
-											LOG.debug("getTypeResource():Adding existsResource " + responseResource);
+											LOG.debug("getTypeResource():Adding existing Resource " + responseResource);
 										}
 										lret.add(responseResource);
 									}
@@ -326,9 +324,6 @@ public class AtlasClient extends BaseClient {
 			if (resultResponse != null) {
 				resultResponse.close();
 			}
-			if (client != null) {
-				client.destroy();
-			}
 		}
 		return lret;
 	}
@@ -347,7 +342,7 @@ public class AtlasClient extends BaseClient {
 					LOG.debug("getEntityResource():response.getStatus() = " + statusResponse.getStatus());
 				}
 				if (statusResponse.getStatus() == 200) {
-					WebResource webResourceEntity = client.resource(atlasUrl + ATLAS_ENTITY_lIST_API_ENDPOINT);
+					WebResource webResourceEntity = client.resource(atlasUrl + ATLAS_ENTITY_LIST_API_ENDPOINT);
 					WebResource.Builder builder = webResourceEntity.getRequestBuilder();
 					for (NewCookie cook : statusResponse.getCookies()) {
 						builder = builder.cookie(cook);
@@ -376,7 +371,7 @@ public class AtlasClient extends BaseClient {
 										if (atlasResourceParameter == null || atlasResourceParameter.isEmpty()
 												|| responseResource.startsWith(atlasResourceParameter)) {
 											if (LOG.isDebugEnabled()) {
-												LOG.debug("getEntityResource():Adding existsResource "
+												LOG.debug("getEntityResource():Adding existing Resource "
 														+ responseResource);
 											}
 											lret.add(responseResource);
@@ -390,7 +385,7 @@ public class AtlasClient extends BaseClient {
 			}
 		} catch (Throwable t) {
 			String msgDesc = "Exception while getting Atlas getEntityResource List." + " URL : " + atlasUrl
-					+ ATLAS_ENTITY_lIST_API_ENDPOINT;
+					+ ATLAS_ENTITY_LIST_API_ENDPOINT;
 			HadoopException hdpException = new HadoopException(msgDesc, t);
 			LOG.error(msgDesc, t);
 			hdpException.generateResponseDataMap(false, BaseClient.getMessage(t), msgDesc + errMsg, null, null);
@@ -444,7 +439,7 @@ public class AtlasClient extends BaseClient {
 									if (atlasResourceParameter == null || atlasResourceParameter.isEmpty()
 											|| responseResource.startsWith(atlasResourceParameter)) {
 										if (LOG.isDebugEnabled()) {
-											LOG.debug("getTermResource():Adding existsResource " + responseResource);
+											LOG.debug("getTermResource():Adding existing Resource " + responseResource);
 										}
 										lret.add(responseResource);
 									}
@@ -510,7 +505,7 @@ public class AtlasClient extends BaseClient {
 									if (atlasResourceParameter == null || atlasResourceParameter.isEmpty()
 											|| responseResource.startsWith(atlasResourceParameter)) {
 										if (LOG.isDebugEnabled()) {
-											LOG.debug("getTaxonomyResource():Adding existsResource " + responseResource);
+											LOG.debug("getTaxonomyResource():Adding existing Resource " + responseResource);
 										}
 										lret.add(responseResource);
 									}
@@ -545,7 +540,6 @@ public class AtlasClient extends BaseClient {
 		ClientResponse statusResponse = null;
 		ClientResponse resultResponse = null;
 		try {
-			client = Client.create();
 			statusResponse = getStatusResponse(client);
 			if (statusResponse != null) {
 				if (LOG.isDebugEnabled()) {
@@ -580,7 +574,7 @@ public class AtlasClient extends BaseClient {
 									if (atlasResourceParameter == null || atlasResourceParameter.isEmpty()
 											|| responseResource.startsWith(atlasResourceParameter)) {
 										if (LOG.isDebugEnabled()) {
-											LOG.debug("getOperationResource():Adding existsResource "
+											LOG.debug("getOperationResource():Adding existing Resource "
 													+ responseResource);
 										}
 										lret.add(responseResource);
@@ -615,8 +609,8 @@ public class AtlasClient extends BaseClient {
 		String errMsg = errMessage;
 		boolean connectivityStatus = false;
 		HashMap<String, Object> responseData = new HashMap<String, Object>();
-		AtlasClient AtlasClient = getAtlasClient(serviceName, configs);
-		List<String> strList = getAtlasResource(AtlasClient, "", "", null);
+		AtlasClient atlasClient = getAtlasClient(serviceName, configs);
+		List<String> strList = getAtlasResource(atlasClient, "", "", null);
 
 		if (strList != null && strList.size() > 0) {
 			if (LOG.isDebugEnabled()) {
@@ -636,7 +630,7 @@ public class AtlasClient extends BaseClient {
 	}
 
 	public static AtlasClient getAtlasClient(String serviceName, Map<String, String> configs) {
-		AtlasClient AtlasClient = null;
+		AtlasClient atlasClient = null;
 		if (LOG.isDebugEnabled()) {
 			LOG.debug("Getting AtlasClient for datasource: " + serviceName);
 		}
@@ -648,9 +642,9 @@ public class AtlasClient extends BaseClient {
 			hdpException.generateResponseDataMap(false, msgDesc, msgDesc + errMsg, null, null);
 			throw hdpException;
 		} else {
-			AtlasClient = new AtlasClient(serviceName, configs);
+			atlasClient = new AtlasClient(serviceName, configs);
 		}
-		return AtlasClient;
+		return atlasClient;
 	}
 
 	public static List<String> getAtlasResource(final AtlasClient atlasClient, String atlasResourceName,
