@@ -176,7 +176,7 @@ public class KmsKeyMgr {
 			}
 		}
 		//details
-		if (vxKmsKeyList != null && vxKmsKeyList.getVXKeys() != null && vxKmsKeyList.getVXKeys().size() > 0) {
+		if (vxKmsKeyList != null && vxKmsKeyList.getVXKeys() != null && !vxKmsKeyList.getVXKeys().isEmpty()) {
 			List<VXKmsKey> lstKMSKey = vxKmsKeyList.getVXKeys();
 			int startIndex=restErrorUtil.parseInt(
 					request.getParameter("startIndex"), 0,
@@ -587,7 +587,7 @@ public class KmsKeyMgr {
 	}
 
 	private boolean checkKerberos() throws Exception {
-		if(PropertiesUtil.getProperty(RANGER_AUTH_TYPE, "simple").equalsIgnoreCase(KERBEROS_TYPE)){
+		if(KERBEROS_TYPE.equalsIgnoreCase(PropertiesUtil.getProperty(RANGER_AUTH_TYPE, "simple"))){
 			return true;
 		}else{
 			return false;
