@@ -32,9 +32,9 @@ import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.common.GUIDUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.RESTErrorUtil;
+import org.apache.ranger.common.RangerAdminTagEnricher;
 import org.apache.ranger.common.RangerServiceTagsCache;
 import org.apache.ranger.db.RangerDaoManager;
-import org.apache.ranger.entity.XXDBBase;
 import org.apache.ranger.entity.XXResourceDef;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.entity.XXServiceDef;
@@ -63,6 +63,7 @@ import org.apache.ranger.service.RangerServiceResourceService;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
 
+import javax.annotation.PostConstruct;
 import javax.servlet.http.HttpServletResponse;
 
 @Component
@@ -88,7 +89,7 @@ public class TagDBStore extends AbstractTagStore {
 	RESTErrorUtil errorUtil;
 
 	@Autowired
-	RangerAuditFields<XXDBBase> rangerAuditFields;
+	RangerAuditFields rangerAuditFields;
 
 	@Autowired
 	GUIDUtil guidUtil;
@@ -96,6 +97,11 @@ public class TagDBStore extends AbstractTagStore {
 	@Autowired
 	RESTErrorUtil restErrorUtil;
 
+	@PostConstruct
+	public void initStore() {
+		RangerAdminTagEnricher.setTagStore(this);
+	}
+
 	@Override
 	public RangerTagDef createTagDef(RangerTagDef tagDef) throws Exception {
 		if (LOG.isDebugEnabled()) {
@@ -1044,7 +1050,7 @@ public class TagDBStore extends AbstractTagStore {
 				xAttrDef.setTagDefId(tagDefId);
 				xAttrDef.setName(attrDef.getName());
 				xAttrDef.setType(attrDef.getType());
-				xAttrDef = (XXTagAttributeDef) rangerAuditFields.populateAuditFieldsForCreate(xAttrDef);
+				xAttrDef = rangerAuditFields.populateAuditFieldsForCreate(xAttrDef);
 
 				xAttrDef = daoManager.getXXTagAttributeDef().create(xAttrDef);
 
@@ -1092,7 +1098,7 @@ public class TagDBStore extends AbstractTagStore {
 				xTagAttr.setTagId(tagId);
 				xTagAttr.setName(attr.getKey());
 				xTagAttr.setValue(attr.getValue());
-				xTagAttr = (XXTagAttribute) rangerAuditFields.populateAuditFieldsForCreate(xTagAttr);
+				xTagAttr = rangerAuditFields.populateAuditFieldsForCreate(xTagAttr);
 
 				xTagAttr = daoManager.getXXTagAttribute().create(xTagAttr);
 
@@ -1161,7 +1167,7 @@ public class TagDBStore extends AbstractTagStore {
 			resourceElement.setResDefId(xResDef.getId());
 			resourceElement.setResourceId(resourceId);
 
-			resourceElement = (XXServiceResourceElement) rangerAuditFields.populateAuditFieldsForCreate(resourceElement);
+			resourceElement = rangerAuditFields.populateAuditFieldsForCreate(resourceElement);
 
 			resourceElement = daoManager.getXXServiceResourceElement().create(resourceElement);
 
@@ -1171,7 +1177,7 @@ public class TagDBStore extends AbstractTagStore {
 				resourceElementValue.setResElementId(resourceElement.getId());
 				resourceElementValue.setValue(resVal);
 				resourceElementValue.setSortOrder(sortOrder);
-				resourceElementValue = (XXServiceResourceElementValue) rangerAuditFields.populateAuditFieldsForCreate(resourceElementValue);
+				resourceElementValue = rangerAuditFields.populateAuditFieldsForCreate(resourceElementValue);
 
 				resourceElementValue = daoManager.getXXServiceResourceElementValue().create(resourceElementValue);
 				sortOrder++;
