@@ -142,6 +142,8 @@ public class UserMgr {
 			Collection<String> userRoleList) {
 		XXPortalUser user = mapVXPortalUserToXXPortalUser(userProfile);
 		checkAdminAccess();
+                List<String> userRolesList = new ArrayList<String>(userRoleList);
+        xUserMgr.checkAccessRoles(userRolesList);
 		user = createUser(user, userStatus, userRoleList);
 
 		return user;
@@ -174,9 +176,13 @@ public class UserMgr {
 		ArrayList<String> roleList = new ArrayList<String>();
 		Collection<String> reqRoleList = userProfile.getUserRoleList();
 		if (reqRoleList != null && reqRoleList.size() > 0) {
-			for (String role : reqRoleList) {
-				roleList.add(role);
-			}
+            for (String role : reqRoleList) {
+                if (role != null) {
+                    roleList.add(role);
+                } else {
+                    roleList.add(RangerConstants.ROLE_USER);
+                }
+            }
 		} else {
 			roleList.add(RangerConstants.ROLE_USER);
 		}
@@ -365,7 +371,7 @@ public class UserMgr {
 
 	/**
 	 * @param userId
-	 * @param vStrings
+	 * @param vStringRolesList
 	 */
 	public void setUserRoles(Long userId, List<VXString> vStringRolesList) {
 		List<String> stringRolesList = new ArrayList<String>();
@@ -395,7 +401,13 @@ public class UserMgr {
 			logger.warn("SECURITY:changePassword(). User not found. LoginId="+ pwdChange.getLoginId());
 			throw restErrorUtil.createRESTException("serverMsg.userMgrInvalidUser",MessageEnums.DATA_NOT_FOUND, null, null,pwdChange.getLoginId());
 		}
-
+        if (gjUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+            logger.info("SECURITY:changePassword().Ranger External Users cannot change password. LoginId=" + pwdChange.getLoginId());
+            VXResponse vXResponse = new VXResponse();
+            vXResponse.setStatusCode(HttpServletResponse.SC_FORBIDDEN);
+            vXResponse.setMsgDesc("SECURITY:changePassword().Ranger External Users cannot change password. LoginId=" + pwdChange.getLoginId());
+            throw restErrorUtil.generateRESTException(vXResponse);
+        }
 		//check current password and provided old password is same or not
 		String encryptedOldPwd = encrypt(pwdChange.getLoginId(),pwdChange.getOldPassword());
 		if (!stringUtil.equals(encryptedOldPwd, gjUser.getPassword())) {
@@ -444,16 +456,13 @@ public class UserMgr {
 			VXPasswordChange changeEmail) {
 		checkAccessForUpdate(gjUser);
 		if (StringUtils.isEmpty(changeEmail.getEmailAddress())) {
-			throw restErrorUtil.createRESTException(
-					"serverMsg.userMgrInvalidEmail",
-					MessageEnums.INVALID_INPUT_DATA, changeEmail.getId(),
-					"emailAddress", changeEmail.toString());
+			changeEmail.setEmailAddress(null);
 		}
 
 		String encryptedOldPwd = encrypt(gjUser.getLoginId(),
 				changeEmail.getOldPassword());
 
-		if (!stringUtil.validateEmail(changeEmail.getEmailAddress())) {
+		if (!StringUtils.isEmpty(changeEmail.getEmailAddress()) && !stringUtil.validateEmail(changeEmail.getEmailAddress())) {
 			logger.info("Invalid email address." + changeEmail);
 			throw restErrorUtil.createRESTException(
 					"serverMsg.userMgrInvalidEmail",
@@ -478,15 +487,18 @@ public class UserMgr {
 
 		String saltEncodedpasswd = encrypt(gjUser.getLoginId(),
 				changeEmail.getOldPassword());
-
+        if (gjUser.getUserSource() == RangerCommonEnums.USER_APP) {
 		gjUser.setPassword(saltEncodedpasswd);
-
+       }
+        else if (gjUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+                gjUser.setPassword(gjUser.getPassword());
+        }
 		daoManager.getXXPortalUser().update(gjUser);
 		return mapXXPortalUserVXPortalUser(gjUser);
 	}
 
 	/**
-	 * @param userId
+	 * @param gjUser
 	 */
 	public VXPortalUser deactivateUser(XXPortalUser gjUser) {
 		checkAdminAccess();
@@ -617,9 +629,7 @@ public class UserMgr {
 				userProfile.setEmailAddress(user.getEmailAddress());
 			}
 
-			if (sess != null) {
-				userProfile.setUserSource(sess.getAuthProvider());
-			}
+			userProfile.setUserSource(sess.getAuthProvider());
 
 			List<XXPortalUserRole> gjUserRoleList = daoManager
 					.getXXPortalUserRole().findByParentId(user.getId());
@@ -627,10 +637,7 @@ public class UserMgr {
 			for (XXPortalUserRole gjUserRole : gjUserRoleList) {
 				userProfile.getUserRoleList().add(gjUserRole.getUserRole());
 			}
-		}
 
-		if (sess.isUserAdmin() || sess.isKeyAdmin()
-				|| sess.getXXPortalUser().getId().equals(user.getId())) {
 			userProfile.setId(user.getId());
 			List<XXUserPermission> xUserPermissions = daoManager
 					.getXXUserPermission().findByUserPermissionIdAndIsAllowed(
@@ -944,8 +951,8 @@ public class UserMgr {
 		 * return false; }
 		 */
 		boolean publicRole = false;
-		for (int i = 0; i < publicRoles.length; i++) {
-			if (publicRoles[i].equalsIgnoreCase(gjUserRole.getUserRole())) {
+		for (String publicRoleStr : publicRoles) {
+			if (publicRoleStr.equalsIgnoreCase(gjUserRole.getUserRole())) {
 				publicRole = true;
 				break;
 			}
@@ -965,8 +972,8 @@ public class UserMgr {
 		List<XXPortalUserRole> roleList = daoManager.getXXPortalUserRole()
 				.findByUserId(userId);
 		boolean publicRole = false;
-		for (int i = 0; i < publicRoles.length; i++) {
-			if (publicRoles[i].equalsIgnoreCase(userRole)) {
+		for (String publicRoleStr : publicRoles) {
+			if (publicRoleStr.equalsIgnoreCase(userRole)) {
 				publicRole = true;
 				break;
 			}
@@ -1034,7 +1041,7 @@ public class UserMgr {
 		if (sess != null) {
 
 			// Admin
-			if (sess != null && sess.isUserAdmin() || sess.isKeyAdmin()) {
+			if (sess.isUserAdmin() || sess.isKeyAdmin()) {
 				return;
 			}
 
@@ -1061,7 +1068,7 @@ public class UserMgr {
 		if (sess != null) {
 
 			// Admin
-			if (sess != null && sess.isUserAdmin()) {
+			if (sess.isUserAdmin()) {
 				return;
 			}
 
@@ -1109,16 +1116,18 @@ public class UserMgr {
 		checkAdminAccess();
 		logger.info("create:" + userProfile.getLoginId());
 		XXPortalUser xXPortalUser = null;
+                Collection<String> existingRoleList = null;
+                Collection<String> reqRoleList = null;
 		String loginId = userProfile.getLoginId();
 		String emailAddress = userProfile.getEmailAddress();
 
-		if (loginId != null && !loginId.isEmpty()) {
+                if (loginId != null && !loginId.isEmpty()) {
 			xXPortalUser = this.findByLoginId(loginId);
 			if (xXPortalUser == null) {
 				if (!stringUtil.isEmpty(emailAddress)) {
 					xXPortalUser = this.findByEmailAddress(emailAddress);
 					if (xXPortalUser == null) {
-						xXPortalUser = this.createUser(userProfile,
+                                            xXPortalUser = this.createUser(userProfile,
 								RangerCommonEnums.STATUS_ENABLED);
 					} else {
 						throw restErrorUtil
@@ -1130,9 +1139,9 @@ public class UserMgr {
 										MessageEnums.OPER_NOT_ALLOWED_FOR_STATE);
 					}
 				} else {
-					userProfile.setEmailAddress(null);
-					xXPortalUser = this.createUser(userProfile,
-							RangerCommonEnums.STATUS_ENABLED);
+                        userProfile.setEmailAddress(null);
+                        xXPortalUser = this.createUser(userProfile,
+                                RangerCommonEnums.STATUS_ENABLED);
 				}
 			} else { //NOPMD
 				/*
@@ -1142,16 +1151,71 @@ public class UserMgr {
 				 * + "login id.", MessageEnums.OPER_NOT_ALLOWED_FOR_STATE);
 				 */
 			}
-		}
-		if (xXPortalUser != null) {
-			return mapXXPortalUserToVXPortalUserForDefaultAccount(xXPortalUser);
-		} else {
-			return null;
-		}
-	}
+        }
+        VXPortalUser userProfileRes = null;
+        if (xXPortalUser != null) {
+            userProfileRes = mapXXPortalUserToVXPortalUserForDefaultAccount(xXPortalUser);
+            if (userProfile.getUserRoleList() != null
+                    && userProfile.getUserRoleList().size() > 0
+                    && ((List<String>) userProfile.getUserRoleList()).get(0) != null) {
+                reqRoleList = userProfile.getUserRoleList();
+                existingRoleList = this.getRolesByLoginId(loginId);
+                XXPortalUser xxPortalUser = daoManager.getXXPortalUser()
+                        .findByLoginId(userProfile.getLoginId());
+                if (xxPortalUser != null
+                        && xxPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+                    userProfileRes = updateRoleForExternalUsers(reqRoleList,
+                            existingRoleList, userProfileRes);
+                }
+            }
+        }
+        return userProfileRes;
+        }
 
-	protected VXPortalUser mapXXPortalUserToVXPortalUserForDefaultAccount(
-			XXPortalUser user) {
+    protected VXPortalUser updateRoleForExternalUsers(
+            Collection<String> reqRoleList,
+            Collection<String> existingRoleList, VXPortalUser userProfileRes) {
+        UserSessionBase session = ContextUtil.getCurrentUserSession();
+        if (session != null && session.getXXPortalUser() != null && session.getXXPortalUser().getLoginId() != null &&  "rangerusersync".equals(session.getXXPortalUser().getLoginId())
+                && reqRoleList != null && !reqRoleList.isEmpty()
+                && existingRoleList != null && !existingRoleList.isEmpty()) {
+            if (!reqRoleList.equals(existingRoleList)) {
+                userProfileRes.setUserRoleList(reqRoleList);
+                userProfileRes.setUserSource(RangerCommonEnums.USER_EXTERNAL);
+                List<XXUserPermission> xuserPermissionList = daoManager
+                        .getXXUserPermission().findByUserPermissionId(
+                                userProfileRes.getId());
+                if (xuserPermissionList != null
+                        && xuserPermissionList.size() > 0) {
+                    for (XXUserPermission xXUserPermission : xuserPermissionList) {
+                        if (xXUserPermission != null) {
+                            try {
+                                xUserPermissionService
+                                        .deleteResource(xXUserPermission
+                                                .getId());
+                            } catch (Exception e) {
+                                logger.error(e.getMessage());
+                            }
+                        }
+
+                    }
+                }
+                updateUser(userProfileRes);
+            }
+        } else {
+            if (logger.isDebugEnabled()) {
+                logger.debug("Permission"
+                        + " denied. LoggedInUser="
+                        + (session != null ? session.getXXPortalUser().getId()
+                                : "")
+                        + " isn't permitted to perform the action.");
+            }
+        }
+        return userProfileRes;
+    }
+
+        protected VXPortalUser mapXXPortalUserToVXPortalUserForDefaultAccount(
+                        XXPortalUser user) {
 
 		VXPortalUser userProfile = new VXPortalUser();
 
@@ -1163,7 +1227,6 @@ public class UserMgr {
 		userProfile.setFirstName(user.getFirstName());
 		userProfile.setLastName(user.getLastName());
 		userProfile.setPublicScreenName(user.getPublicScreenName());
-		userProfile.setEmailAddress(user.getEmailAddress());
 
 		List<XXPortalUserRole> gjUserRoleList = daoManager
 				.getXXPortalUserRole().findByParentId(user.getId());
@@ -1189,7 +1252,7 @@ public class UserMgr {
 
 	public XXPortalUser updateUserWithPass(VXPortalUser userProfile) {
 		String updatedPassword = userProfile.getPassword();
-		XXPortalUser xXPortalUser = this.updateUser(userProfile);
+        XXPortalUser xXPortalUser = this.updateUser(userProfile);
 
 		if (xXPortalUser == null) {
 			return null;
@@ -1210,8 +1273,13 @@ public class UserMgr {
 
 			String encryptedNewPwd = encrypt(xXPortalUser.getLoginId(),
 					updatedPassword);
-			xXPortalUser.setPassword(encryptedNewPwd);
-			xXPortalUser = daoManager.getXXPortalUser().update(xXPortalUser);
+            if (xXPortalUser.getUserSource() != RangerCommonEnums.USER_EXTERNAL) {
+		xXPortalUser.setPassword(encryptedNewPwd);
+             }
+             else if (xXPortalUser.getUserSource() != RangerCommonEnums.USER_EXTERNAL) {
+		 xXPortalUser.setPassword(xXPortalUser.getPassword());
+             }
+             xXPortalUser = daoManager.getXXPortalUser().update(xXPortalUser);
 		}
 		return xXPortalUser;
 	}
@@ -1229,7 +1297,13 @@ public class UserMgr {
 		}
                 String dbOldPwd =xXPortalUser.getPassword();
 		String encryptedNewPwd = encrypt(xXPortalUser.getLoginId(),userPassword);
-		xXPortalUser.setPassword(encryptedNewPwd);
+       if (xXPortalUser.getUserSource() != RangerCommonEnums.USER_EXTERNAL) {
+                xXPortalUser.setPassword(encryptedNewPwd);
+       }
+       else if (xXPortalUser.getUserSource() != RangerCommonEnums.USER_EXTERNAL) {
+	   xXPortalUser.setPassword(xXPortalUser.getPassword());
+       }
+
 		xXPortalUser = daoManager.getXXPortalUser().update(xXPortalUser);
                 if(xXPortalUser!=null && logAudits){
                         String dbNewPwd=xXPortalUser.getPassword();
@@ -1306,7 +1380,12 @@ public class UserMgr {
                 xXPortalUser.setLoginId(newUserName);
                 // The old password needs to be encrypted by the new user name
                 String updatedPwd = encrypt(newUserName,currentPassword);
-                xXPortalUser.setPassword(updatedPwd);
+                if (xXPortalUser.getUserSource() == RangerCommonEnums.USER_APP) {
+                        xXPortalUser.setPassword(updatedPwd);
+                }
+                else  if (xXPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+                    xXPortalUser.setPassword(xXPortalUser.getPassword());
+                }
                 xXPortalUser = daoManager.getXXPortalUser().update(xXPortalUser);
                 List<XXTrxLog> trxLogList = new ArrayList<XXTrxLog>();
                 XXTrxLog xTrxLog = new XXTrxLog();
