@@ -53,6 +53,7 @@ import org.apache.ranger.common.AppConstants;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.PropertiesUtil;
 import org.apache.ranger.common.RangerConstants;
+import org.apache.ranger.common.RangerServicePoliciesCache;
 import org.apache.ranger.common.SearchCriteria;
 import org.apache.ranger.common.UserSessionBase;
 import org.apache.ranger.db.RangerDaoManager;
@@ -156,6 +157,9 @@ public class XUserMgr extends XUserMgrBase {
 	@Autowired
 	GUIDUtil guidUtil;
 
+    @Autowired
+    UserMgr userManager;
+
 	static final Logger logger = Logger.getLogger(XUserMgr.class);
 
 
@@ -180,6 +184,7 @@ public class XUserMgr extends XUserMgrBase {
 
 	public VXUser createXUser(VXUser vXUser) {
 		checkAdminAccess();
+                validatePassword(vXUser);
 		String userName = vXUser.getName();
 		if (userName == null || "null".equalsIgnoreCase(userName)
 				|| userName.trim().isEmpty()) {
@@ -382,8 +387,14 @@ public class XUserMgr extends XUserMgrBase {
 				&& password.equals(hiddenPasswordString)) {
 			vXPortalUser.setPassword(oldUserProfile.getPassword());
 		}
-		vXPortalUser.setPassword(password);
-
+                else if(oldUserProfile != null && oldUserProfile.getUserSource() == RangerCommonEnums.USER_EXTERNAL && password != null){
+                        vXPortalUser.setPassword(oldUserProfile.getPassword());
+                        logger.debug("User is trrying to change external user password which we are not allowing it to change");
+                }
+        else if(password != null){
+                validatePassword(vXUser);
+                vXPortalUser.setPassword(password);
+        }
 		Collection<Long> groupIdList = vXUser.getGroupIdList();
 		XXPortalUser xXPortalUser = new XXPortalUser();
 		xXPortalUser = userMgr.updateUserWithPass(vXPortalUser);
@@ -435,7 +446,15 @@ public class XUserMgr extends XUserMgrBase {
 		// There is nothing to log anything in XXUser so far.
 		vXUser = xUserService.updateResource(vXUser);
 		vXUser.setUserRoleList(roleList);
-		vXUser.setPassword(password);
+		if (oldUserProfile != null) {
+			if (oldUserProfile.getUserSource() == RangerCommonEnums.USER_APP) {
+				vXUser.setPassword(password);
+			}
+			else if (oldUserProfile.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+				vXUser.setPassword(oldUserProfile.getPassword());
+			}
+		}
+
 		List<XXTrxLog> trxLogList = xUserService.getTransactionLog(vXUser,
 				oldUserProfile, "update");
 		vXUser.setPassword(hiddenPasswordString);
@@ -511,33 +530,36 @@ public class XUserMgr extends XUserMgrBase {
 		return vXUser;
 	}
 
-	public VXUserGroupInfo createXUserGroupFromMap(
-			VXUserGroupInfo vXUserGroupInfo) {
+        public VXUserGroupInfo createXUserGroupFromMap(VXUserGroupInfo vXUserGroupInfo) {
 		checkAdminAccess();
 		VXUserGroupInfo vxUGInfo = new VXUserGroupInfo();
-
-		VXUser vXUser = vXUserGroupInfo.getXuserInfo();
-
-		vXUser = xUserService.createXUserWithOutLogin(vXUser);
-
-		vxUGInfo.setXuserInfo(vXUser);
-
-		List<VXGroup> vxg = new ArrayList<VXGroup>();
-
-		for (VXGroup vXGroup : vXUserGroupInfo.getXgroupInfo()) {
-			VXGroup VvXGroup = xGroupService.createXGroupWithOutLogin(vXGroup);
-			vxg.add(VvXGroup);
-			VXGroupUser vXGroupUser = new VXGroupUser();
-			vXGroupUser.setUserId(vXUser.getId());
-			vXGroupUser.setName(VvXGroup.getName());
-			vXGroupUser = xGroupUserService
-					.createXGroupUserWithOutLogin(vXGroupUser);
-		}
-		VXPortalUser vXPortalUser = userMgr.getUserProfileByLoginId(vXUser
-				.getName());
-		if(vXPortalUser!=null){
-			assignPermissionToUser(vXPortalUser, true);
-		}
+        VXUser vXUser = vXUserGroupInfo.getXuserInfo();
+        VXPortalUser vXPortalUser = userMgr.getUserProfileByLoginId(vXUser
+                .getName());
+        XXPortalUser xxPortalUser = daoManager.getXXPortalUser().findByLoginId(
+                vXUser.getName());
+        Collection<String> reqRoleList = vXUser.getUserRoleList();
+        List<String> existingRole = daoManager.getXXPortalUserRole()
+                .findXPortalUserRolebyXPortalUserId(xxPortalUser.getId());
+        if (xxPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+            vXPortalUser = userManager.updateRoleForExternalUsers(reqRoleList,
+                    existingRole, vXPortalUser);
+        }
+        vXUser = xUserService.createXUserWithOutLogin(vXUser);
+        vxUGInfo.setXuserInfo(vXUser);
+        List<VXGroup> vxg = new ArrayList<VXGroup>();
+        for (VXGroup vXGroup : vXUserGroupInfo.getXgroupInfo()) {
+            VXGroup VvXGroup = xGroupService.createXGroupWithOutLogin(vXGroup);
+            vxg.add(VvXGroup);
+            VXGroupUser vXGroupUser = new VXGroupUser();
+            vXGroupUser.setUserId(vXUser.getId());
+            vXGroupUser.setName(VvXGroup.getName());
+            vXGroupUser = xGroupUserService
+                    .createXGroupUserWithOutLogin(vXGroupUser);
+        }
+        if (vXPortalUser != null) {
+            assignPermissionToUser(vXPortalUser, true);
+        }
 		vxUGInfo.setXgroupInfo(vxg);
 
 		return vxUGInfo;
@@ -557,19 +579,40 @@ public class XUserMgr extends XUserMgrBase {
 		}*/
 
 		List<VXUser> vxu = new ArrayList<VXUser>();
-
-		for (VXUser vXUser : vXGroupUserInfo.getXuserInfo()) {
-			XXUser xUser = daoManager.getXXUser().findByUserName(vXUser.getName());
-			if (xUser != null) {
+        for (VXUser vXUser : vXGroupUserInfo.getXuserInfo()) {
+            XXUser xUser = daoManager.getXXUser().findByUserName(
+                    vXUser.getName());
+            XXPortalUser xXPortalUser = daoManager.getXXPortalUser()
+                    .findByLoginId(vXUser.getName());
+            if (xUser != null) {
 				// Add or update group user mapping only if the user already exists in x_user table.
+				logger.debug(String.format("createXGroupUserFromMap(): Create or update group %s ", vXGroup.getName()));
 				vXGroup = xGroupService.createXGroupWithOutLogin(vXGroup);
 				vxGUInfo.setXgroupInfo(vXGroup);
 				vxu.add(vXUser);
 				VXGroupUser vXGroupUser = new VXGroupUser();
 				vXGroupUser.setUserId(xUser.getId());
 				vXGroupUser.setName(vXGroup.getName());
-				vXGroupUser = xGroupUserService
-						.createXGroupUserWithOutLogin(vXGroupUser);
+                if (xXPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+                    vXGroupUser = xGroupUserService
+                            .createXGroupUserWithOutLogin(vXGroupUser);
+		    logger.debug(String.format("createXGroupUserFromMap(): Create or update group user mapping with groupname =  " + vXGroup.getName()
+											+ " username = %s userId = %d", xXPortalUser.getLoginId(), xUser.getId()));
+                }
+                Collection<String> reqRoleList = vXUser.getUserRoleList();
+
+                XXPortalUser xxPortalUser = daoManager.getXXPortalUser()
+                        .findByLoginId(vXUser.getName());
+                List<String> existingRole = daoManager.getXXPortalUserRole()
+                        .findXPortalUserRolebyXPortalUserId(
+                                xxPortalUser.getId());
+                VXPortalUser vxPortalUser = userManager
+                        .mapXXPortalUserToVXPortalUserForDefaultAccount(xxPortalUser);
+                if (xxPortalUser.getUserSource() == RangerCommonEnums.USER_EXTERNAL) {
+                    vxPortalUser = userManager.updateRoleForExternalUsers(
+                            reqRoleList, existingRole, vxPortalUser);
+                    assignPermissionToUser(vxPortalUser, true);
+                }
 			}
 		}
 
@@ -602,6 +645,17 @@ public class XUserMgr extends XUserMgrBase {
 			if (xUser != null) {
 				VXUser vxUser = new VXUser();
 				vxUser.setName(xUser.getName());
+                XXPortalUser xXPortalUser = daoManager.getXXPortalUser()
+                        .findByLoginId(xUser.getName());
+                if (xXPortalUser != null) {
+                    List<String> existingRole = daoManager
+                            .getXXPortalUserRole()
+                            .findXPortalUserRolebyXPortalUserId(
+                                    xXPortalUser.getId());
+                    if (existingRole != null) {
+                        vxUser.setUserRoleList(existingRole);
+                    }
+                }
 				vxu.add(vxUser);
 			}
 			
@@ -614,6 +668,7 @@ public class XUserMgr extends XUserMgrBase {
 
 	public VXUser createXUserWithOutLogin(VXUser vXUser) {
 		checkAdminAccess();
+                validatePassword(vXUser);
 		return xUserService.createXUserWithOutLogin(vXUser);
 	}
 
@@ -761,12 +816,13 @@ public class XUserMgr extends XUserMgrBase {
 		return ret;
 	}
 
-	public VXUserList getXGroupUsers(Long xGroupId) {
-		SearchCriteria searchCriteria = new SearchCriteria();
-		searchCriteria.addParam("xGroupId", xGroupId);
+        public VXUserList getXGroupUsers(SearchCriteria searchCriteria) {
+
+                VXUserList vXUserList = new VXUserList();
+
 		VXGroupUserList vXGroupUserList = xGroupUserService
 				.searchXGroupUsers(searchCriteria);
-		VXUserList vXUserList = new VXUserList();
+
 
 		List<VXUser> vXUsers = new ArrayList<VXUser>();
 		if (vXGroupUserList != null) {
@@ -781,8 +837,14 @@ public class XUserMgr extends XUserMgrBase {
 
 			}
 			vXUserList.setVXUsers(vXUsers);
+                        vXUserList.setStartIndex(searchCriteria.getStartIndex());
+                        vXUserList.setResultSize(vXGroupUserList.getList().size());
+                        vXUserList.setTotalCount(vXGroupUserList.getTotalCount());
+                        vXUserList.setPageSize(searchCriteria.getMaxRows());
+                        vXUserList.setSortBy(vXGroupUserList.getSortBy());
+                        vXUserList.setSortType(vXGroupUserList.getSortType());
 		} else {
-			logger.debug("No users found for group id : " + xGroupId);
+                        logger.debug("No users found for group id : " + searchCriteria.getParamValue("xGroupId"));
 		}
 		return vXUserList;
 	}
@@ -800,8 +862,24 @@ public class XUserMgr extends XUserMgrBase {
 				xGroup, "update");
 		xaBizUtil.createTrxLog(trxLogList);
 		vXGroup = (VXGroup) xGroupService.updateResource(vXGroup);
+		if (vXGroup != null) {
+			updateXgroupUserForGroupUpdate(vXGroup);
+			RangerServicePoliciesCache.sInstance=null;
+		}
 		return vXGroup;
 	}
+
+	private void updateXgroupUserForGroupUpdate(VXGroup vXGroup) {
+		List<XXGroupUser> grpUsers = daoManager.getXXGroupUser().findByGroupId(vXGroup.getId());
+		if(CollectionUtils.isNotEmpty(grpUsers)){
+			for (XXGroupUser grpUser : grpUsers) {
+				VXGroupUser vXGroupUser = xGroupUserService.populateViewBean(grpUser);
+				vXGroupUser.setName(vXGroup.getName());
+				updateXGroupUser(vXGroupUser);
+			}
+		}
+	}
+
 	public VXGroupUser updateXGroupUser(VXGroupUser vXGroupUser) {
 		checkAdminAccess();
 		return super.updateXGroupUser(vXGroupUser);
@@ -1266,36 +1344,48 @@ public class XUserMgr extends XUserMgrBase {
 	}
 
 	public void checkAccessRoles(List<String> stringRolesList) {
-		UserSessionBase session = ContextUtil.getCurrentUserSession();
-		if (session != null && stringRolesList!=null) {
-			if (!session.isUserAdmin() && !session.isKeyAdmin()) {
-				throw restErrorUtil.create403RESTException("Permission"
-						+ " denied. LoggedInUser="
-						+ (session != null ? session.getXXPortalUser().getId()
-								: "Not Logged In")
-						+ " ,isn't permitted to perform the action.");
-			}else{
-				if (session.isUserAdmin() && stringRolesList.contains(RangerConstants.ROLE_KEY_ADMIN)) {
-					throw restErrorUtil.create403RESTException("Permission"
-							+ " denied. LoggedInUser="
-							+ (session != null ? session.getXXPortalUser().getId()
-									: "")
-							+ " isn't permitted to perform the action.");
-				}
-				if (session.isKeyAdmin() && stringRolesList.contains(RangerConstants.ROLE_SYS_ADMIN)) {
-					throw restErrorUtil.create403RESTException("Permission"
-							+ " denied. LoggedInUser="
-							+ (session != null ? session.getXXPortalUser().getId()
-									: "")
-							+ " isn't permitted to perform the action.");
-				}
-			}
-		}else{
-			VXResponse vXResponse = new VXResponse();
-			vXResponse.setStatusCode(HttpServletResponse.SC_UNAUTHORIZED);
-			vXResponse.setMsgDesc("Bad Credentials");
-			throw restErrorUtil.generateRESTException(vXResponse);
-		}
+        UserSessionBase session = ContextUtil.getCurrentUserSession();
+        if (session != null && stringRolesList != null) {
+            if (!session.isUserAdmin() && !session.isKeyAdmin()) {
+                throw restErrorUtil.create403RESTException("Permission"
+                        + " denied. LoggedInUser="
+                        + (session != null ? session.getXXPortalUser().getId()
+                                : "Not Logged In")
+                        + " ,isn't permitted to perform the action.");
+            } else {
+                if (!"rangerusersync".equals(session.getXXPortalUser()
+                        .getLoginId())) {// new logic for rangerusersync user
+                    if (session.isUserAdmin()
+                            && stringRolesList
+                                    .contains(RangerConstants.ROLE_KEY_ADMIN)) {
+                        throw restErrorUtil.create403RESTException("Permission"
+                                + " denied. LoggedInUser="
+                                + (session != null ? session.getXXPortalUser()
+                                        .getId() : "")
+                                + " isn't permitted to perform the action.");
+                    }
+                    if (session.isKeyAdmin()
+                            && stringRolesList
+                                    .contains(RangerConstants.ROLE_SYS_ADMIN)) {
+                        throw restErrorUtil.create403RESTException("Permission"
+                                + " denied. LoggedInUser="
+                                + (session != null ? session.getXXPortalUser()
+                                        .getId() : "")
+                                + " isn't permitted to perform the action.");
+                    }
+                } else {
+                    logger.info("LoggedInUser="
+                            + (session != null ? session.getXXPortalUser()
+                                    .getId() : "")
+                                    + " is permitted to perform the action.");
+                }
+            }
+        } else {
+            VXResponse vXResponse = new VXResponse();
+            vXResponse.setStatusCode(HttpServletResponse.SC_UNAUTHORIZED);
+            vXResponse.setMsgDesc("Bad Credentials");
+            throw restErrorUtil.generateRESTException(vXResponse);
+        }
 	}
 
 	public VXStringList setUserRolesByExternalID(Long userId, List<VXString> vStringRolesList) {
@@ -1311,6 +1401,7 @@ public class XUserMgr extends XUserMgrBase {
 		if(vXUser!=null && roleListNewProfile.size()>0){
 			VXPortalUser oldUserProfile = userMgr.getUserProfileByLoginId(vXUser.getName());
 			if(oldUserProfile!=null){
+				denySelfRoleChange(oldUserProfile.getLoginId());
 				updateUserRolesPermissions(oldUserProfile,roleListNewProfile);
 				portalUserRoleList = daoManager.getXXPortalUserRole().findByUserId(oldUserProfile.getId());
 				return getStringListFromUserRoleList(portalUserRoleList);
@@ -1333,6 +1424,7 @@ public class XUserMgr extends XUserMgrBase {
 		if(userName!=null && roleListNewProfile.size()>0){
 			VXPortalUser oldUserProfile = userMgr.getUserProfileByLoginId(userName);
 			if(oldUserProfile!=null){
+				denySelfRoleChange(oldUserProfile.getLoginId());
 				updateUserRolesPermissions(oldUserProfile,roleListNewProfile);
 				List<XXPortalUserRole> portalUserRoleList = daoManager.getXXPortalUserRole().findByUserId(oldUserProfile.getId());
 				return getStringListFromUserRoleList(portalUserRoleList);
@@ -1855,7 +1947,7 @@ public class XUserMgr extends XUserMgrBase {
 		}
 	}
 
-	public void deleteXUser(Long id, boolean force) {
+        public synchronized void deleteXUser(Long id, boolean force) {
 		checkAdminAccess();
 		XXUserDao xXUserDao = daoManager.getXXUser();
 		XXUser xXUser =	xXUserDao.getById(id);
@@ -2116,11 +2208,11 @@ public class XUserMgr extends XUserMgrBase {
 			xXPortalUser=userMgr.createUser(xXPortalUser, RangerCommonEnums.STATUS_ENABLED, roleList);
 		}
 		VXUser createdXUser=null;
-		if(xxUser==null && vXUser!=null){
-			try{
+		if (xxUser == null && vXUser != null) {
+			try {
 				createdXUser = xUserService.createResource(vXUser);
-			}catch(Exception ex){
-				logger.error("Error creating user: "+createdXUser.getName(),ex);
+			} catch (Exception ex) {
+				logger.error("Error creating user: " + vXUser.getName(), ex);
 			}
 		}
 		if(createdXUser!=null){
@@ -2145,5 +2237,32 @@ public class XUserMgr extends XUserMgrBase {
 			}
 		}
 		return createdXUser;
-}
+        }
+        private void validatePassword(VXUser vXUser) {
+                if (vXUser.getPassword() != null && !vXUser.getPassword().isEmpty()) {
+                        boolean checkPassword = false;
+                        String pattern = "(?=.*[0-9])(?=.*[a-zA-Z]).{8,}";
+                        checkPassword = vXUser.getPassword().trim().matches(pattern);
+                        if (!checkPassword) {
+                                logger.warn("validatePassword(). Password should be minimum 8 characters with min one alphabet and one numeric.");
+                                throw restErrorUtil.createRESTException("serverMsg.xuserMgrValidatePassword", MessageEnums.INVALID_PASSWORD, null, "Password should be minimum 8 characters with min one alphabet and one numeric", null);
+                        }
+                } else {
+                        logger.warn("validatePassword(). Password cannot be blank/null.");
+                        throw restErrorUtil.createRESTException("serverMsg.xuserMgrValidatePassword", MessageEnums.INVALID_PASSWORD, null, "Password cannot be blank/null", null);
+                }
+        }
+
+        public void denySelfRoleChange(String userName) {
+            UserSessionBase session = ContextUtil.getCurrentUserSession();
+            if (session != null && session.getXXPortalUser()!=null) {
+                if (userName.equals(session.getXXPortalUser().getLoginId())) {
+                    throw restErrorUtil.create403RESTException("Permission"
+                            + " denied. LoggedInUser="
+                            + (session != null ? session.getXXPortalUser().getId()
+                                    : "Not Logged In")
+                            + " ,isn't permitted to change its own role.");
+                }
+            }
+	}
 }
