@@ -44,7 +44,6 @@ public class RangerSearchUtil extends SearchUtil {
 		if (request == null) {
 			return null;
 		}
-
 		SearchFilter ret = new SearchFilter();
 
 		if (MapUtils.isEmpty(request.getParameterMap())) {
@@ -66,7 +65,8 @@ public class RangerSearchUtil extends SearchUtil {
 		ret.setParam(SearchFilter.POL_RESOURCE, request.getParameter(SearchFilter.POL_RESOURCE));
 		ret.setParam(SearchFilter.RESOURCE_SIGNATURE, request.getParameter(SearchFilter.RESOURCE_SIGNATURE));
 		ret.setParam(SearchFilter.POLICY_TYPE, request.getParameter(SearchFilter.POLICY_TYPE));
-
+		ret.setParam(SearchFilter.POLICY_LABEL, request.getParameter(SearchFilter.POLICY_LABEL));
+		ret.setParam(SearchFilter.POLICY_LABELS_PARTIAL, request.getParameter(SearchFilter.POLICY_LABELS_PARTIAL));
 		ret.setParam(SearchFilter.PLUGIN_HOST_NAME, request.getParameter(SearchFilter.PLUGIN_HOST_NAME));
 		ret.setParam(SearchFilter.PLUGIN_APP_TYPE, request.getParameter(SearchFilter.PLUGIN_APP_TYPE));
 		ret.setParam(SearchFilter.PLUGIN_ENTITY_TYPE, request.getParameter(SearchFilter.PLUGIN_ENTITY_TYPE));
@@ -116,7 +116,6 @@ public class RangerSearchUtil extends SearchUtil {
 		if (request == null) {
 			return null;
 		}
-
 		SearchFilter ret = new SearchFilter();
 
 		if (MapUtils.isEmpty(request.getParameterMap())) {
@@ -210,11 +209,8 @@ public class RangerSearchUtil extends SearchUtil {
 			int objectClassType, boolean hasAttributes, boolean isCountQuery) {
 
 		StringBuilder queryClause = buildWhereClause(searchCriteria, searchFields);
-
 		super.addOrderByClause(queryClause, sortClause);
-
 		Query query = em.createQuery(queryStr + queryClause);
-
 		resolveQueryParams(query, searchCriteria, searchFields);
 
 		if (!isCountQuery) {
@@ -296,13 +292,13 @@ public class RangerSearchUtil extends SearchUtil {
 				if (fieldValue != null) {
 					if (searchField.getCustomCondition() == null) {
 						whereClause.append(" and ").append(searchField.getFieldName());
-						if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.LESS_THAN)) {
+						if (SearchField.SEARCH_TYPE.LESS_THAN.equals(searchField.getSearchType())) {
 							whereClause.append("< :");
-						} else if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.LESS_EQUAL_THAN)) {
+						} else if (SearchField.SEARCH_TYPE.LESS_EQUAL_THAN.equals(searchField.getSearchType())) {
 							whereClause.append("<= :");
-						} else if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.GREATER_THAN)) {
+						} else if (SearchField.SEARCH_TYPE.GREATER_THAN.equals(searchField.getSearchType())) {
 							whereClause.append("> :");
-						} else if (searchField.getSearchType().equals(SearchField.SEARCH_TYPE.GREATER_EQUAL_THAN)) {
+						} else if (SearchField.SEARCH_TYPE.GREATER_EQUAL_THAN.equals(searchField.getSearchType())) {
 							whereClause.append(">= :");
 						}
 						whereClause.append(searchField.getClientFieldName());
@@ -408,7 +404,7 @@ public class RangerSearchUtil extends SearchUtil {
 			String sortType = searchCriteria.getSortType();
 			String querySortType = "asc";
 			if (sortType != null) {
-				if (sortType.equalsIgnoreCase("asc") || sortType.equalsIgnoreCase("desc")) {
+				if ("asc".equalsIgnoreCase(sortType) || "desc".equalsIgnoreCase(sortType)) {
 					querySortType = sortType;
 				} else {
 					logger.error("Invalid sortType. sortType=" + sortType);
