@@ -231,7 +231,7 @@ public class ServiceUtil {
 		ret.setName(StringUtils.trim(resource.getPolicyName()));
 		ret.setDescription(resource.getDescription());
 		ret.setIsEnabled(resource.getResourceStatus() == RangerCommonEnums.STATUS_ENABLED);
-		ret.setIsAuditEnabled(resource.getAuditList() != null && resource.getAuditList().size() > 0);
+		ret.setIsAuditEnabled(resource.getAuditList() != null && !resource.getAuditList().isEmpty());
 
 		Boolean isPathRecursive  = resource.getIsRecursive() == RangerCommonEnums.BOOL_TRUE;
 		Boolean isTableExcludes  = resource.getTableType() == RangerCommonEnums.POLICY_EXCLUSION;
@@ -352,24 +352,24 @@ public class ServiceUtil {
 			String                            resType   = e.getKey();
 			String                            resString = getResourceString(res.getValues());
 
-			if(resType.equalsIgnoreCase("path")) {
+			if("path".equalsIgnoreCase(resType)) {
 				ret.setName(resString);
 				ret.setIsRecursive(Boolean.TRUE.equals(res.getIsRecursive()) ? RangerCommonEnums.BOOL_TRUE : RangerCommonEnums.BOOL_FALSE);
-			} else if(resType.equalsIgnoreCase("table")) {
+			} else if("table".equalsIgnoreCase(resType)) {
 				ret.setTables(resString);
 				ret.setTableType(Boolean.TRUE.equals(res.getIsExcludes()) ? RangerCommonEnums.POLICY_EXCLUSION : RangerCommonEnums.POLICY_INCLUSION);
-			} else if(resType.equalsIgnoreCase("column-family")) {
+			} else if("column-family".equalsIgnoreCase(resType)) {
 				ret.setColumnFamilies(resString);
-			} else if(resType.equalsIgnoreCase("column")) {
+			} else if("column".equalsIgnoreCase(resType)) {
 				ret.setColumns(resString);
 				ret.setColumnType(Boolean.TRUE.equals(res.getIsExcludes()) ? RangerCommonEnums.POLICY_EXCLUSION : RangerCommonEnums.POLICY_INCLUSION);
-			} else if(resType.equalsIgnoreCase("database")) {
+			} else if("database".equalsIgnoreCase(resType)) {
 				ret.setDatabases(resString);
-			} else if(resType.equalsIgnoreCase("udf")) {
+			} else if("udf".equalsIgnoreCase(resType)) {
 				ret.setUdfs(resString);
-			} else if(resType.equalsIgnoreCase("topology")) {
+			} else if("topology".equalsIgnoreCase(resType)) {
 				ret.setTopologies(resString);
-			} else if(resType.equalsIgnoreCase("service")) {
+			} else if("service".equalsIgnoreCase(resType)) {
 				ret.setServices(resString);
 			}
 		}
@@ -424,9 +424,7 @@ public class ServiceUtil {
 				ret.put(resourceType, resource);
 			}
 
-			for(String res : resourceString.split(",")) {
-				resource.getValues().add(res);
-			}
+			Collections.addAll(resource.getValues(), resourceString.split(","));
 		}
 
 		return ret;
@@ -816,24 +814,24 @@ public class ServiceUtil {
 			String                            resType   = e.getKey();
 			String                            resString = getResourceString(res.getValues());
 
-			if(resType.equalsIgnoreCase("path")) {
+			if("path".equalsIgnoreCase(resType)) {
 				ret.setResourceName(resString);
 				ret.setIsRecursive(Boolean.TRUE.equals(res.getIsRecursive()) ? true : false);
-			} else if(resType.equalsIgnoreCase("table")) {
+			} else if("table".equalsIgnoreCase(resType)) {
 				ret.setTables(resString);
 				ret.setTableType(Boolean.TRUE.equals(res.getIsExcludes()) ? toVxPolicyIncExc(RangerCommonEnums.POLICY_EXCLUSION):toVxPolicyIncExc(RangerCommonEnums.POLICY_INCLUSION));
-			} else if(resType.equalsIgnoreCase("column-family")) {
+			} else if("column-family".equalsIgnoreCase(resType)) {
 				ret.setColumnFamilies(resString);
-			} else if(resType.equalsIgnoreCase("column")) {
+			} else if("column".equalsIgnoreCase(resType)) {
 				ret.setColumns(resString);
 				ret.setColumnType(Boolean.TRUE.equals(res.getIsExcludes()) ? toVxPolicyIncExc(RangerCommonEnums.POLICY_EXCLUSION):toVxPolicyIncExc(RangerCommonEnums.POLICY_INCLUSION));
-			} else if(resType.equalsIgnoreCase("database")) {
+			} else if("database".equalsIgnoreCase(resType)) {
 				ret.setDatabases(resString);
-			} else if(resType.equalsIgnoreCase("udf")) {
+			} else if("udf".equalsIgnoreCase(resType)) {
 				ret.setUdfs(resString);
-			} else if(resType.equalsIgnoreCase("topology")) {
+			} else if("topology".equalsIgnoreCase(resType)) {
 				ret.setTopologies(resString);
-			} else if(resType.equalsIgnoreCase("service")) {
+			} else if("service".equalsIgnoreCase(resType)) {
 				ret.setServices(resString);
 			}
 		}
@@ -1089,7 +1087,7 @@ public class ServiceUtil {
 				if (vXPermObj.getPermList() != null) {
 					for (String perm : vXPermObj.getPermList()) {
 						if ( AppConstants.getEnumFor_XAPermType(perm) != 0 ) {
-							if (perm.equalsIgnoreCase("Admin")) {
+							if ("Admin".equalsIgnoreCase(perm)) {
 								delegatedAdmin=true;
 								if (assetType != RangerCommonEnums.ASSET_HBASE) {
 									continue;
@@ -1163,11 +1161,11 @@ public class ServiceUtil {
 		VXPolicyList vXPolicyListObj = new VXPolicyList(new ArrayList<VXPolicy>());
 		if(CollectionUtils.isNotEmpty(rangerPolicyList)) {
 			int    totalCount = rangerPolicyList.size();
-			int    startIndex = filter == null ? 0 : filter.getStartIndex();
-			int    pageSize   = filter == null ? totalCount : filter.getMaxRows();
+			int    startIndex = filter.getStartIndex();
+			int    pageSize   = filter.getMaxRows();
 			int    toIndex    = Math.min(startIndex + pageSize, totalCount);
-			String sortType   = filter == null ? null : filter.getSortType();
-			String sortBy     = filter == null ? null : filter.getSortBy();
+			String sortType   = filter.getSortType();
+			String sortBy     = filter.getSortBy();
 			for(int i = startIndex; i < toIndex; i++) {
 				RangerPolicy policy =rangerPolicyList.get(i);
 				try {
@@ -1282,7 +1280,7 @@ public class ServiceUtil {
 					if(vXPermObj.getPermList() != null) {
 						for (String perm : vXPermObj.getPermList()) {
 							if ( AppConstants.getEnumFor_XAPermType(perm) != 0 ) {
-								if (perm.equalsIgnoreCase("Admin")) {
+								if ("Admin".equalsIgnoreCase(perm)) {
 									delegatedAdmin=true;
 									if (assetType!=null && assetType.intValue() != RangerCommonEnums.ASSET_HBASE) {
 										continue;
@@ -1414,7 +1412,7 @@ public class ServiceUtil {
 					try {
 						LdapName ln = new LdapName(dn);
 						for (Rdn rdn : ln.getRdns()) {
-							if (rdn.getType().equalsIgnoreCase("CN")) {
+							if ("CN".equalsIgnoreCase(rdn.getType())) {
 								commonName = rdn.getValue() + "";
 								break;
 							}
@@ -1563,5 +1561,59 @@ public class ServiceUtil {
 		
 		return assetType;
 	}
+
+	public List<RangerPolicy> getMatchingPoliciesForResource(HttpServletRequest request,
+			List<RangerPolicy> policyLists) {
+		List<RangerPolicy> policies = new ArrayList<RangerPolicy>();
+		if (request != null) {
+			String resource = request.getParameter(SearchFilter.POL_RESOURCE);
+			String serviceType = request.getParameter(SearchFilter.SERVICE_TYPE);
+			if (!StringUtil.isEmpty(resource) && !StringUtil.isEmpty(serviceType)) {
+				List<String> resourceList = null;
+				Map<String, RangerPolicy.RangerPolicyResource> rangerPolicyResourceMap = null;
+				RangerPolicy.RangerPolicyResource rangerPolicyResource = null;
+				for (RangerPolicy rangerPolicy : policyLists) {
+					if (rangerPolicy != null) {
+						rangerPolicyResourceMap = rangerPolicy.getResources();
+						if (rangerPolicyResourceMap != null) {
+							if (rangerPolicyResourceMap.containsKey("path")) {
+								rangerPolicyResource = rangerPolicyResourceMap.get("path");
+								if (rangerPolicyResource != null) {
+									resourceList = rangerPolicyResource.getValues();
+									if (CollectionUtils.isNotEmpty(resourceList) && resourceList.size() == 1) {
+										String resourcePath = resourceList.get(0);
+										if (!StringUtil.isEmpty(resourcePath)) {
+											if (resourcePath.equals(resource)
+													|| resourcePath.startsWith(resource + "/")) {
+												policies.add(rangerPolicy);
+											}
+										}
+									}
+								}
+							} else if (rangerPolicyResourceMap.containsKey("database")) {
+								rangerPolicyResource = rangerPolicyResourceMap.get("database");
+								if (rangerPolicyResource != null) {
+									resourceList = rangerPolicyResource.getValues();
+									if (CollectionUtils.isNotEmpty(resourceList) && resourceList.size() == 1) {
+										String resourcePath = resourceList.get(0);
+										if (!StringUtil.isEmpty(resourcePath)) {
+											if (resourcePath.equals(resource)) {
+												policies.add(rangerPolicy);
+											}
+										}
+									}
+								}
+							}
+						}
+					}
+				}
+				policyLists.clear();
+				if (CollectionUtils.isNotEmpty(policies)) {
+					policyLists.addAll(policies);
+				}
+			}
+		}
+		return policyLists;
+	}
 }
 	
