@@ -93,7 +93,7 @@ public class MetricUtil extends BaseLoader  {
 			if (args.length != 2) {
 				System.out.println("type: Incorrect Arguments usage : -type policies | audits | usergroup | services | database | contextenrichers | denyconditions");
 			} else {
-				if (!(args[0].equalsIgnoreCase("-type")) || !(args[1].equalsIgnoreCase("policies") || args[1].equalsIgnoreCase("audits") || args[1].equalsIgnoreCase("usergroup") || args[1].equalsIgnoreCase("services") || args[1].equalsIgnoreCase("database") || args[1].equalsIgnoreCase("contextenrichers") || args[1].equalsIgnoreCase("denyconditions"))) {
+				if (!("-type".equalsIgnoreCase(args[0])) || !("policies".equalsIgnoreCase(args[1]) || "audits".equalsIgnoreCase(args[1]) || "usergroup".equalsIgnoreCase(args[1]) || "services".equalsIgnoreCase(args[1]) || "database".equalsIgnoreCase(args[1]) || "contextenrichers".equalsIgnoreCase(args[1]) || "denyconditions".equalsIgnoreCase(args[1]))) {
 					System.out.println("type: Incorrect Arguments usage : -type policies | audits | usergroup | services | database | contextenrichers | denyconditions");
 				} else {
 					metricType = args[1];
@@ -338,7 +338,7 @@ public class MetricUtil extends BaseLoader  {
 								RangerServiceDef rangerServiceDefObj = (RangerServiceDef) repoType;
 								String name = rangerServiceDefObj.getName();
 								List<RangerContextEnricherDef> contextEnrichers = rangerServiceDefObj.getContextEnrichers();
-								if (contextEnrichers != null && contextEnrichers.size() > 0) {
+								if (contextEnrichers != null && !contextEnrichers.isEmpty()) {
 									serviceWithContextEnrichers.setServiceName(name);
 									serviceWithContextEnrichers.setTotalCount(contextEnrichers.size());
 								}
@@ -364,11 +364,11 @@ public class MetricUtil extends BaseLoader  {
 						Map<String, Integer> denyconditionsonMap = new HashMap<String, Integer>();
 						PList<RangerServiceDef> paginatedSvcDefs = svcStore.getPaginatedServiceDefs(policyFilter1);
 						if (paginatedSvcDefs != null) {
-							List<RangerServiceDef> rangerServiceDef = paginatedSvcDefs.getList();
-							if (rangerServiceDef != null && rangerServiceDef.size() > 0) {
-								for (int i = 0; i < rangerServiceDef.size(); i++) {
-									if (rangerServiceDef.get(i) != null) {
-										String serviceDef = rangerServiceDef.get(i).getName();
+							List<RangerServiceDef> rangerServiceDefs = paginatedSvcDefs.getList();
+							if (rangerServiceDefs != null && !rangerServiceDefs.isEmpty()) {
+								for (RangerServiceDef rangerServiceDef : rangerServiceDefs) {
+									if (rangerServiceDef != null) {
+										String serviceDef = rangerServiceDef.getName();
 										if (!StringUtils.isEmpty(serviceDef)) {
 											policyFilter1.setParam("serviceType", serviceDef);
 											PList<RangerPolicy> policiesList = svcStore.getPaginatedPolicies(policyFilter1);
@@ -376,18 +376,18 @@ public class MetricUtil extends BaseLoader  {
 												int policyListCount = policiesList.getListSize();
 												if (policyListCount > 0 && policiesList.getList() != null) {
 													List<RangerPolicy> policies = policiesList.getList();
-													for (int j = 0; j < policies.size(); j++) {
-														if (policies.get(j) != null) {
-															List<RangerPolicyItem> policyItem = policies.get(j).getDenyPolicyItems();
-															if (policyItem != null && policyItem.size() > 0) {
+													for (RangerPolicy policy : policies) {
+														if (policy != null) {
+															List<RangerPolicyItem> policyItem = policy.getDenyPolicyItems();
+															if (policyItem != null && !policyItem.isEmpty()) {
 																if (denyconditionsonMap.get(serviceDef) != null) {
 																	denyCount = denyconditionsonMap.get(serviceDef) + denyCount + policyItem.size();
 																} else {
 																	denyCount = denyCount + policyItem.size();
 																}
 															}
-															List<RangerPolicyItem> policyItemExclude = policies.get(j).getDenyExceptions();
-															if (policyItemExclude != null && policyItemExclude.size() > 0) {
+															List<RangerPolicyItem> policyItemExclude = policy.getDenyExceptions();
+															if (policyItemExclude != null && !policyItemExclude.isEmpty()) {
 																if (denyconditionsonMap.get(serviceDef) != null) {
 																	denyCount = denyconditionsonMap.get(serviceDef) + denyCount + policyItemExclude.size();
 																} else {
@@ -447,7 +447,7 @@ public class MetricUtil extends BaseLoader  {
 				PList<RangerPolicy> policiestype = svcStore.getPaginatedPolicies(policyFilter1);
 				long count = policiestype.getTotalCount();
 				if (count != 0) {
-					if (!serviceName.equalsIgnoreCase("tag")) {
+					if (!"tag".equalsIgnoreCase(serviceName)) {
 						servicesforPolicyType.put(serviceName, count);
 					} else {
 						tagCount = count;
