@@ -139,6 +139,9 @@ public class RangerSecurityContextFormationFilter extends GenericFilterBean {
 			}
 			HttpServletResponse res = (HttpServletResponse)response;
 			res.setHeader("X-Frame-Options", "DENY" );
+			res.setHeader("X-Content-Type-Options", "nosniff");
+			res.setHeader("X-XSS-Protection", "1; mode=block");
+			res.setHeader("Strict-Transport-Security", "max-age=31536000; includeSubDomains");
 			chain.doFilter(request, res);
 
 		} finally {
