@@ -24,11 +24,15 @@ import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
 import org.apache.ranger.biz.RangerPolicyRetriever;
 import org.apache.ranger.common.AppConstants;
 import org.apache.ranger.common.JSONUtil;
 import org.apache.ranger.common.MessageEnums;
 import org.apache.ranger.common.view.VTrxLogAttr;
+import org.apache.ranger.entity.XXDataMaskTypeDef;
 import org.apache.ranger.entity.XXPolicy;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.entity.XXTrxLog;
@@ -48,6 +52,7 @@ import org.springframework.stereotype.Service;
 @Service
 @Scope("singleton")
 public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, RangerPolicy> {
+	private static final Log logger = LogFactory.getLog(RangerPolicyService.class);
 
 	@Autowired
 	JSONUtil jsonUtil;
@@ -63,6 +68,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 	public static final String ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME="rowFilterPolicyItems";
 	public static final String IS_ENABLED_CLASS_FIELD_NAME="isEnabled";
 	public static final String IS_AUDIT_ENABLED_CLASS_FIELD_NAME="isAuditEnabled";
+        public static final String POLICY_LABELS_CLASS_FIELD_NAME="policyLabels";
 
 	static HashMap<String, VTrxLogAttr> trxLogAttrs = new HashMap<String, VTrxLogAttr>();
 	String actionCreate;
@@ -81,6 +87,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		trxLogAttrs.put("dataMaskPolicyItems", new VTrxLogAttr("dataMaskPolicyItems", "Masked Policy Items", false));
 		trxLogAttrs.put("rowFilterPolicyItems", new VTrxLogAttr("rowFilterPolicyItems", "Row level filter Policy Items", false));
 		trxLogAttrs.put("isAuditEnabled", new VTrxLogAttr("isAuditEnabled", "Audit Status", false));
+                trxLogAttrs.put("policyLabels", new VTrxLogAttr("policyLabels", "Policy Labels", false));
 	}
 	
 	public RangerPolicyService() {
@@ -125,7 +132,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		return this.populateViewBean(xPolicy);
 	}
 	
-	public List<XXTrxLog> getTransactionLog(RangerPolicy vPolicy, int action){
+	public List<XXTrxLog> getTransactionLog(RangerPolicy vPolicy, int action) {
 		return getTransactionLog(vPolicy, null, action);
 	}
 
@@ -154,7 +161,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			Field[] superClassFields = vObj.getClass().getSuperclass()
 					.getDeclaredFields();
 			for (Field field : superClassFields) {
-				if (field.getName().equalsIgnoreCase("isEnabled")) {
+				if ("isEnabled".equalsIgnoreCase(field.getName())) {
 					XXTrxLog xTrx = processFieldToCreateTrxLog(field, objectName, nameField, vObj, mObj, action);
 					if (xTrx != null) {
 						trxLogList.add(xTrx);
@@ -163,9 +170,9 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 				}
 			}
 		} catch (IllegalAccessException illegalAcc) {
-			illegalAcc.printStackTrace();
+			logger.error("Transaction log failure.", illegalAcc);
 		} catch (NoSuchFieldException noSuchField) {
-			noSuchField.printStackTrace();
+			logger.error("Transaction log failure.", noSuchField);
 		}
 		
 		return trxLogList;
@@ -189,27 +196,47 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			boolean isEnum = vTrxLogAttr.isEnum();
 			if (isEnum) {
 
-			} else if (fieldName.equalsIgnoreCase(POLICY_RESOURCE_CLASS_FIELD_NAME)) {
+			} else if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processPolicyResourcesForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(POLICY_ITEM_CLASS_FIELD_NAME)) {
+			} else if (POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(DENYPOLICY_ITEM_CLASS_FIELD_NAME)) {
+			} else if (DENYPOLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(POLICY_NAME_CLASS_FIELD_NAME)){
+			} else if (POLICY_NAME_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processPolicyNameForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(ALLOW_EXCEPTIONS_CLASS_FIELD_NAME)){
+			} else if (ALLOW_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(DENY_EXCEPTIONS_CLASS_FIELD_NAME)){
+			} else if (DENY_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processPolicyItemsForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME)){
+			} else if (DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processDataMaskPolicyItemsForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME)){
+				if(vObj.getDataMaskPolicyItems() != null && CollectionUtils.isNotEmpty(vObj.getDataMaskPolicyItems())) {
+					for(RangerDataMaskPolicyItem policyItem : vObj.getDataMaskPolicyItems()) {
+						if(policyItem.getDataMaskInfo() != null && policyItem.getDataMaskInfo().getDataMaskType() != null) {
+							List<XXDataMaskTypeDef> xDataMaskDef = daoMgr.getXXDataMaskTypeDef().getAll();
+							if(CollectionUtils.isNotEmpty(xDataMaskDef) && xDataMaskDef != null ) {
+								for (XXDataMaskTypeDef xxDataMaskTypeDef : xDataMaskDef) {
+									if(xxDataMaskTypeDef.getName().equalsIgnoreCase(policyItem.getDataMaskInfo().getDataMaskType())) {
+										String label = xxDataMaskTypeDef.getLabel();
+										StringBuilder sbValue = new StringBuilder(value);
+										label = ",\"DataMasklabel\":\""+label+"\"";
+										int sbValueIndex = sbValue.lastIndexOf("}]");
+										sbValue.insert(sbValueIndex, label);
+										value = sbValue.toString();
+										break;
+									}
+								}
+							}
+						}
+					}
+				}
+			} else if (ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = processRowFilterPolicyItemForTrxLog(field.get(vObj));
-			} else if (fieldName.equalsIgnoreCase(IS_ENABLED_CLASS_FIELD_NAME)){
+			} else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 				value = String.valueOf(processIsEnabledClassFieldNameForTrxLog(field.get(vObj)));
-			
-			}
-			else {
+                        } else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+                                value = processPolicyLabelsClassFieldNameForTrxLog(field.get(vObj));
+                        } else {
 				value = "" + field.get(vObj);
 			}
 
@@ -239,108 +266,134 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 					}
 				}
 				RangerPolicy oldPolicy = populateViewBean(mObj);
-				if (fieldName.equalsIgnoreCase(POLICY_RESOURCE_CLASS_FIELD_NAME)) {
+				if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyResourcesForTrxLog(oldPolicy.getResources());
 					}
-				} else if (fieldName.equalsIgnoreCase(POLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyItemsForTrxLog(oldPolicy.getPolicyItems());
 					}
-				} else if (fieldName.equalsIgnoreCase(DENYPOLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (DENYPOLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyItemsForTrxLog(oldPolicy.getDenyPolicyItems());
 					}
-				} else if (fieldName.equalsIgnoreCase(POLICY_NAME_CLASS_FIELD_NAME)){
+				} else if (POLICY_NAME_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyNameForTrxLog(oldPolicy.getName());
 					}
-				} else if (fieldName.equalsIgnoreCase(POLICY_DESCRIPTION_CLASS_FIELD_NAME)){
+				} else if (POLICY_DESCRIPTION_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyNameForTrxLog(oldPolicy.getDescription());
 					}
-				}  else if (fieldName.equalsIgnoreCase(ALLOW_EXCEPTIONS_CLASS_FIELD_NAME)) {
+				}  else if (ALLOW_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyItemsForTrxLog(oldPolicy.getAllowExceptions());
 					}
-				} else if (fieldName.equalsIgnoreCase(DENY_EXCEPTIONS_CLASS_FIELD_NAME)) {
+				} else if (DENY_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processPolicyItemsForTrxLog(oldPolicy.getDenyExceptions());
 					}
-				} else if (fieldName.equalsIgnoreCase(DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processDataMaskPolicyItemsForTrxLog(oldPolicy.getDataMaskPolicyItems());
+						if(oldPolicy.getDataMaskPolicyItems() != null && CollectionUtils.isNotEmpty(oldPolicy.getDataMaskPolicyItems())) {
+							for(RangerDataMaskPolicyItem oldPolicyItem : oldPolicy.getDataMaskPolicyItems()) {
+								if(oldPolicyItem.getDataMaskInfo() != null && oldPolicyItem.getDataMaskInfo().getDataMaskType() != null) {
+									List<XXDataMaskTypeDef> xDataMaskDef = daoMgr.getXXDataMaskTypeDef().getAll();
+									if(CollectionUtils.isNotEmpty(xDataMaskDef) && xDataMaskDef != null ) {
+										for (XXDataMaskTypeDef xxDataMaskTypeDef : xDataMaskDef) {
+											if(xxDataMaskTypeDef.getName().equalsIgnoreCase(oldPolicyItem.getDataMaskInfo().getDataMaskType())) {
+												String oldLabel = xxDataMaskTypeDef.getLabel();
+												StringBuilder sbOldValue = new StringBuilder(oldValue);
+												oldLabel = ",\"DataMasklabel\":\""+oldLabel+"\"";
+												int sbValueIndex = sbOldValue.lastIndexOf("}]");
+												sbOldValue.insert(sbValueIndex, oldLabel);
+												oldValue = sbOldValue.toString();
+												break;
+											}
+										}
+									}
+								}
+							}
+						}
 					}
-				} else if (fieldName.equalsIgnoreCase(ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = processRowFilterPolicyItemForTrxLog(oldPolicy.getRowFilterPolicyItems());
 					}
-				}else if (fieldName.equalsIgnoreCase(IS_ENABLED_CLASS_FIELD_NAME)) {
+				}else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
 						oldValue = String.valueOf(processIsEnabledClassFieldNameForTrxLog(oldPolicy.getIsEnabled()));
 					}
+                                } else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+                                        oldValue = processPolicyLabelsClassFieldNameForTrxLog(oldPolicy.getPolicyLabels());
 				}
 				if (oldValue == null || oldValue.equalsIgnoreCase(value)) {
 					return null;
-				} else if (fieldName.equalsIgnoreCase(POLICY_RESOURCE_CLASS_FIELD_NAME)) {
+				} else if (POLICY_RESOURCE_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					// Compare old and new resources
 					if(compareTwoPolicyResources(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(POLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//Compare old and new policyItems
 					if(compareTwoPolicyItemList(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(POLICY_NAME_CLASS_FIELD_NAME)) {
+				} else if (POLICY_NAME_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new policyName
 					if(compareTwoPolicyName(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(DENYPOLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (DENYPOLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new denyPolicyItem
 					if(compareTwoPolicyItemList(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(ALLOW_EXCEPTIONS_CLASS_FIELD_NAME)) {
+				} else if (ALLOW_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new allowExceptions
 					if(compareTwoPolicyItemList(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(DENY_EXCEPTIONS_CLASS_FIELD_NAME)) {
+				} else if (DENY_EXCEPTIONS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new denyExceptions
 					if(compareTwoPolicyItemList(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(POLICY_DESCRIPTION_CLASS_FIELD_NAME)) {
+				} else if (POLICY_DESCRIPTION_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new Description
 					if(org.apache.commons.lang.StringUtils.equals(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (DATAMASK_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new dataMaskPolicyItems
 					if(compareTwoDataMaskingPolicyItemList(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME)) {
+				} else if (ROWFILTER_POLICY_ITEM_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					//compare old and new rowFilterPolicyItems
 					if(compareTwoRowFilterPolicyItemList(value, oldValue)) {
 						return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(IS_ENABLED_CLASS_FIELD_NAME)) {
+				} else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
-					    oldValue=processPolicyNameForTrxLog(String.valueOf(oldPolicy.getIsEnabled()));
+					    oldValue = processPolicyNameForTrxLog(String.valueOf(oldPolicy.getIsEnabled()));
 					}
-				} else if (fieldName.equalsIgnoreCase(IS_AUDIT_ENABLED_CLASS_FIELD_NAME)) {
+				} else if (IS_AUDIT_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if (oldPolicy != null) {
-					    oldValue=processPolicyNameForTrxLog(String.valueOf(oldPolicy.getIsAuditEnabled()));
+					    oldValue = processPolicyNameForTrxLog(String.valueOf(oldPolicy.getIsAuditEnabled()));
 					}
-				} else if (fieldName.equalsIgnoreCase(IS_ENABLED_CLASS_FIELD_NAME)) {
+				} else if (IS_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
 					if(compareTwoPolicyName(value, oldValue)) {
 					    return null;
 					}
-				} else if (fieldName.equalsIgnoreCase(IS_AUDIT_ENABLED_CLASS_FIELD_NAME)) {
-					if(compareTwoPolicyName(value, oldValue)) {
+				} else if (IS_AUDIT_ENABLED_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+                                        if (compareTwoPolicyName(value, oldValue)) {
+                                                return null;
+                                        }
+                                } else if (POLICY_LABELS_CLASS_FIELD_NAME.equalsIgnoreCase(fieldName)) {
+                                        if (compareTwoPolicyLabelList(value, oldValue)) {
 						return null;
 					}
 				}
@@ -349,7 +402,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 				xTrxLog.setNewValue(value);
 			}
 		} catch (IllegalArgumentException | IllegalAccessException e) {
-			e.printStackTrace();
+			logger.error("Process field to create trx log failure.", e);
 		}
 
 		xTrxLog.setAction(actionString);
@@ -365,6 +418,45 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		return xTrxLog;
 	}
 
+        private boolean compareTwoPolicyLabelList(String value, String oldValue) {
+                if (value == null && oldValue == null) {
+                        return true;
+                }
+                if (value == "" && oldValue == "") {
+                        return true;
+                }
+                if (stringUtil.isEmpty(value) || stringUtil.isEmpty(oldValue)) {
+                        return false;
+                }
+                ObjectMapper mapper = new ObjectMapper();
+                try {
+                        List<String> obj = mapper.readValue(value, new TypeReference<List<String>>() {
+                        });
+                        List<String> oldObj = mapper.readValue(oldValue, new TypeReference<List<String>>() {
+                        });
+                        int oldListSize = oldObj.size();
+                        int listSize = obj.size();
+                        if (oldListSize != listSize) {
+                                return false;
+                        }
+                        for (String polItem : obj) {
+                                if (!oldObj.contains(polItem)) {
+                                        return false;
+                                }
+                        }
+                        return true;
+                } catch (JsonParseException e) {
+                        throw restErrorUtil.createRESTException("Invalid input data: " + e.getMessage(),
+                                        MessageEnums.INVALID_INPUT_DATA);
+                } catch (JsonMappingException e) {
+                        throw restErrorUtil.createRESTException("Invalid input data: " + e.getMessage(),
+                                        MessageEnums.INVALID_INPUT_DATA);
+                } catch (IOException e) {
+                        throw restErrorUtil.createRESTException("Invalid input data: " + e.getMessage(),
+                                        MessageEnums.INVALID_INPUT_DATA);
+                }
+        }
+
 	private boolean compareTwoPolicyItemList(String value, String oldValue) {
 		if (value == null && oldValue == null) {
 			return true;
@@ -463,7 +555,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			return "";
 		}
 		List<RangerPolicyItem> rangerPolicyItems = (List<RangerPolicyItem>) value;
-		if(rangerPolicyItems==null || rangerPolicyItems.size()==0){
+		if(rangerPolicyItems == null || rangerPolicyItems.isEmpty()) {
 			return "";
 		}
 		String ret = jsonUtil.readListToString(rangerPolicyItems);
@@ -499,12 +591,22 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 	}
 
 	@SuppressWarnings("unchecked")
+        private String processPolicyLabelsClassFieldNameForTrxLog(Object value) {
+                if (value == null) {
+                        return "";
+                }
+                List<String> policyLabels = (List<String>) value;
+                String ret = jsonUtil.readListToString(policyLabels);
+                return ret;
+        }
+
+        @SuppressWarnings("unchecked")
 	private String processDataMaskPolicyItemsForTrxLog(Object value) {
 		if(value == null) {
 			return "";
 		}
 		List<RangerDataMaskPolicyItem> rangerPolicyItems = (List<RangerDataMaskPolicyItem>) value;
-		if(rangerPolicyItems==null || rangerPolicyItems.size()==0){
+		if(rangerPolicyItems == null || rangerPolicyItems.isEmpty()) {
 			return "";
 		}
 		String ret = jsonUtil.readListToString(rangerPolicyItems);
@@ -520,7 +622,7 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 			return "";
 		}
 		List<RangerRowFilterPolicyItem> rangerPolicyItems = (List<RangerRowFilterPolicyItem>) value;
-		if(rangerPolicyItems==null || rangerPolicyItems.size()==0){
+		if(rangerPolicyItems == null || rangerPolicyItems.isEmpty()) {
 			return "";
 		}
 		String ret = jsonUtil.readListToString(rangerPolicyItems);
@@ -529,10 +631,10 @@ public class RangerPolicyService extends RangerPolicyServiceBase<XXPolicy, Range
 		}
 		return ret;
 	}
-	private String processIsEnabledClassFieldNameForTrxLog(Object value){
+	private String processIsEnabledClassFieldNameForTrxLog(Object value) {
 		if(value == null)
 			return null;
-		String isEnabled= String.valueOf(value);
+		String isEnabled = String.valueOf(value);
 			return isEnabled;
 	}
 
