@@ -63,6 +63,8 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 		searchFields.add(new SearchField(SearchFilter.POL_RESOURCE, "resMap.value", DATA_TYPE.STRING,
 				SEARCH_TYPE.PARTIAL, "XXPolicyResourceMap resMap, XXPolicyResource polRes",
 				"resMap.resourceId = polRes.id and polRes.policyId = obj.id"));
+                /*searchFields.add(new SearchField(SearchFilter.POLICY_LABELS_PARTIAL, "obj.label_name", DATA_TYPE.STRING,
+                                SEARCH_TYPE.PARTIAL));*/
 		searchFields.add(new SearchField(SearchFilter.POLICY_NAME_PARTIAL, "obj.name", DATA_TYPE.STRING,
 				SEARCH_TYPE.PARTIAL));
 		searchFields.add(new SearchField(SearchFilter.POLICY_TYPE, "obj.policyType", DATA_TYPE.INTEGER, SEARCH_TYPE.FULL));
@@ -83,7 +85,7 @@ public abstract class RangerPolicyServiceBase<T extends XXPolicyBase, V extends
 		XXService xService = daoMgr.getXXService().findByName(vObj.getService());
 		if (xService == null) {
 			throw restErrorUtil.createRESTException("No corresponding service found for policyName: " + vObj.getName()
-					+ "Service Not Found : " + vObj.getName(), MessageEnums.INVALID_INPUT_DATA);
+					+ "Service Not Found : " + vObj.getService(), MessageEnums.INVALID_INPUT_DATA);
 		}
 		xObj.setService(xService.getId());
 		xObj.setName(StringUtils.trim(vObj.getName()));
