@@ -23,6 +23,7 @@ define(function(require) {
 	var Backbone 	= require('backbone');
 	var XAUtils 	= require('utils/XAUtils');
 	var XAEnums		= require('utils/XAEnums');
+	var localization	= require('utils/XALangSupport');
 
 	var FormDataType = Backbone.Model.extend({
 		type : [ 'string', 'boolean', 'int' ],
@@ -33,7 +34,10 @@ define(function(require) {
 			var getResourceConfigs = function(configs){
 				if(XAUtils.isMaskingPolicy(form.model.get('policyType'))){
 					if(XAUtils.isRenderMasking(form.rangerServiceDefModel.get('dataMaskDef'))){
-						configs = form.rangerServiceDefModel.get('dataMaskDef').resources;
+						var resources = form.rangerServiceDefModel.get('dataMaskDef').resources;
+						if(!_.isEmpty(resources)){
+							configs = form.rangerServiceDefModel.get('dataMaskDef').resources;
+						}
 						configs = _.map(configs, function(obj){ obj.type =  'string'; return obj; });
 						return configs;
 					}
@@ -76,9 +80,16 @@ define(function(require) {
 						case 'string':
 							if(!isPolicyForm) {
 								formObj.type = 'Text';
+								if(!_.isUndefined(v.uiHint) && !_.isEmpty(v.uiHint)){
+									var UIHint = JSON.parse(v.uiHint);
+									if(!_.isUndefined(UIHint.TextFieldWithIcon) && UIHint.TextFieldWithIcon){
+										formObj.type = 'TextFieldWithIcon';
+										formObj.errorMsg = UIHint.info;
+									}
+								}
 								break;
 							}
-							if($.inArray(v.level, samelevelFieldCreated) >= 0){
+                                                        if($.inArray(v.parent, samelevelFieldCreated) >= 0){
 								return;
 							}
 							
@@ -109,24 +120,33 @@ define(function(require) {
 									formObj['resourceOpts'] = resourceOpts; 
 								}
 								//same level resources check
-								var optionsAttrs = [];
+								var optionsAttrs = [] ,parentResource;
 								if(!_.isUndefined(v.level)){
-									optionsAttrs = _.filter(config,function(field){ if(field.level == v.level) return field;})
+									optionsAttrs = _.filter(config,function(field){ 
+										if(field.level == v.level && field.parent == v.parent){
+											return field;	
+										}
+									});
+								}
+								var resourceDef = _.findWhere(optionsAttrs,{'name':v.name});
+								//for parent leftnode status
+								if(v.parent){
+									parentResource = _.findWhere(config ,{'name':v.parent});
+								}
+								//show only required resources in acccess policy in order to show their access types
+								if(!_.isUndefined(v.parent) && !_.isEmpty(v.parent)
+										&& parentResource.isValidLeaf){
+									optionsAttrs.unshift({'level':v.level, name:'none',label:'none'});
 								}
-								//TODO
-								//if policyType is masking then check for supported resources
-//									if( XAUtils.isMaskingPolicy(form.model.get('policyType')) && optionsAttrs.length > 1 ){
-//										var allResourceNames  = _.map(optionsAttrs, function(m){ return m.name});
-//										var rscNames = allResourceNames.splice(allResourceNames.indexOf(v.name), 1);
-//										if(_.intersection(allResourceNames, rscNames) != rscNames){
-//											optionsAttrs = _.filter(optionsAttrs, function(m){ return $.inArray(m.name, allResourceNames) >= 0;})
-//										}
-//									}
 								if(optionsAttrs.length > 1){
 									var optionsTitle = _.map(optionsAttrs,function(field){ return field.name;});
 									formObj['sameLevelOpts'] = optionsTitle;
-									samelevelFieldCreated.push(v.level);
-									fieldName = 'sameLevel'+v.level;
+                                                                        samelevelFieldCreated.push(v.parent);
+                                                                        if(!_.isUndefined(v.parent)){
+                                                                                fieldName = 'sameLevel'+v.level+''+v.parent;
+                                                                        }else{
+                                                                                fieldName = 'sameLevel'+v.level;
+                                                                        }
 									formObj['title'] = '';
 									formObj['resourcesAtSameLevel'] = true;
 									
@@ -166,6 +186,7 @@ define(function(require) {
 							formObj['recursiveSupport'] = v.recursiveSupported;
 							formObj['name'] = v.name;
 							formObj['editorAttrs'] = {'data-placeholder': v.label };
+                                                        formObj.fieldAttrs = { 'data-name' : 'field-'+v.name, 'parent' : v.parent };
 							if(!_.isUndefined(v.lookupSupported) && v.lookupSupported ){
 								var options = {
 										'containerCssClass' : v.name,
@@ -180,6 +201,39 @@ define(function(require) {
 								form.initilializePathPlugin = true;
 							}
 							formObj['initilializePathPlugin'] = true;
+                                                        var optionsAttrs = [] ,parentResource;
+                                                                if(!_.isUndefined(v.level)){
+                                                                        optionsAttrs = _.filter(config,function(field){
+                                                                                if(field.level == v.level && field.parent == v.parent){
+                                                                                        return field;
+                                                                                }
+                                                                        });
+                                                                }
+                                                                var resourceDef = _.findWhere(optionsAttrs,{'name':v.name});
+                                                                //for parent leftnode status
+                                                                if(v.parent){
+                                                                        parentResource = _.findWhere(config ,{'name':v.parent});
+                                                                }
+                                                                //show only required resources in acccess policy in order to show their access types
+                                                                if(!_.isUndefined(v.parent) && !_.isEmpty(v.parent)
+                                                                                && parentResource.isValidLeaf){
+                                                                        optionsAttrs.unshift({'level':v.level, name:'none',label:'none'});
+                                                                }
+                                                                if(optionsAttrs.length > 1){
+                                                                        var optionsTitle = _.map(optionsAttrs,function(field){ return field.name;});
+                                                                        formObj['sameLevelOpts'] = optionsTitle;
+                                                                        samelevelFieldCreated.push(v.parent);
+                                                                        if(!_.isUndefined(v.parent)){
+                                                                                fieldName = 'sameLevel'+v.level+''+v.parent;
+                                                                        }else{
+                                                                                fieldName = 'sameLevel'+v.level;
+                                                                        }
+                                                                        formObj['title'] = '';
+                                                                        formObj['resourcesAtSameLevel'] = true;
+
+                                                                        // formView is used to listen form events
+                                                                        formObj['formView'] = form;
+                                                                }
 							break;
 						case 'password':formObj.type = 'Password';break;
 						default:formObj.type = 'Text';
