@@ -175,17 +175,25 @@ define(function(require) {
 	};
    //	Search Info it give popover box
    XAUtils.searchInfoPopover = function(myArray, $infoEle, placement){
-            var msg = "<span> Wildcard searches ( for example using * or ? ) are not currently supported.</span>";
+        var msg = "<span> Wildcard searches ( for example using * or ? ) are not currently supported.</span>";
 		myArray.map(function(m){
                    msg += '<div><span><b>'+m.text+' : </b></span><span>'+m.info+'</span></div>'
                 });
-        $infoEle.popover({
-           content: msg,
-           html: true,
-           trigger: 'hover',
-           placement: placement,
-           container: 'body'
-        });
+        $infoEle.popover({ trigger: "manual" , html: true, animation:false, content: msg, container:'body', placement: placement})
+                           .on("mouseenter", function () {
+                               var _this = this;
+                               $(this).popover("show");
+                               $(".popover").on("mouseleave", function () {
+                                   $(_this).popover('hide');
+                               });
+                           }).on("mouseleave", function () {
+                               var _this = this;
+                               setTimeout(function () {
+                                   if (!$(".popover:hover").length) {
+                                       $(_this).popover("hide");
+                                   }
+                               }, 300);
+               });
    };
 
 
@@ -609,7 +617,9 @@ define(function(require) {
 	XAUtils.defaultErrorHandler = function(model, error) {
 		var App = require('App');
 		var vError = require('views/common/ErrorView');
-		if(!_.isUndefined(model) && !_.isUndefined(model.modelName) &&  model.modelName == XAEnums.ClassTypes.CLASS_TYPE_XA_ACCESS_AUDIT.modelName){
+		if(!_.isUndefined(model) && !_.isUndefined(model.modelName) 
+				&&  model.modelName == XAEnums.ClassTypes.CLASS_TYPE_XA_ACCESS_AUDIT.modelName
+				&& error.status !== 419){
 			return;
 		}
 		if (error.status == 404) {
@@ -621,7 +631,7 @@ define(function(require) {
 				status : error.status
 			}));
 		} else if (error.status == 419) {
-			window.location = 'login.jsp'
+			window.location = 'login.jsp?sessionTimeout=true';
 		}
 	};
 	XAUtils.select2Focus = function(event) {
@@ -752,6 +762,9 @@ define(function(require) {
 		var search = function(searchCollection, serverAttrName, searchOpt,
 				collection) {
 			var params = {};
+                        if($('.popover')){
+                                $('.popover').remove();
+                        }
 			searchCollection.each(function(m) {
 				var serverParamName = _.findWhere(serverAttrName, {
 					text : m.attributes.category
@@ -777,18 +790,16 @@ define(function(require) {
 				reset : true,
 				cache : false,
 				error : function(coll, response, options) {
+					that.blockUI('unblock');
                                         if(response && response.responseJSON && response.responseJSON.msgDesc){
-                                                that.notifyError('Error', response.responseJSON.msgDesc);  				                                                     }else{
+                                                that.notifyError('Error', response.responseJSON.msgDesc);
+                                        }else{
                                                 that.notifyError('Error', localization.tt('msg.errorLoadingAuditLogs'));
 					}
+
 				}
-			// data : params,
 			});
 		};
-		// var searchOpt = ['Event Time','User','Resource Name','Resource
-		// ID','Resource Type','Repository Name','Repository
-		// Type','Result','Client IP','Client Type','Access Type','Access
-		// Enforcer','Audit Type','Session ID'];
 
 		var callbackCommon = {
 			search : function(query, searchCollection) {
@@ -1207,7 +1218,9 @@ define(function(require) {
 		_.each(XAEnums.UserRoles,function(val, key){
 			if(SessionMgr.isKeyAdmin() && XAEnums.UserRoles.ROLE_SYS_ADMIN.value != val.value){
 				userRoleList.push(key)
-			}else if(!SessionMgr.isKeyAdmin() && XAEnums.UserRoles.ROLE_KEY_ADMIN.value != val.value){
+			}else if(SessionMgr.isSystemAdmin() && XAEnums.UserRoles.ROLE_KEY_ADMIN.value != val.value){
+				userRoleList.push(key)
+			}else if(SessionMgr.isUser() && XAEnums.UserRoles.ROLE_USER.value == val.value){
 				userRoleList.push(key)
 			}
 		})
@@ -1248,15 +1261,15 @@ define(function(require) {
 		}
 		return window.location.origin
 		+ window.location.pathname.substring(window.location.pathname
-				.indexOf('/', 2) + 1, 0);
+				.lastIndexOf('/') + 1, 0);
 	};
 	
 	XAUtils.isMaskingPolicy = function(type){
 		return type == XAEnums.RangerPolicyType.RANGER_MASKING_POLICY_TYPE.value ? true : false;
 	};
 	XAUtils.isRenderMasking = function(dataMaskDef){
-		return (!_.isUndefined(dataMaskDef) && !_.isUndefined(dataMaskDef.resources) 
-			&& dataMaskDef.resources.length > 0) ? true : false; 
+		return (!_.isUndefined(dataMaskDef) && !_.isUndefined(dataMaskDef.maskTypes) 
+			&& dataMaskDef.maskTypes.length > 0) ? true : false; 
 	};
 	XAUtils.isAccessPolicy = function(type){
 		return type == XAEnums.RangerPolicyType.RANGER_ACCESS_POLICY_TYPE.value ? true : false;
@@ -1329,5 +1342,39 @@ define(function(require) {
                         return '--';
                 }
         };
+        XAUtils.isTagBasedDef = function(def){
+        	return def.get('name') == XAEnums.ServiceType.SERVICE_TAG.label ? true : false;
+        };
+    XAUtils.policyTypeResources = function(obj , policyType){
+    	if(XAUtils.isAccessPolicy(policyType)){
+    		return obj.get('resources');
+    	}else{
+    		if(XAUtils.isMaskingPolicy(policyType)){
+    			return obj.get('dataMaskDef').resources;
+    		}else{
+    			return obj.get('rowFilterDef').resources;
+    		}
+    	}
+    };
+    XAUtils.showMoreAndLessButton = function(rawValue, model){
+        var showMoreLess = false;
+        var newLabelArr = _.map(rawValue, function(name, i) {
+            if (i >= 4) {
+                return '<span class="label label-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'" style="display:none;">'+ _.escape(name) + '</span>';
+            } else if (i == 3 && rawValue.length > 4) {
+                showMoreLess = true;
+                return '<span class="label label-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'">' + _.escape(name) + '</span>';
+            } else {
+                return '<span class="label label-info float-left-margin-2 shorten-label" title="'+ _.escape(name) +'" policy-label-id ="'+ model.id +'">' + _.escape(name) + '</span>';
+            }
+        });
+        if (showMoreLess) {
+            newLabelArr.push('<span class="pull-left float-left-margin-2"><a href="javascript:void(0);" data-id="showMore" policy-label-id ="'+ model.id +'"><code style=""> + More..</code></a></span>\
+                    <span class="pull-left float-left-margin-2" ><a href="javascript:void(0);" data-id="showLess" style="display:none;" policy-label-id ="'+ model.id +'"><code> - Less..</code></a></span>');
+        }
+        newLabelArr.unshift('<div data-id="groupsDiv">');
+        newLabelArr.push('</div>');
+        return newLabelArr.length ? newLabelArr.join(' ') : '--';
+    };
 	return XAUtils;
 });
\ No newline at end of file
