@@ -31,6 +31,7 @@ define(function(require) {
 	var XATableLayout	= require('views/common/XATableLayout');
 	var localization	= require('utils/XALangSupport');
 	var SessionMgr 		= require('mgrs/SessionMgr');
+	var XAViewUtils		= require('utils/XAViewUtils');
 	
 	var VXAuthSession				= require('collections/VXAuthSessionList');
 	var VXTrxLogList   				= require('collections/VXTrxLogList');
@@ -88,7 +89,8 @@ define(function(require) {
             'iconSearchInfo' : '[data-id="searchInfo"]',
             btnShowMore : '[data-id="showMore"]',
                         btnShowLess : '[data-id="showLess"]',
-			
+            iconqueryInfo : '[data-name="queryInfo"]',
+            hidePopup : '[data-id="hide-popup"]'
 		},
 
 		/** ui events hash */
@@ -99,7 +101,10 @@ define(function(require) {
 			events['click '+this.ui.tab+' a']		   = 'onTabChange';
                         events['click ' + this.ui.btnShowMore]  = 'onShowMore';
                         events['click ' + this.ui.btnShowLess]  = 'onShowLess';
-			return events;
+            if(this.currentTab == '#bigData'){
+                events['click ' + this.ui.hidePopup]  = 'onClickOutSide';
+            }
+            return events;
 		},
 
 		/**
@@ -116,16 +121,22 @@ define(function(require) {
 			this.timezone = date.replace(/^.*GMT.*\(/, "").replace(/\)$/, "");
 			this.initializeServiceDefColl();
             if(_.isUndefined(App.vsHistory)){
-                    var startDateModel = new Backbone.Model({'category':'Start Date', value:Globalize.format(new Date(),"MM/dd/yyyy")});
-                    App.vsHistory = {'bigData':[startDateModel], 'admin':[], 'loginSession':[], 'plugin':[],'pluginStatus':[]};
+	            var startDateModel = new Backbone.Model({'category':'Start Date', value:Globalize.format(new Date(),"MM/dd/yyyy")});
+	            App.vsHistory = {'bigData':[startDateModel], 'admin':[], 'loginSession':[], 'plugin':[],'pluginStatus':[]};
             }
 		},
 
 		/** all events binding here */
 		bindEvents : function() {
-                        this.listenTo(this.accessAuditList, "sync",this.showTagsAttributes, this);
+            this.listenTo(this.accessAuditList, "sync", this.showTagsAttributes, this);
 		},
 
+                onClickOutSide: function(){
+                        if($('.queryInfo') && this.currentTab == '#bigData'){
+                                $('.queryInfo').popover('hide');
+                        }
+                },
+
 		initializeServiceDefColl : function() {
 			this.serviceDefList	= new RangerServiceDefList();
 			this.serviceDefList.fetch({ 
@@ -146,7 +157,7 @@ define(function(require) {
 				this.addSearchForBigDataTab();
 				this.modifyTableForSubcolumns();
 			}
-                        this.showTagsAttributes();
+			this.showTagsAttributes();
 
 		},
 		modifyTableForSubcolumns : function(){
@@ -190,16 +201,16 @@ define(function(require) {
 					this.renderBigDataTable();
 					this.modifyTableForSubcolumns();
 					this.addSearchForBigDataTab();
-                                        this.listenTo(this.accessAuditList, "request", that.updateLastRefresh);
+                    this.listenTo(this.accessAuditList, "request", that.updateLastRefresh);
                     this.ui.iconSearchInfo.show();
-                                        this.showTagsAttributes();
+                    this.showTagsAttributes();
 					break;
 				case "#admin":
 					this.currentTab = '#admin';
-                                        App.vsHistory.admin = XAUtils.removeEmptySearchValue(App.vsHistory.admin);
+                    App.vsHistory.admin = XAUtils.removeEmptySearchValue(App.vsHistory.admin);
 					this.trxLogList = new VXTrxLogList();
 					this.renderAdminTable();
-                                        if(_.isEmpty(App.vsHistory.admin) && _.isUndefined(App.sessionId)){
+                    if(_.isEmpty(App.vsHistory.admin) && _.isUndefined(App.sessionId)){
 			     	    this.trxLogList.fetch({
 							   cache : false
 						});
@@ -211,16 +222,16 @@ define(function(require) {
 					break;
 				case "#loginSession":
 					this.currentTab = '#loginSession';
-                                        App.vsHistory.loginSession = XAUtils.removeEmptySearchValue(App.vsHistory.loginSession);
+                    App.vsHistory.loginSession = XAUtils.removeEmptySearchValue(App.vsHistory.loginSession);
 					this.authSessionList = new VXAuthSession();
 					this.renderLoginSessionTable();
 					//Setting SortBy as id and sortType as desc = 1
 					this.authSessionList.setSorting('id',1); 
-                                        if(_.isEmpty(App.vsHistory.loginSession)){
-                                                this.authSessionList.fetch({
-                                                        cache:false,
-                                                });
-                                        }
+                    if(_.isEmpty(App.vsHistory.loginSession)){
+                        this.authSessionList.fetch({
+                        	cache:false,
+                        });
+                    }
 					this.addSearchForLoginSessionTab();
 					this.listenTo(this.authSessionList, "request", that.updateLastRefresh)
                     this.ui.iconSearchInfo.hide();
@@ -233,12 +244,12 @@ define(function(require) {
 					var params = { priAcctId : 1 };
 					that.renderAgentTable();
 					this.policyExportAuditList.setSorting('createDate',1);
-                                        if(_.isEmpty(App.vsHistory.plugin)){
-                                                this.policyExportAuditList.fetch({
-                                                        cache : false,
-                                                        data :params
-                                                });
-                                        }
+                    if(_.isEmpty(App.vsHistory.plugin)){
+                    this.policyExportAuditList.fetch({
+	                    cache : false,
+	                    data :params
+                    });
+                    }
 					this.addSearchForAgentTab();
 					this.listenTo(this.policyExportAuditList, "request", that.updateLastRefresh)
                     this.ui.iconSearchInfo.hide();
@@ -320,15 +331,25 @@ define(function(require) {
 						
 						switch (facet) {
 							case 'Service Name':
-								var serviceList 	= new RangerServiceList();
+								var serviceList 	= new RangerServiceList() , serviceNameVal = [];
 								serviceList.setPageSize(100);
 								serviceList.fetch().done(function(){
-									callback(serviceList.map(function(model){return model.get('name');}));
+								serviceList.each(function(m){
+									if(m.get('type') !== XAEnums.ServiceType.SERVICE_TAG.label){
+										serviceNameVal.push(m.get('name'));
+									};
+								});
+								callback(serviceNameVal);
 								});
 								break;
 							case 'Service Type':
-								var serviceList =  that.serviceDefList.map(function(serviceDef){ return {'label' : serviceDef.get('name').toUpperCase(), 'value' : serviceDef.get('name').toUpperCase()}; })
-								callback(serviceList);
+								var serviveDefs = [];
+								that.serviceDefList.each(function(m){
+									if(m.get('name').toUpperCase() != (XAEnums.ServiceType.SERVICE_TAG.label).toUpperCase()){
+										serviveDefs.push({ 'label' : m.get('name').toUpperCase(), 'value' : m.get('name').toUpperCase() });
+									}
+								});
+								callback(serviveDefs);
 								break;
 							case 'Result':
 				                callback(XAUtils.hackForVSLabelValuePairs(XAEnums.AccessResult));
@@ -360,11 +381,11 @@ define(function(require) {
 			var that = this;
 			var searchOpt = ["Audit Type", "User", "Actions", "Session Id", "Start Date", "End Date"];
 			var serverAttrName  = [{text : "Audit Type", label :"objectClassType",'multiple' : true, 'optionsArr' : XAUtils.enumToSelectLabelValuePairs(XAEnums.ClassTypes)},
-			                       {text : "User", label :"owner"},
-			                       {text : "Actions", label :"action"},{text :  "Session Id", label :"sessionId"},
-			                       {text : 'Start Date',label :'startDate'},{text : 'End Date',label :'endDate'} ];
+                                               {text : "User", label :"owner"}, {text :  "Session Id", label :"sessionId"},
+                                               {text : 'Start Date',label :'startDate'},{text : 'End Date',label :'endDate'},
+                                               {text : "Actions", label :"action",'multiple' : true, 'optionsArr' : XAUtils.enumToSelectLabelValuePairs(XAGlobals.ActionType)},];
 			
-			var auditList = [],query = '';
+                        var auditList = [],query = '', actionTypeList = [];
 			_.each(XAEnums.ClassTypes, function(obj){
 				if((obj.value == XAEnums.ClassTypes.CLASS_TYPE_XA_ASSET.value) 
 						|| (obj.value == XAEnums.ClassTypes.CLASS_TYPE_XA_RESOURCE.value) 
@@ -374,6 +395,11 @@ define(function(require) {
 						|| (obj.value == XAEnums.ClassTypes.CLASS_TYPE_XA_GROUP.value))
 					auditList.push({label :obj.label, value :obj.label+''});
 			});
+			_.each(XAGlobals.ActionType, function(obj){
+				if(obj.label){
+					actionTypeList.push({label :obj.label, value :obj.label})
+				}
+			})
 			if(!_.isUndefined(App.sessionId)){
                                 App.vsHistory.admin = [] ;
 				query = '"Session Id": "'+App.sessionId+'"';
@@ -394,7 +420,7 @@ define(function(require) {
 										callback(auditList);
 										break;
 									case 'Actions':
-										callback(["Create","Update","Delete","Password Change","Export Json","Export Csv","Export Excel","Import End","Import Start"]);
+										callback(actionTypeList);
 										break;
 									case 'Start Date' :
 											var endDate, models = that.visualSearch.searchQuery.where({category:"End Date"});
@@ -609,7 +635,14 @@ define(function(require) {
 					
 					var fullTrxLogListForTrxId = new VXTrxLogList();
 					fullTrxLogListForTrxId.getFullTrxLogListForTrxId(this.model.get('transactionId'),{
-						cache : false
+                                                cache : false,
+                                                error : function(response , error){
+                                                        if (response && response.status === 419 ) {
+                                                                XAUtils.defaultErrorHandler(error , response);
+                                                        } else {
+                                                                XAUtils.showErrorMsg(response.responseJSON.msgDesc);
+                                                        }
+                                                }
 					}).done(function(coll,mm){
 						XAUtils.blockUI('unblock');
 						fullTrxLogListForTrxId = new VXTrxLogList(coll.vXTrxLogs);
@@ -726,9 +759,9 @@ define(function(require) {
 								hasAction = ["EXPORT JSON", "EXPORT EXCEL", "EXPORT CSV", "IMPORT START", "IMPORT END"];
 							if($.inArray(action,hasAction)>=0){
 								if(action == "EXPORT JSON" || action == "EXPORT EXCEL" || action == "EXPORT CSV")
-									return html = 	'Exported policies';
+                                                                        return 'Exported policies';
 								else
-									return html = 	action;
+                                                                        return action;
 							} else{	
 								 if(rawValue == XAEnums.ClassTypes.CLASS_TYPE_XA_ASSET.value || rawValue == XAEnums.ClassTypes.CLASS_TYPE_RANGER_SERVICE.value)
 								 	 html = 	'Service '+action+'d '+'<b>'+name+'</b>';
@@ -835,19 +868,18 @@ define(function(require) {
 					Backgrid.Row.prototype.initialize.apply(this, args);
 				},
 				onClick: function (e) {
-					var self = this;
-                                        if($(e.target).hasClass('tagsColumn') || $(e.target).closest('td').hasClass("tagsColumn")){
-                                                return;
-                                        }
+                    var self = this ;
+                    if($(e.target).hasClass('tagsColumn') || $(e.target).closest('td').hasClass("tagsColumn")){
+                            return;
+                    }
+                    if(this.model.get('repoType')){
+                        var repoType =  this.model.get('repoType');
+                    }
 					var policyId = this.model.get('policyId');
 					if(policyId == -1){
 						return;
 					}
-					var	serviceDef = that.serviceDefList.findWhere({'id':this.model.get('repoType')});
-					if(_.isUndefined(serviceDef)){
-						return ;
-					}
-					var eventTime = this.model.get('eventTime');
+                    var eventTime = this.model.get('eventTime');
 
 					var policy = new RangerPolicy({
 						id: policyId
@@ -856,17 +888,19 @@ define(function(require) {
 					var view = new RangerPolicyRO({
 						policy: policy,
 						policyVersionList : policyVersionList,
-						serviceDef: serviceDef,
-						eventTime : eventTime
+                        serviceDefList: that.serviceDefList,
+                        eventTime : eventTime,
+                        repoType : repoType
 					});
 					var modal = new Backbone.BootstrapModal({
 						animate : true, 
 						content		: view,
 						title: localization.tt("h.policyDetails"),
 						okText :localization.tt("lbl.ok"),
-						allowCancel : false,
+                        allowCancel : true,
 						escape : true
 					}).open();
+                    modal.$el.find('.cancel').hide();
 					var policyVerEl = modal.$el.find('.modal-footer').prepend('<div class="policyVer pull-left"></div>').find('.policyVer');
 					policyVerEl.append('<i id="preVer" class="icon-chevron-left '+ ((policy.get('version')>1) ? 'active' : '') +'"></i><text>Version '+ policy.get('version') +'</text>').find('#preVer').click(function(e){
 						view.previousVer(e);
@@ -945,7 +979,7 @@ define(function(require) {
 						formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 							fromRaw: function (rawValue, model) {
 								return '<div title="'+rawValue+'">'+_.escape(rawValue)+'</div>\
-								<div title="'+model.get('serviceType')+'" style="border-top: 1px solid #ddd;">'+_.escape(model.get('serviceType'))+'</div>';;
+                                                                <div title="'+model.get('serviceType')+'" style="border-top: 1px solid #ddd;">'+_.escape(model.get('serviceType'))+'</div>';
 							}
 						})
 					},
@@ -955,12 +989,7 @@ define(function(require) {
 						click: false,
 						formatter: _.extend({},Backgrid.CellFormatter.prototype,{
 							 fromRaw: function(rawValue,model) {
-								 var resourcePath = _.isUndefined(model.get('resourcePath')) ? undefined : model.get('resourcePath');
-								 var resourceType = _.isUndefined(model.get('resourceType')) ? undefined : model.get('resourceType');
-								 if(resourcePath) {
-								 return '<span title="'+resourcePath+'">'+resourcePath+'</span>\
-									<div title="'+resourceType+'" style="border-top: 1px solid #ddd;">'+resourceType+'</div>';
-								 }
+							     return XAViewUtils.resourceTypeFormatter(rawValue, model);
 							 }
 						}),
 						drag: false,
@@ -1557,6 +1586,7 @@ define(function(require) {
 
                                         });
                                 }
+                                XAViewUtils.showQueryPopup(model, that);
                         });
                 },
                 onShowMore : function(e){
