@@ -80,7 +80,8 @@ define(function(require) {'use strict';
 			policyType          : '[data-id="policyType"]',
 			btnShowMoreAccess 	: '[data-id="showMoreAccess"]',
                         btnShowLessAccess 	: '[data-id="showLessAccess"]',
-                        'iconSearchInfo' 	: '[data-id="searchInfo"]',
+                        iconSearchInfo      : '[data-id="searchInfo"]',
+                        policyLabels		: '[data-id="policyLabels"]'
 		},
 
 		/** ui events hash */
@@ -119,15 +120,20 @@ define(function(require) {'use strict';
 				var collName = serviceDefName +'PolicyList';
 				this[collName] = new RangerPolicyList();
 				this.defaultPageState = this[collName].state;
-				this.policyCollList.push({ 'collName' : collName, 'serviceDefName' : serviceDefName})
+				this.policyCollList.push({ 'collName' : collName, 'serviceDefName' : serviceDefName});
+				//set subgrid coll for policy item on pagination
+				this.listenTo(this[collName],'change',function(model){
+					this.setSubgridCollForPolicyItems(model);			
+				});
 			},this);
+			
 		},
 		initializeServiceDef : function() {
-			   this.serviceDefList = new RangerServiceDefList();
-			   this.serviceDefList.fetch({
-				   cache : false,
-				   async:false
-			   });
+		   this.serviceDefList = new RangerServiceDefList();
+		   this.serviceDefList.fetch({
+			   cache : false,
+			   async:false
+		   });
 		},	   
 
 		/** all events binding here */
@@ -141,10 +147,11 @@ define(function(require) {'use strict';
 			this.initializePlugins();
 			this.setupGroupAutoComplete();
 			this.renderComponentAndPolicyTypeSelect();
-			//Show policies listing for each service and GET policies for each service
+                        var policyType = this.ui.policyType.val();
+//			Show policies listing for each service and GET policies for each service
 			_.each(this.policyCollList, function(obj,i){
 				this.renderTable(obj.collName, obj.serviceDefName);
-				this.getResourceLists(obj.collName,obj.serviceDefName);
+                                this.getResourceLists(obj.collName,obj.serviceDefName,policyType);
 			},this);
 			this.$el.find('[data-js="policyName"]').focus()
 			var urlString = XAUtil.getBaseUrl();
@@ -159,13 +166,18 @@ define(function(require) {'use strict';
 	                 {text :'Policy Type' , info :localization.tt('msg.policyTypeMsg')},
 	                 {text :'Component'   , info :localization.tt('msg.componentMsg')},
 	                 {text :'Search By'   , info :localization.tt('msg.searchBy')},
-	                 {text :'Resource'    , info :localization.tt('msg.resourceMsg')}]
+                         {text :'Resource'    , info :localization.tt('msg.resourceMsg')},
+                         {text :'Policy Label', info :localization.tt('msg.policyLabelsinfo')}]
          },
-         getResourceLists: function(collName, serviceDefName){
+         getResourceLists: function(collName, serviceDefName , policyType){
 
 			var that = this, coll = this[collName];
 			that.allowDownload = false;
 			coll.queryParams.serviceType = serviceDefName;
+                        if(policyType){
+//				to set default value access type in policy type
+                                coll.queryParams.policyType = policyType;
+                        }
 			coll.fetch({
 				cache : false,
 				reset: true,
@@ -176,17 +188,7 @@ define(function(require) {'use strict';
 				if(coll.length >= 1 && !that.allowDownload)
 					that.allowDownload = true;
 				_.each(that[collName].models,function(model,ind){
-					if (XAUtil.isMaskingPolicy(model.get('policyType'))) {
-						//'<name>Collection' must be same as subgrid custom column name
-						model.attributes.allowCollection = model.get('dataMaskPolicyItems');
-					} else if (XAUtil.isRowFilterPolicy(model.get('policyType'))) {
-						model.attributes.allowCollection = model.get('rowFilterPolicyItems');
-					} else {
-						model.attributes.allowCollection = model.get('policyItems');
-					}
-					model.attributes.denyCollection  = model.get('denyPolicyItems');
-					model.attributes.denyExcludeCollection    = model.get('denyExceptions');
-					model.attributes.allowExcludeCollection = model.get('allowExceptions');
+					that.setSubgridCollForPolicyItems(model);
 				});
 
 			});
@@ -215,16 +217,15 @@ define(function(require) {'use strict';
 					label: 'Groups',
 					formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 						fromRaw: function (rawValue,model, coll) {
-							var startSpanEle = '<span class="label label-info cellWidth-1 float-left-margin-2" style="">',endSpanEle = '</span>';
 							var group_str = '';
 							if(_.isEmpty(model.get('groups'))){
 								return '<center>--</center>';
 							} else {
 								_.each(model.get('groups'),function(group,index){
 									if(index < 4) {
-										group_str += '<span class="label label-info cellWidth-1 float-left-margin-2" group-policy-id="'+model.cid+'" style="">' + _.escape(group) + endSpanEle  + " ";
+                                                                                group_str += '<span class="label label-info cellWidth-1 float-left-margin-2" group-policy-id="'+model.cid+'" style="">' + _.escape(group) + '</span>'  + " ";
 									} else {
-										group_str += '<span class="label label-info cellWidth-1 float-left-margin-2" group-policy-id="'+model.cid+'" style="display:none">' + _.escape(group) + endSpanEle  + " ";
+                                                                                group_str += '<span class="label label-info cellWidth-1 float-left-margin-2" group-policy-id="'+model.cid+'" style="display:none">' + _.escape(group) + '</span>'  + " ";
 									}
 								});
 								if(model.get('groups').length > 4) {
@@ -247,16 +248,15 @@ define(function(require) {'use strict';
 					label: 'Users',
 					formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 						fromRaw: function (rawValue,model) {
-							var startSpanEle = '<span class="label label-info cellWidth-1 float-left-margin-2" style="">',endSpanEle = '</span>';
 							var user_str = '';
 							if(_.isEmpty(model.get('users'))){
 								return '<center>--</center>';
 							} else {
 								_.each(model.get('users'),function(user,index){
 									if(index < 4) {
-										user_str += '<span class="label label-info cellWidth-1 float-left-margin-2" user-policy-id="'+model.cid+'" style="">' + _.escape(user) + endSpanEle  + " ";
+                                                                                user_str += '<span class="label label-info cellWidth-1 float-left-margin-2" user-policy-id="'+model.cid+'" style="">' + _.escape(user) + '</span>'+ " ";
 									} else {
-										user_str += '<span class="label label-info cellWidth-1 float-left-margin-2" user-policy-id="'+model.cid+'" style="display:none">' + _.escape(user) + endSpanEle  + " ";
+                                                                                user_str += '<span class="label label-info cellWidth-1 float-left-margin-2" user-policy-id="'+model.cid+'" style="display:none">' + _.escape(user) + '</span>'+ " ";
 									}
 								});
 								if(model.get('users').length > 4) {
@@ -278,13 +278,12 @@ define(function(require) {'use strict';
 					label: 'Accesses',
 					formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
 						fromRaw: function (rawValue,model) {
-							var startSpanEle = '<span class="label label-info cellWidth-1 float-left-margin-2" style="">',endSpanEle = '</span>';
 							var access_str = '';
 							_.each(model.get('accesses'),function(access,index){
 								if(index < 4){
-									access_str += '<span class="label label-info cellWidth-1 float-left-margin-2" access-policy-id="'+model.cid+'" style="">' + access.type+ endSpanEle  + " ";
+                                                                        access_str += '<span class="label label-info cellWidth-1 float-left-margin-2" access-policy-id="'+model.cid+'" style="">' + access.type+'</span>'  + " ";
 								} else {
-									access_str += '<span class="label label-info cellWidth-1 float-left-margin-2" access-policy-id="'+model.cid+'" style="display:none">' + access.type+ endSpanEle  + " ";
+                                                                        access_str += '<span class="label label-info cellWidth-1 float-left-margin-2" access-policy-id="'+model.cid+'" style="display:none">' + access.type+'</span>'+ " ";
 								}
 							});
 							if(model.get('accesses').length > 4) {
@@ -301,6 +300,64 @@ define(function(require) {'use strict';
 					sortable: false
 				}
 			];
+               if(XAUtil.isMaskingPolicy(this.ui.policyType.val())){
+                        subcolumns.push({
+                                name: 'maskingCondition',
+                                cell: Backgrid.HtmlCell.extend({
+                                        className : 'subgridTable'
+                        }),
+                        label: 'Masking Condition',
+                        formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                            fromRaw: function (rawValue,model) {
+                                var access_str = '';
+                                var servicedef = _.find(that.serviceDefList.models ,function(m){
+									return m.get('name') == model.get('type');
+                                });
+                                var maskValue = _.find(servicedef.get('dataMaskDef').maskTypes,function(m){
+									return m.name == model.get('dataMaskInfo').dataMaskType
+                                })
+                                if(maskValue.label){
+									if(maskValue.label == "Custom"){
+										var title = model.attributes.dataMaskInfo.dataMaskType +' : '+model.attributes.dataMaskInfo.valueExpr;
+										access_str = '<span class="label label-info trim-containt" title="'+_.escape(title)+'">'+_.escape(title)+'</span>';
+									}else{
+										access_str = '<span class="label label-info trim-containt" title="'+_.escape(maskValue.label)+'">'+_.escape(maskValue.label)+'</span>';
+									}
+                                }else {
+                                  access_str ='<center>--</center>';
+                                }
+                                return access_str;
+                            }
+                        }),
+                        editable: false,
+                        click: false,
+                        sortable: false
+
+                })
+            };
+            if(XAUtil.isRowFilterPolicy(this.ui.policyType.val())){
+                    subcolumns.push({
+                            name: 'rowLevelFilter',
+                            cell: Backgrid.HtmlCell.extend({
+                                className : 'subgridTable'
+                            }),
+                            label: 'Row Level Filter',
+                            formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                                fromRaw: function (rawValue,model) {
+                                    var access_str = '';
+                                    if(model.get('rowFilterInfo').filterExpr){
+                                           access_str = '<span class="label label-info trim-containt" title="'+_.escape(model.get('rowFilterInfo').filterExpr)+'">' + _.escape(model.get('rowFilterInfo').filterExpr)+ '</span>'  + " ";
+                                    } else {
+                                           access_str ='<center>--</center>';
+                                    }
+                                    return access_str;
+                                }
+                            }),
+                            editable: false,
+                            click: false,
+                            sortable: false
+                    })
+            }
 			var columns = {
 				id : {
 					cell : "uri",
@@ -323,6 +380,21 @@ define(function(require) {'use strict';
 					editable: false,
 					sortable : false
 				},
+                                policyLabels: {
+                                    cell	: Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                                    label : localization.tt("lbl.policyLabels"),
+                                    formatter: _.extend({}, Backgrid.CellFormatter.prototype, {
+                                        fromRaw: function (rawValue, model) {
+                                            var labels ="";
+                                            if(!_.isUndefined(rawValue) && rawValue.length != 0){
+                                                return XAUtil.showMoreAndLessButton(rawValue, model)
+                                            }else{
+                                                return '--';
+                                            }
+                                        }
+                                    }),
+                                    editable : false,
+                                },
 				resources: {
 					label: 'Resources',
 					cell: 'Html',
@@ -401,18 +473,43 @@ define(function(require) {'use strict';
 			if(serviceDefName === XAEnums.ServiceType.SERVICE_TAG.label){
 				enableDenyAndExceptionsInPolicies = true;
 			}
+            if(XAUtil.isAccessPolicy(this.ui.policyType.val())){
+                permissions = {
+                        allow:{
+                                label: 'Allow Conditions',
+                                cell: "subgrid-custom",
+                                optionValues : subcolumns,
+                                editable: false,
+                                sortable: false,
+                                click : false
+                           }
+                        };
+            }else if(XAUtil.isMaskingPolicy(this.ui.policyType.val())){
+                                permissions = {
+                                        mask:{
+                                                        label: 'Masking Conditions',
+                                                        cell: "subgrid-custom",
+                                                        optionValues : subcolumns,
+                                                        editable: false,
+                                                        sortable: false,
+                                                        click : false
+                                        }
+                            };
+                   }else if(XAUtil.isRowFilterPolicy(this.ui.policyType.val())){
+                                permissions = {
+                                                rowlvl:{
+                                                                label: 'Row Level Conditions',
+                                                                cell: "subgrid-custom",
+                                                                optionValues : subcolumns,
+                                                                editable: false,
+                                                                sortable: false,
+                                                                click : false
+                                                }
+                                    };
+                        }
 
-            permissions = {
-        		allow:{
-					label: 'Allow Conditions',
-					cell: "subgrid-custom",
-					optionValues : subcolumns,
-					editable: false,
-					sortable: false,
-					click : false
-		        }
-            };
-            if(enableDenyAndExceptionsInPolicies) {
+
+            if(enableDenyAndExceptionsInPolicies && that.ui.policyType.val() == 0) {
             	cols = {
             			allowExclude:{
             				label: 'Allow Exclude',
@@ -460,14 +557,34 @@ define(function(require) {'use strict';
 			    data: options
 			});
 			this.ui.policyType.select2({
-				closeOnSelect: true,
-				placeholder: 'Select policy type',
+                                closeOnSelect: false,
 				maximumSelectionSize : 1,
 				width: '220px',
-				allowClear: true,
+                                value : this.ui.policyType.val("0"),
+                                allowClear: false,
 				data: policyTypes
 	
 			});
+                        this.ui.policyLabels.select2({
+                            multiple: false,
+                            closeOnSelect: true,
+                            placeholder: 'Select Policy Label',
+                            allowClear: true,
+                            width: '220px',
+                            ajax :{
+                                url: "service/plugins/policyLabels",
+                                async : false,
+                                dataType : 'JSON',
+                                data: function (term, page) {
+                                    return {policyLabel : term};
+                                },
+                                results: function (data, page) {
+                                    var results = [];
+                                    results = data.map(function(m, i){return {id : _.escape(m), text: _.escape(m) };});
+                                    return {results : results};
+                                }
+                            }
+                        });
 		},
 		onDownload: function(e){
 			var that = this, url = '';
@@ -663,10 +780,14 @@ define(function(require) {'use strict';
 			//Get search values
 			var groups = (this.ui.userGroup.is(':visible')) ? this.ui.userGroup.select2('val'):undefined;
 			var users = (this.ui.userName.is(':visible')) ? this.ui.userName.select2('val'):undefined;
-			var rxName = this.ui.resourceName.val(), policyName = this.ui.policyName.val() , policyType = this.ui.policyType.val();
-			var params = {group : groups, user : users, polResource : rxName, policyNamePartial : policyName, policyType: policyType};
+                        var rxName = this.ui.resourceName.val(), policyName = this.ui.policyName.val() , policyType = this.ui.policyType.val(),
+                        policyLabel = this.ui.policyLabels.val()
+                        var params = {group : groups, user : users, polResource : rxName, policyNamePartial : policyName, policyType: policyType, policyLabelsPartial:policyLabel };
 			var component = (this.ui.componentType.val() != "") ? this.ui.componentType.select2('val'):undefined;
-
+            that.initializeRequiredData();
+            _.each(this.policyCollList, function(obj,i){
+                    this.renderTable(obj.collName, obj.serviceDefName);
+            },this);
 			var compFlag = false;
 			if(!_.isUndefined(component)) {
 				compFlag = true;
@@ -716,7 +837,8 @@ define(function(require) {'use strict';
 				user : users,
 				polResource : rxName,
 				policyNamePartial : policyName,
-				policyType: policyType
+                                policyType: policyType,
+                                policyLabelsPartial:policyLabel
 			};
 
 			this.setDownloadReportUrl(this,component,params);
@@ -792,6 +914,24 @@ define(function(require) {'use strict';
 				}, 1100);
 			}
 		},
+		
+		setSubgridCollForPolicyItems: function(model){
+			if (XAUtil.isMaskingPolicy(model.get('policyType'))) {
+				//'<name>Collection' must be same as subgrid custom column name
+                model.attributes.maskCollection = model.get('dataMaskPolicyItems');
+                //Add service type in masking condition
+                _.each(model.attributes.dataMaskPolicyItems , function(m){
+                    m.type = model.collection.queryParams.serviceType;
+                })
+			} else if (XAUtil.isRowFilterPolicy(model.get('policyType'))) {
+                model.attributes.rowlvlCollection = model.get('rowFilterPolicyItems');
+			} else {
+				model.attributes.allowCollection = model.get('policyItems');
+			}
+			model.attributes.denyCollection  = model.get('denyPolicyItems');
+			model.attributes.denyExcludeCollection    = model.get('denyExceptions');
+			model.attributes.allowExcludeCollection = model.get('allowExceptions');
+		},
 		onShowMorePermissions: function(e){
 						var policyId = $(e.currentTarget).attr('policy-id');
 						var $td = $(e.currentTarget).parents('td');
@@ -814,29 +954,30 @@ define(function(require) {'use strict';
 					},
 
 		onShowMore : function(e){
-			var attrName = 'policy-groups-id';
-			var id = $(e.currentTarget).attr(attrName);
-			if(_.isUndefined(id)){
-				id = $(e.currentTarget).attr('policy-users-id');
-				attrName = 'policy-users-id';
-			}   
+                    var attrName = this.attributName(e);
+                    var id = $(e.currentTarget).attr(attrName[0]);
 			var $td = $(e.currentTarget).parents('td');
 			$td.find('['+attrName+'="'+id+'"]').show();
 			$td.find('[data-id="showLess"]['+attrName+'="'+id+'"]').show();
 			$td.find('[data-id="showMore"]['+attrName+'="'+id+'"]').hide();
 		},
 		onShowLess : function(e){
-			var attrName = 'policy-groups-id';
-			var id = $(e.currentTarget).attr(attrName);
-			if(_.isUndefined(id)){
-				id = $(e.currentTarget).attr('policy-users-id');
-				attrName = 'policy-users-id';
-			}
+                    var attrName = this.attributName(e);
+                    var id = $(e.currentTarget).attr(attrName[0]);
 			var $td = $(e.currentTarget).parents('td');
 			$td.find('['+attrName+'="'+id+'"]').slice(4).hide();
 			$td.find('[data-id="showLess"]['+attrName+'="'+id+'"]').hide();
 			$td.find('[data-id="showMore"]['+attrName+'="'+id+'"]').show();
 		},
+                attributName :function(e){
+                    var attrName = ['policy-groups-id', 'policy-users-id', 'policy-label-id'], attributeName = "";
+                    attributeName =_.filter(attrName, function(name){
+                        if($(e.currentTarget).attr(name)){
+                            return name;
+                        }
+                    });
+                    return attributeName;
+                },
 		/** on close */
 		onClose : function() {
                         $('.popover').remove();
