@@ -64,7 +64,8 @@ define(function(require){
     		btnShowHide		: '[data-action="showHide"]',
 			visibilityDropdown		: '[data-id="visibilityDropdown"]',
 			addNewBtnDiv	: '[data-id="addNewBtnDiv"]',
-			deleteUser: '[data-id="deleteUserGroup"]'
+                        deleteUser: '[data-id="deleteUserGroup"]',
+                       showUserList:'[data-js="showUserList"]',
     	},
 
 		/** ui events hash */
@@ -76,7 +77,8 @@ define(function(require){
 			events['click ' + this.ui.btnSave]  = 'onSave';
 			events['click ' + this.ui.visibilityDropdown +' li a']  = 'onVisibilityChange';
 			events['click ' + this.ui.deleteUser] = 'onDeleteUser';
-			return events;
+            events['click ' + this.ui.showUserList] = 'showUserList';
+            return events;
 		},
 
     	/**
@@ -462,11 +464,118 @@ define(function(require){
 					}),
 					editable:false,
 					sortable:false
-				}
+                },
+                member	:{
+                    label : "Users",
+                    click : false,
+                    cell  : Backgrid.HtmlCell.extend({className: 'cellWidth-1'}),
+                    drag  : false,
+                    editable  : false,
+                    formatter : _.extend({}, Backgrid.CellFormatter.prototype, {
+                        fromRaw : function (rawValue,model) {
+                            return ('<div align="center"><button class="userViewicon" title = "View Users" data-js="showUserList" data-name="' + model.get('name')
+                                + '" data-id="' + model.id + '"<font color="black"><i class="icon-group"> </i></font></button></div>');
+                        }
+                    }),
+                }
 			};
 			return this.groupList.constructor.getTableCols(cols, this.groupList);
 		},
 
+        showUserList :function(e){
+            XAUtil.blockUI();
+            var that = this , name , msg = "", content = "" , totalRecords, infoMsg = "";
+            var anchor = $(e.currentTarget);
+            this.groupId = anchor.attr('data-id');
+            name = anchor.attr('data-name');
+            this.grpUserList = new VXUserList();
+            this.grpUserList.url  = "service/xusers/"+ this.groupId +"/users";
+            this.grpUserList.setPageSize(100);
+            this.grpUserList.fetch({
+                async : true,
+                cache : false,
+                reset : true,
+            }).then(function(){
+                XAUtil.blockUI('unblock');
+                totalRecords = this.state.totalRecords;
+                var title =  "<h4>User's List: " + name + "</h4>";
+                    _.each(that.grpUserList.models , function(model){
+                        msg +='<span class="label label-info userLists span-margin" >'+ model.get('name') + '</span>';
+                    });
+                    var html = '<div class="row-fluid">\
+                                    <div class="span12"><input type="text" data-id="userInput" placeholder="Search Users" class= "users-list-search"></div>\
+                                </div>';
+                    if(totalRecords > 100){
+                        var showAllUserbtn = '<button class="btn btn-mini showMore" data-id="'+ that.groupId +'" data-id="showMore" title="Show All Users">Show All Users</button>'
+                        infoMsg = '<div class="alert alert-warning infoWidth">'+localization.tt('msg.showInitialHundredUser')+showAllUserbtn+'</div>'
+                    }
+                    if(_.isEmpty(msg)){
+                            content = localization.tt("msg.noUserFoundText");
+                    }else{
+                            content = infoMsg + html + '<div class="usernames clearfix">' + msg +'</div>';
+                    }
+                    var modal = new Backbone.BootstrapModal({
+                        animate : true,
+                        content	: content,
+                        title   : title,
+                        okText  : localization.tt("lbl.ok"),
+                        allowCancel : true,
+                    }).open();
+                    modal.$el.find('.cancel').hide();
+                    that.showAllUser(modal, totalRecords, msg);
+            })
+        },
+
+        showAllUser : function(modal, totalRecords, msg){
+            var that = this;
+            var filterUserLists = _.clone(modal.$content.find('span'));
+            modal.$content.find('.showMore').on("click" ,function(){
+                modal.$el.find('.modal-body').scrollTop(0);
+                modal.$el.find('.modal-body').addClass('pointer-event');
+                modal.$el.find('.modal-body').append('<div class="loaderForModal"></div>');
+                this.grpUserList = new VXUserList();
+                this.grpUserList.url  = "service/xusers/"+ that.groupId +"/users";
+                this.grpUserList.setPageSize(totalRecords);
+                this.grpUserList.fetch({
+                    async : true,
+                    cache : false,
+                    reset : true,
+                }).then(function(){
+                    var tag ="";
+                    modal.$content.find('.showMore').attr('disabled',true);
+                    modal.$el.find('.modal-body').removeClass('pointer-event');
+                    modal.$el.find('.loaderForModal').remove();
+                    _.each(this.models, function(m){
+                        tag +='<span class="label label-info userLists span-margin" >'+ m.get('name') + '</span>';
+                    });
+                    modal.$el.find(".usernames").empty();
+                    modal.$el.find(".usernames").append(tag);
+                    filterUserLists = _.clone(modal.$content.find('span'));
+                    msg = tag;
+                })
+            });
+            modal.$el.find('[data-id="userInput"]').on("keyup" ,function(){
+                var input, users;
+                input = $('input[data-id="userInput"]');
+                users = msg;
+                if(!_.isEmpty(input.val())){
+                    users = _.filter(filterUserLists, function(v) {
+                        if(v.innerText.toLowerCase().indexOf(input.val().toLowerCase()) > -1){
+                            return v;
+                        }
+                    });
+                }
+                modal.$el.find(".usernames").empty();
+                if(_.isEmpty(users)){
+                    users = "No users found."
+                }
+                modal.$el.find(".usernames").append(users);
+                if(_.isEmpty(input.val())){
+                    that.showAllUser(modal, totalRecords, msg);
+                }
+            })
+        },
+
 		onUserGroupDeleteSuccess: function(jsonUsers,collection){
 			_.each(jsonUsers.vXStrings,function(ob){
 				var model = _.find(collection.models, function(mo){
@@ -485,15 +594,16 @@ define(function(require){
 			var message = '';
 			collection.each(function(obj){
 				if(obj.selected){
-	                selArr.push(obj.get('name'));
+	                selArr.push({"value" : obj.get('name') , "id" : obj.get('id')});
 	            }
             });
 			var  vXStrings = [];
 			var jsonUsers  = {};
 			for(var i in selArr) {
-				var item = selArr[i];
+				var itemName = selArr[i].value , itemId = selArr[i].id;
 				vXStrings.push({
-					"value" : item,
+					"value" : itemName,
+					"id" : itemId
 				});
 			}
 			jsonUsers.vXStrings = vXStrings;
@@ -520,38 +630,65 @@ define(function(require){
 						XAUtil.blockUI();
 						if(that.showUsers){
 							var model = new VXUser();
-							model.deleteUsers(jsonUsers,{
-								success: function(response,options){
-									XAUtil.blockUI('unblock');
-									that.collection.getFirstPage({fetch:true});
-									XAUtil.notifySuccess('Success','User deleted successfully!');
-									that.collection.selected = {};
-								},
-								error:function(response,options){
-									XAUtil.blockUI('unblock');
-									XAUtil.notifyError('Error', 'Error deleting User!');
-								}
-							});
-						}
-						else {
+                            var count = 0 , notDeletedUserName = "";
+                            _.map(jsonUsers.vXStrings , function(m){
+                            	model.deleteUsers(m.id,{
+                            		success: function(response,options){
+                            			count += 1;
+                            			that.userCollection(jsonUsers.vXStrings.length, count, notDeletedUserName)
+                            		},
+                            		error:function(response,options){
+                            			count += 1;
+                            			notDeletedUserName += m.value + ", ";
+                            			that.userCollection(jsonUsers.vXStrings.length, count, notDeletedUserName)
+                            		}
+                            	});
+                            });
+                        }else {
 							var model = new VXGroup();
-							model.deleteGroups(jsonUsers,{
-								success: function(response){
-									XAUtil.blockUI('unblock');
-									that.groupList.getFirstPage({fetch:true});
-									XAUtil.notifySuccess('Success','Group deleted successfully!');
-									that.groupList.selected  = {};
-								},
-								error:function(response,options){
-									XAUtil.blockUI('unblock');
-									XAUtil.notifyError('Error', 'Error deleting Group!');
-								}
-							});
+                            var count = 0, notDeletedGroupName ="";
+                            _.map(jsonUsers.vXStrings, function(m){
+                            	model.deleteGroups(m.id,{
+                            		success: function(response){
+                            			count += 1;
+                            			that.groupCollection(jsonUsers.vXStrings.length,count,notDeletedGroupName)
+                            		},
+                            		error:function(response,options){
+                            			count += 1;
+                            			notDeletedGroupName += m.value + ", ";
+                            			that.groupCollection(jsonUsers.vXStrings.length,count, notDeletedGroupName)
+                            		}
+                            	})
+                            });
 						}
 					}
 				});
 			}
 		},
+        userCollection : function(numberOfUser, count, notDeletedUserName){
+                if(count == numberOfUser){
+                        this.collection.getFirstPage({fetch:true});
+                        this.collection.selected = {};
+                        XAUtil.blockUI('unblock');
+                        if(notDeletedUserName === ""){
+                                XAUtil.notifySuccess('Success','User deleted successfully!');
+                        }else{
+                                XAUtil.notifyError('Error', 'Error occurred during deleting Users: '+ notDeletedUserName.slice(0 , -2));
+                        }
+                }
+        },
+        groupCollection : function(numberOfGroup, count ,notDeletedGroupName){
+                if(count == numberOfGroup){
+                        this.groupList.getFirstPage({fetch:true});
+                        this.groupList.selected  = {};
+                        XAUtil.blockUI('unblock');
+                        if(notDeletedGroupName === ""){
+                                XAUtil.notifySuccess('Success','Group deleted successfully!');
+                        } else {
+                                XAUtil.notifyError('Error', 'Error occurred during deleting Groups: '+ notDeletedGroupName.slice(0 , -2));
+                        }
+                }
+        },
 		addVisualSearch : function(){
 			var that = this;
 			var coll,placeholder;
@@ -654,6 +791,8 @@ define(function(require){
 		/** on close */
 		onClose: function(){
 			XAUtil.allowNavigation();
+			$('.fade.modal').hide();
+			$('.modal-backdrop').hide();
 		}
 
 	});
