@@ -139,7 +139,7 @@
 			return moment(context).format(f);
 		}else{
 			return context;   //  moment plugin not available. return data as is.
-		};
+                }
 	});
 
 	/*
@@ -154,7 +154,6 @@
 	
 	Handlebars.registerHelper('tt', function(str) {
 		return localization.tt(str);
-		return str;
 	});
 	
 	Handlebars.registerHelper('getCopyrightDate', function() {
@@ -187,7 +186,7 @@
 	Handlebars.registerHelper('customPermString', function(permsString,kclass) {
 		if(permsString == "--")
 			return permsString;
-		permArr = permsString.split(',');
+                var permArr = permsString.split(',');
 		var cl = _.isObject(kclass) ? 'label label-info' : kclass;
 		var tempArr = [];
 		_.each(permArr, function(val){
@@ -310,6 +309,9 @@
 			case '>=':
 				return (v1 >= v2) ? options.fn(this) : options.inverse(this);
 			break;
+			case '||':
+				return (v1 || v2) ? options.fn(this) : options.inverse(this);
+			break;
 			default:
 				return options.inverse(this);     
 			break;
@@ -421,7 +423,7 @@
 				html = '<span class="add-text">'+val+'</span>';
 		} else {
 			if($.inArray(val, arr) < 0)
-				return html = '<span class="delete-text">'+val+'</span>';
+                                return '<span class="delete-text">'+val+'</span>';
 		}
 	    return html;
 	});
@@ -439,9 +441,9 @@
 							isRemoved = false;
 					});
 					if(isRemoved)
-						return html = '<span class="delete-text">'+perm[type]+'</span>';
+                                                return '<span class="delete-text">'+perm[type]+'</span>';
 				} else {
-					return html = '<span class="delete-text">'+perm[type]+'</span>';
+                                        return '<span class="delete-text">'+perm[type]+'</span>';
 				}
 			}
 		} else {
@@ -453,9 +455,9 @@
 							isNewAdd = false;
 					});
 					if(isNewAdd)
-						return html = '<span class="add-text">'+perm[type]+'</span>';
+                                                return '<span class="add-text">'+perm[type]+'</span>';
 				} else {
-					return html = '<span class="delete-text">'+perm[type]+'</span>';
+                                        return '<span class="delete-text">'+perm[type]+'</span>';
 				}
 			}
 		}
@@ -476,9 +478,9 @@
 							isRemoved = false;
 					});
 					if(isRemoved)
-						return html = '<span class="delete-text">'+perm[type]+'</span>';
+                                                return  '<span class="delete-text">'+perm[type]+'</span>';
 				} else {
-					return html = '<span class="delete-text">'+perm[type]+'</span>';
+                                        return '<span class="delete-text">'+perm[type]+'</span>';
 				}
 			}
 		} else {
@@ -490,9 +492,9 @@
 							isNewAdd = false;
 					});
 					if(isNewAdd)
-						return html = '<span class="add-text">'+perm[type]+'</span>';
+                                                return  '<span class="add-text">'+perm[type]+'</span>';
 				} else {
-					return html = '<span class="add-text">'+perm[type]+'</span>';
+                                        return  '<span class="add-text">'+perm[type]+'</span>';
 				}
 			}
 		}
@@ -540,7 +542,21 @@
 		var XAEnums		= require('utils/XAEnums');
 		return XAUtil.isRenderRowFilter(XAEnums.RangerPolicyType.RANGER_ROW_FILTER_POLICY_TYPE.value);
 	});
-	
+	Handlebars.registerHelper('showMaskingTab', function(context, options) {
+		var dataMaskDef = context.rangerServiceDef.get('dataMaskDef');
+		
+		return ( !_.isUndefined(dataMaskDef) 
+				&& ( !_.isUndefined(dataMaskDef.accessTypes) ) && dataMaskDef.accessTypes.length > 0 
+				&& ( !_.isUndefined(dataMaskDef.maskTypes) )   && dataMaskDef.maskTypes.length > 0 )
+				? options.fn(this) : options.inverse(this);
+	});
+	Handlebars.registerHelper('showRowLevelTab', function(context, options) {
+		var rowFilterDef = context.rangerServiceDef.get('rowFilterDef');
+		return ( !_.isUndefined(rowFilterDef) 
+				&& ( !_.isUndefined(rowFilterDef.accessTypes) ) && rowFilterDef.accessTypes.length > 0 
+				&& ( !_.isUndefined(rowFilterDef.resources) ) && rowFilterDef.resources.length > 0 )
+				? options.fn(this) : options.inverse(this); 
+	});
 
 	return HHelpers;
 });
