@@ -45,7 +45,6 @@ import org.apache.ranger.common.UserSessionBase;
 import org.apache.ranger.db.RangerDaoManager;
 import org.apache.ranger.db.XXServiceDao;
 import org.apache.ranger.db.XXServiceDefDao;
-import org.apache.ranger.entity.XXDBBase;
 import org.apache.ranger.entity.XXService;
 import org.apache.ranger.entity.XXServiceDef;
 import org.apache.ranger.plugin.model.RangerPolicy;
@@ -73,6 +72,7 @@ import org.apache.ranger.security.context.RangerContextHolder;
 import org.apache.ranger.security.context.RangerSecurityContext;
 import org.apache.ranger.service.RangerAuditFields;
 import org.apache.ranger.service.RangerDataHistService;
+import org.apache.ranger.service.RangerPolicyLabelsService;
 import org.apache.ranger.service.RangerPolicyService;
 import org.apache.ranger.service.RangerServiceDefService;
 import org.apache.ranger.service.RangerServiceService;
@@ -93,7 +93,7 @@ import org.mockito.InjectMocks;
 import org.mockito.Matchers;
 import org.mockito.Mock;
 import org.mockito.Mockito;
-import org.mockito.runners.MockitoJUnitRunner;
+import org.mockito.junit.MockitoJUnitRunner;
 
 @RunWith(MockitoJUnitRunner.class)
 @FixMethodOrder(MethodSorters.NAME_ASCENDING)
@@ -141,7 +141,7 @@ public class TestServiceREST {
 	XUserMgr userMgr;
 
 	@Mock
-	RangerAuditFields<XXDBBase> rangerAuditFields;
+	RangerAuditFields rangerAuditFields;
 
 	@Mock
 	ContextUtil contextUtil;
@@ -178,6 +178,9 @@ public class TestServiceREST {
 
 	@Mock
 	AssetMgr assetMgr;
+	
+	@Mock
+    RangerPolicyLabelsService policyLabelsService;
 
 	@Rule
 	public ExpectedException thrown = ExpectedException.none();
@@ -331,7 +334,7 @@ public class TestServiceREST {
 
 		Mockito.when(
 				svcStore.createServiceDef((RangerServiceDef) Mockito
-						.anyObject())).thenReturn(rangerServiceDef);
+						.any())).thenReturn(rangerServiceDef);
 
 		RangerServiceDef dbRangerServiceDef = serviceREST
 				.createServiceDef(rangerServiceDef);
@@ -371,7 +374,7 @@ public class TestServiceREST {
 
 		Mockito.when(
 				svcStore.updateServiceDef((RangerServiceDef) Mockito
-						.anyObject())).thenReturn(rangerServiceDef);
+						.any())).thenReturn(rangerServiceDef);
 
 		RangerServiceDef dbRangerServiceDef = serviceREST
 				.updateServiceDef(rangerServiceDef);
@@ -475,7 +478,7 @@ public class TestServiceREST {
 				.thenReturn(xServiceDef);
 
 		Mockito.when(
-				svcStore.createService((RangerService) Mockito.anyObject()))
+				svcStore.createService((RangerService) Mockito.any()))
 				.thenReturn(rangerService);
 
 		RangerService dbRangerService = serviceREST
@@ -528,8 +531,6 @@ public class TestServiceREST {
 		serviceDefList.setList(serviceDefsList);
 		Mockito.when(svcStore.getPaginatedServiceDefs(filter)).thenReturn(
 				serviceDefList);
-		Mockito.when(serviceDefService.searchRangerServiceDefs(filter))
-				.thenReturn(new RangerServiceDefList(serviceDefsList));
 		RangerServiceDefList dbRangerServiceDef = serviceREST
 				.getServiceDefs(request);
 		Assert.assertNotNull(dbRangerServiceDef);
@@ -543,6 +544,9 @@ public class TestServiceREST {
 
 		RangerService rangerService = rangerService();
 		XXServiceDef xServiceDef = serviceDef();
+        HttpServletRequest request = null;
+		Map<String, Object> options = null;
+
 		XXServiceDefDao xServiceDefDao = Mockito.mock(XXServiceDefDao.class);
 		Mockito.when(validatorFactory.getServiceValidator(svcStore))
 				.thenReturn(serviceValidator);
@@ -552,11 +556,11 @@ public class TestServiceREST {
 				.thenReturn(xServiceDef);
 
 		Mockito.when(
-				svcStore.updateService((RangerService) Mockito.anyObject()))
+				svcStore.updateService((RangerService) Mockito.any(), (Map<String, Object>) Mockito.any()))
 				.thenReturn(rangerService);
 
 		RangerService dbRangerService = serviceREST
-				.updateService(rangerService);
+				.updateService(rangerService, request);
 		Assert.assertNotNull(dbRangerService);
 		Assert.assertNotNull(dbRangerService);
 		Assert.assertEquals(rangerService, dbRangerService);
@@ -580,7 +584,7 @@ public class TestServiceREST {
 				dbRangerService.getUpdatedBy());
 		Mockito.verify(validatorFactory).getServiceValidator(svcStore);
 		Mockito.verify(daoManager).getXXServiceDef();
-		Mockito.verify(svcStore).updateService(rangerService);
+		Mockito.verify(svcStore).updateService(rangerService, options);
 	}
 
 	@Test
@@ -669,8 +673,6 @@ public class TestServiceREST {
 		grantRequestObj.setGrantor("read");
 		grantRequestObj.setIsRecursive(true);
 
-		Mockito.when(validatorFactory.getServiceDefValidator(svcStore))
-				.thenReturn(serviceDefValidator);
 		Mockito.when(
 				serviceUtil.isValidateHttpsAuthentication(serviceName, request))
 				.thenReturn(false);
@@ -700,9 +702,6 @@ public class TestServiceREST {
 		revokeRequest.setGroups(groupList);
 		revokeRequest.setUsers(userList);
 
-		Mockito.when(validatorFactory.getServiceDefValidator(svcStore))
-				.thenReturn(serviceDefValidator);
-
 		RESTResponse restResponse = serviceREST.revokeAccess(serviceName,
 				revokeRequest, request);
 		Assert.assertNotNull(restResponse);
@@ -741,22 +740,17 @@ public class TestServiceREST {
 		XXServiceDefDao xServiceDefDao = Mockito.mock(XXServiceDefDao.class);
 		XXServiceDao xServiceDao = Mockito.mock(XXServiceDao.class);
 
-		Mockito.when(
-				svcStore.getServicePoliciesIfUpdated(Mockito.anyString(),
-						Mockito.anyLong())).thenReturn(servicePolicies);
 		Mockito.when(validatorFactory.getPolicyValidator(svcStore)).thenReturn(
 				policyValidator);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
 		Mockito.when(bizUtil.getCurrentUserLoginId()).thenReturn(userName);
-		Mockito.when(userMgr.getGroupsForUser(userName)).thenReturn(
-				userGroupsList);
 		Mockito.when(daoManager.getXXService()).thenReturn(xServiceDao);
 		Mockito.when(xServiceDao.findByName(Mockito.anyString())).thenReturn(
 				xService);
 		Mockito.when(daoManager.getXXServiceDef()).thenReturn(xServiceDefDao);
 		Mockito.when(xServiceDefDao.getById(xService.getType())).thenReturn(
 				xServiceDef);
-		Mockito.when(svcStore.createPolicy((RangerPolicy) Mockito.anyObject()))
+		Mockito.when(svcStore.createPolicy((RangerPolicy) Mockito.any()))
 				.thenReturn(rangPolicy);
 
 		RangerPolicy dbRangerPolicy = serviceREST.createPolicy(rangerPolicy,null);
@@ -792,8 +786,6 @@ public class TestServiceREST {
 				policyValidator);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
 		Mockito.when(bizUtil.getCurrentUserLoginId()).thenReturn(userName);
-		Mockito.when(userMgr.getGroupsForUser(userName)).thenReturn(
-				userGroupsList);
 		Mockito.when(daoManager.getXXService()).thenReturn(xServiceDao);
 		Mockito.when(xServiceDao.findByName(Mockito.anyString())).thenReturn(xService);
 		Mockito.when(daoManager.getXXServiceDef()).thenReturn(xServiceDefDao);
@@ -829,7 +821,6 @@ public class TestServiceREST {
 				policyValidator);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
 		Mockito.when(bizUtil.getCurrentUserLoginId()).thenReturn(userName);
-		Mockito.when(userMgr.getGroupsForUser(userName)).thenReturn(userGroupsList);
 		Mockito.when(svcStore.getPolicy(Id)).thenReturn(rangerPolicy);
 		Mockito.when(daoManager.getXXService()).thenReturn(xServiceDao);
 		Mockito.when(xServiceDao.findByName(Mockito.anyString())).thenReturn(xService);
@@ -860,12 +851,8 @@ public class TestServiceREST {
 		XXService xService = xService();
 		XXServiceDefDao xServiceDefDao = Mockito.mock(XXServiceDefDao.class);
 		XXServiceDao xServiceDao = Mockito.mock(XXServiceDao.class);
-		Mockito.when(validatorFactory.getPolicyValidator(svcStore)).thenReturn(
-				policyValidator);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(true);
 		Mockito.when(bizUtil.getCurrentUserLoginId()).thenReturn(userName);
-		Mockito.when(userMgr.getGroupsForUser(userName)).thenReturn(
-				userGroupsList);
 		Mockito.when(daoManager.getXXService()).thenReturn(xServiceDao);
 		Mockito.when(xServiceDao.findByName(Mockito.anyString())).thenReturn(xService);
 		Mockito.when(daoManager.getXXServiceDef()).thenReturn(xServiceDefDao);
@@ -892,12 +879,11 @@ public class TestServiceREST {
 		Mockito.verify(searchUtil).getSearchFilter(request,
 				policyService.sortFields);
 	}
-
+	
 	@Test
 	public void test21countPolicies() throws Exception {
 		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
 
-		PList<RangerPolicy> ret  = Mockito.mock(PList.class);
 		SearchFilter filter = new SearchFilter();
 		filter.setParam(SearchFilter.POLICY_NAME, "policyName");
 		filter.setParam(SearchFilter.SERVICE_NAME, "serviceName");
@@ -905,8 +891,6 @@ public class TestServiceREST {
 				searchUtil.getSearchFilter(request, policyService.sortFields))
 				.thenReturn(filter);
 
-		Mockito.when(svcStore.getPaginatedPolicies(filter)).thenReturn(ret);
-
 		Long data = serviceREST.countPolicies(request);
 		Assert.assertNotNull(data);
 		Mockito.verify(searchUtil).getSearchFilter(request,
@@ -918,7 +902,6 @@ public class TestServiceREST {
 		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
 		RangerPolicy rangerPolicy = rangerPolicy();
 
-		PList<RangerPolicy> ret = Mockito.mock(PList.class);
 		SearchFilter filter = new SearchFilter();
 		filter.setParam(SearchFilter.POLICY_NAME, "policyName");
 		filter.setParam(SearchFilter.SERVICE_NAME, "serviceName");
@@ -926,9 +909,6 @@ public class TestServiceREST {
 				searchUtil.getSearchFilter(request, policyService.sortFields))
 				.thenReturn(filter);
 
-		Mockito.when(svcStore.getPaginatedServicePolicies(Id, filter))
-				.thenReturn(ret);
-
 		RangerPolicyList dbRangerPolicy = serviceREST.getServicePolicies(
 				rangerPolicy.getId(), request);
 		Assert.assertNotNull(dbRangerPolicy);
@@ -966,8 +946,6 @@ public class TestServiceREST {
 		Long lastKnownVersion = 1L;
 		String pluginId = "1";
 
-		Mockito.doNothing().when(assetMgr).createPluginInfo(serviceName, pluginId, null, 1, 1L, lastKnownVersion, 1, 0);
-
 		ServicePolicies dbServicePolicies = serviceREST
 				.getServicePoliciesIfUpdated(serviceName, lastKnownVersion, 0L,
 						pluginId, "", request);
@@ -1019,8 +997,6 @@ public class TestServiceREST {
 		Mockito.when(svcStore.getPolicyFromEventTime(strdt, 1l)).thenReturn(policy);
 		Mockito.when(bizUtil.isAdmin()).thenReturn(false);
 		Mockito.when(bizUtil.getCurrentUserLoginId()).thenReturn(userName);
-		Mockito.when(userMgr.getGroupsForUser(userName)).thenReturn(
-				userGroupsList);
 
 		Mockito.when(restErrorUtil.createRESTException(Matchers.anyInt(), Matchers.anyString(), Matchers.anyBoolean()))
 				.thenThrow(new WebApplicationException());
@@ -1099,7 +1075,8 @@ public class TestServiceREST {
 		RangerPolicy existingPolicy = rangerPolicy();
 		RangerPolicy appliedPolicy = rangerPolicy();
 
-		existingPolicy.setPolicyItems(null);
+                List<RangerPolicyItem> policyItem = new ArrayList<RangerPolicyItem>();
+                existingPolicy.setPolicyItems(policyItem );
 		appliedPolicy.setPolicyItems(null);
 
 		Map<String, RangerPolicyResource> policyResources = new HashMap<String, RangerPolicyResource>();
@@ -1148,7 +1125,8 @@ public class TestServiceREST {
 		RangerPolicy existingPolicy = rangerPolicy();
 		RangerPolicy appliedPolicy = rangerPolicy();
 
-		existingPolicy.setPolicyItems(null);
+                List<RangerPolicyItem> policyItem = new ArrayList<RangerPolicyItem>();
+                existingPolicy.setPolicyItems(policyItem);
 		appliedPolicy.setPolicyItems(null);
 
 		Map<String, RangerPolicyResource> policyResources = new HashMap<String, RangerPolicyResource>();
@@ -1242,8 +1220,8 @@ public class TestServiceREST {
 	@Test
 	public void test42grant() {
 		RangerPolicy existingPolicy = rangerPolicy();
-
-		existingPolicy.setPolicyItems(null);
+                List<RangerPolicyItem> policyItem = new ArrayList<RangerPolicyItem>();
+                existingPolicy.setPolicyItems(policyItem );
 
 		Map<String, RangerPolicyResource> policyResources = new HashMap<String, RangerPolicyResource>();
 		RangerPolicyResource rangerPolicyResource = new RangerPolicyResource("/tmp");
@@ -1337,7 +1315,8 @@ public class TestServiceREST {
 	public void test43revoke() {
 		RangerPolicy existingPolicy = rangerPolicy();
 
-		existingPolicy.setPolicyItems(null);
+                List<RangerPolicyItem> policyItem = new ArrayList<RangerPolicyItem>();
+                existingPolicy.setPolicyItems(policyItem );
 
 		Map<String, RangerPolicyResource> policyResources = new HashMap<String, RangerPolicyResource>();
 		RangerPolicyResource rangerPolicyResource = new RangerPolicyResource("/tmp");
@@ -1426,4 +1405,21 @@ public class TestServiceREST {
 
 		assert(true);
 	}
+	
+	@Test
+	public void test44getPolicyLabels() throws Exception {
+		HttpServletRequest request = Mockito.mock(HttpServletRequest.class);
+		SearchFilter filter = new SearchFilter();
+		Mockito.when(
+				searchUtil.getSearchFilter(request, policyLabelsService.sortFields))
+				.thenReturn(filter);
+		List<String> ret = new ArrayList<String>();
+		Mockito.when(
+				svcStore.getPolicyLabels(filter))
+				.thenReturn(ret);
+		ret = serviceREST.getPolicyLabels(request);
+		Assert.assertNotNull(ret);
+		Mockito.verify(searchUtil).getSearchFilter(request,
+				policyLabelsService.sortFields);
+	}
 }
