@@ -36,6 +36,7 @@ import org.apache.ranger.plugin.model.RangerTagDef.RangerTagAttributeDef;
 import org.apache.ranger.plugin.util.ServiceTags;
 
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -134,6 +135,7 @@ public class AtlasNotificationMapper {
 				case ENTITY_UPDATE:
 				case ENTITY_DELETE:
 				case TRAIT_ADD:
+				case TRAIT_UPDATE:
 				case TRAIT_DELETE: {
 					ret = true;
 					break;
@@ -161,9 +163,9 @@ public class AtlasNotificationMapper {
 			ret = buildServiceTags(entityWithTraits, null);
 			if (ret != null) {
 				// tag-definitions should NOT be deleted as part of service-resource delete
-				ret.setTagDefinitions(MapUtils.EMPTY_MAP);
+				ret.setTagDefinitions(Collections.<Long, RangerTagDef>emptyMap());
 				// Ranger deletes tags associated with deleted service-resource
-				ret.setTags(MapUtils.EMPTY_MAP);
+				ret.setTags(Collections.<Long, RangerTag>emptyMap());
 			}
 		}
 
