@@ -6,9 +6,9 @@
  * to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -24,7 +24,11 @@ import java.util.List;
 public interface UserGroupSink {
 	void init() throws Throwable;
 
-	void addOrUpdateUser(String user, List<String> groups);
+	void addOrUpdateUser(String user, List<String> groups) throws Throwable;
 	
-	void addOrUpdateGroup(String group);
+	void addOrUpdateUser(String user) throws Throwable;
+	
+	void addOrUpdateGroup(String group) throws Throwable;
+	
+	void addOrUpdateGroup(String group, List<String> users) throws Throwable;
 }
